<?php
/**
 * stanislav.elbl, 21.02.2021
 */

namespace Ron\Controls;

use Ron\DB\Database;
use Ron\DB\DBUtils;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;


class BrowserField
{
    const FIELD_TYPE_DEFAULT = 'default';
    const FIELD_TYPE_HIDDEN = 'hidden';
    const FIELD_TYPE_LINE = 'line';
    const FIELD_TYPE_TEXT = 'text';
    const FIELD_TYPE_SELECT = 'select';
    const FIELD_TYPE_URL = 'url';

    /** @var Database */
    public $database;

    public $type;

    /** @var string     Kod sloupce */
    public $code;
    /** @var bool       Umoznuje skryt sloupec */
    public $visible = true;

    public $sqlFieldName;
    /** @var string     SQL vyraz, ktery se pouzije pro razeni - kdyz neni nastaven, pouzije se sqlFieldName */
    public $sortSQL;
    /** @var string     SQL vyraz, ktery se pouzije pro razeni - kdyz neni nastaven, pouzije se sqlFieldName [DESC] */
    public $sortSQLDesc;
    /** @var int        index pole v radku nactenem z databaze */
    public $sqlFieldIndex;
    /** @var int        index pole, ktere se pouzije pro titulek */
    public $titleFieldIndex = null;
    /** @var string     Text, ktery se zobrazi na zacatku titulku */
    public $titlePrefix = '';
    /** @var int        index pole, ktere se zobrazi v zavorce */
    public $sqlFieldIndex2 = null;

    /** @var bool       Pokud je true, tak se pole vynecha pri automatickem sestavovani GROUP BY casti SQL dotazu */
    public $excludeFromGroupBy = false;

    /** @var string Prefix pro preklad retezcu pro SELECT */
    public $translationPrefix;
    /** @var string Prefix pro preklad titulku SELECT */
    public $titleTranslationPrefix;
    /** @var int|string    Index nebo kod pole, ktere se pouzije jako kod pro preklad */
    public $translationValueIndex;
    /** @var bool       Priznak, ze se ma prelozit text nacteny z databaze */
    public $translateText = false;


    /** @var int[]      Asociativni pole atributu (nazev atributu => index pole) */
    public $attributeIndexes = [];

    /** @var string     Nepovinne ID pole - pro zjisteni pouzijte metodu getId */
    protected $id;

    /** @var string     Text titulku */
    public $header;
    public $headerColSpan;
    public $footer;
    /** @var int        Pokud je > 1, tak se nasledujici footer(y) nezobrazi*/
    public $footerColSpan;
    /** @var string     Formatovaci retezec pro zobrazeni */
    public $format;
    /** @var string     Text, ktery se zobrazi misto hodnoty pole (pouze pro nektere typy - link,text) */
    public $text;

    /** @var string     Odkaz - prida se k nemu jeste "&record=..." */
    public $link;
    /** @var string[]   Atributy pro odkaz */
    public $linkAttributes = null;

    /** @var string     Zarovnani textu - left, right, center */
    public $align;
    /** @var bool       Jestli se muze podle tohoto pole radit nebo ne */
    public $ordering;
    /** @var bool       Jestli muze byt text zalomeny */
    public $wrap;
    /** @var array      Seznam hodnot, ktere se zobrazi pro pole select (podle hodnoty v databazi) */
    public $options;

    public $style;
    public $className;
    public $rowSpan;

    /** @var mixed      Pokud je nastavena filterValue, pole se zobrazi jen v pripade, ze ma tuto hodnotu.
     *                  Pokud je to funkce, tak se pole zobrazi v pripade, ze funkce vraci true.
     *                  Lze pouzit napriklad pro zobrazeni nejakeho priznaku, ze radek splnuje nejakou podminku. */
    public $filterValue;

    /** @var bool       Priznak, ze se ma konvertovat text (default = true) */
    public $htmlConvert;


    /**
     * Inicializuje pole. Pokud je zadano asociativni pole $options, vola i inicializaci
     * @param Database $database
     * @param array $options
     */
    function __construct($database = null, $options = null)
    {
        $this ->database = $database;

        $this ->type = self::FIELD_TYPE_DEFAULT;
        $this ->align = '';

        $this ->sqlFieldIndex = null;
        $this ->footerColSpan = 0;

        $this ->htmlConvert = true;

        if ($options) {
            $this ->init($options);
        }
    }


    /**
     * Inicializuje pole podle asociativniho pole $options
     * @param mixed $options
     */
    private function init($options) {
        foreach ($options as $key => $value) {
            switch ($key) {
                case 'type' :
                    $this ->type = $value;
                    break;

                case 'sqlFieldName' :
                    $this ->sqlFieldName = $value;
                    break;

                case 'sqlIndex' :
                    $this ->sqlFieldIndex = $value;
                    break;

                case 'visible' :
                    $this ->visible = $value;
                    break;

                case 'header' :
                    $this ->header = $value;
                    break;

                case 'headerTextId' :
                    $this ->header = TextManager::_($value);
                    break;

                case 'format' :
                    $this ->format = $value;
                    break;

                case 'align' :
                    $this ->align = $value;
                    break;

                case 'link' :
                    $this ->link = $value;
                    break;

                case 'wrap' :
                    $this ->wrap = $value;
                    break;

                case 'ordering' :
                    $this ->ordering = $value;
                    break;

                case 'text' :
                    $this ->text = $value;
                    break;

                case 'options' :
                    $this ->options = $value;
                    break;

                case 'headerColSpan' :
                    $this ->headerColSpan = $value;
                    break;

                case 'footerColSpan' :
                    $this ->footerColSpan = $value;
                    break;

                default :
                    $this ->{$key} = $value;
                    break;
            }
        }
    }


    /**
     * @param string $type
     * @return BrowserField
     */
    public function setType($type)
    {
        $this->type = $type;
        return $this;
    }


    /**
     * @param string $code
     * @return BrowserField
     */
    public function setCode($code)
    {
        $this->code = $code;
        return $this;
    }

    /**
     * @param boolean $visible
     * @return BrowserField
     */
    public function setVisible($visible)
    {
        $this->visible = $visible;
        return $this;
    }

    /**
     * @param mixed $sqlFieldName
     * @param null $sqlFieldIndex   Pokud je zadano, nastavi se i index pole
     * @return BrowserField
     */
    public function setSqlFieldName($sqlFieldName, $sqlFieldIndex = null)
    {
        $this->sqlFieldName = $sqlFieldName;
        if (isset($sqlFieldIndex)) {
            $this ->sqlFieldIndex = $sqlFieldIndex;
        }
        return $this;
    }

    /**
     * @param int $sqlFieldIndex
     * @return BrowserField
     */
    public function setSqlFieldIndex($sqlFieldIndex)
    {
        $this->sqlFieldIndex = $sqlFieldIndex;
        return $this;
    }

    /**
     * @param int $sqlFieldIndex2
     * @return BrowserField
     */
    public function setSqlFieldIndex2($sqlFieldIndex2)
    {
        $this->sqlFieldIndex2 = $sqlFieldIndex2;
        return $this;
    }


    /**
     * @param boolean $excludeFromGroupBy
     * @return $this
     */
    public function setExcludeFromGroupBy($excludeFromGroupBy)
    {
        $this->excludeFromGroupBy = $excludeFromGroupBy;
        return $this;
    }




    /**
     * @param int $titleFieldIndex
     * @param string $titlePrefix
     * @return BrowserField
     */
    public function setTitleFieldIndex($titleFieldIndex, $titlePrefix = null)
    {
        $this->titleFieldIndex = $titleFieldIndex;
        if (isset($titlePrefix)) {
            $this ->titlePrefix = $titlePrefix;
        }

        return $this;
    }

    /**
     * @param string $titlePrefix
     * @return BrowserField
     */
    public function setTitlePrefix($titlePrefix)
    {
        $this->titlePrefix = $titlePrefix;
        return $this;
    }


    /**
     * @param string $translationPrefix
     * @param int|string $translationValueIndex
     * @return $this
     */
    public function setTranslationPrefix($translationPrefix, $translationValueIndex = null)
    {
        $this->translationPrefix = $translationPrefix;
        if (isset($translationValueIndex)) {
            $this->translationValueIndex = $translationValueIndex;
        }
        return $this;
    }

    /**
     * @param string $titleTranslationPrefix
     * @return $this
     */
    public function setTitleTranslationPrefix($titleTranslationPrefix)
    {
        $this->titleTranslationPrefix = $titleTranslationPrefix;
        return $this;
    }

    /**
     * @param int|string $translationValueIndex
     * @return $this
     */
    public function setTranslationValueIndex($translationValueIndex)
    {
        $this->translationValueIndex = $translationValueIndex;
        return $this;
    }

    /**
     * @param boolean $translateText
     * @return $this
     */
    public function setTranslateText($translateText)
    {
        $this->translateText = $translateText;
        return $this;
    }


    /**
     * @param \int[] $attributeIndexes
     * @return BrowserField
     */
    public function setAttributeIndexes($attributeIndexes)
    {
        $this->attributeIndexes = $attributeIndexes;
        return $this;
    }

    /**
     * @param \int[] $attributeIndexes
     * @return BrowserField
     */
    public function addAttributeIndexes($attributeIndexes)
    {
        if ($attributeIndexes) {
            foreach ($attributeIndexes as $key => $value) {
                $this ->attributeIndexes[$key] = $value;
            }
        }

        return $this;
    }



    /**
     * @param string $sortSQL
     * @param string $sortSQLDesc   pokud je zadano, nastavi se i SQL pro sestupne razeni
     * @return BrowserField
     */
    public function setSortSQL($sortSQL, $sortSQLDesc = null)
    {
        $this->sortSQL = $sortSQL;
        if (isset($sortSQLDesc)) {
            $this ->sortSQLDesc = $sortSQLDesc;
        }
        return $this;
    }

    /**
     * @param string $sortSQLDesc
     * @return BrowserField
     */
    public function setSortSQLDesc($sortSQLDesc)
    {
        $this->sortSQLDesc = $sortSQLDesc;
        return $this;
    }

    /**
     * @param string $id
     * @return BrowserField
     */
    public function setId($id)
    {
        $this->id = $id;
        return $this;
    }

    /**
     * @param string $header
     * @param int $headerColSpan    Nepovinne lze zadat i hodnotu pro colspan
     * @return BrowserField
     */
    public function setHeader($header, $headerColSpan = null)
    {
        $this->header = $header;
        if (isset($headerColSpan)) {
            $this ->headerColSpan = $headerColSpan;
        }
        return $this;
    }

    /**
     * Nastavi text hlavicky - nejdrive jej prelozi
     * @param string $headerText
     * @param int $headerColSpan    Nepovinne lze zadat i hodnotu pro colspan
     * @return BrowserField
     */
    public function setHeaderText($headerText, $headerColSpan = null)
    {
        $this->header = TextManager::_($headerText);
        if (isset($headerColSpan)) {
            $this ->headerColSpan = $headerColSpan;
        }
        return $this;
    }

    /**
     * @param mixed $headerColSpan
     * @return BrowserField
     */
    public function setHeaderColSpan($headerColSpan)
    {
        $this->headerColSpan = $headerColSpan;
        return $this;
    }

    /**
     * @param mixed $footer
     * @return BrowserField
     */
    public function setFooter($footer)
    {
        $this->footer = $footer;
        return $this;
    }

    /**
     * @param int $footerColSpan
     * @return BrowserField
     */
    public function setFooterColSpan($footerColSpan)
    {
        $this->footerColSpan = $footerColSpan;
        return $this;
    }

    /**
     * @param string $format
     * @return BrowserField
     */
    public function setFormat($format)
    {
        $this->format = $format;
        return $this;
    }

    /**
     * @param string $text
     * @return BrowserField
     */
    public function setText($text)
    {
        $this->text = $text;
        return $this;
    }

    /**
     * @param string $link
     * @return BrowserField
     */
    public function setLink($link)
    {
        $this->link = $link;
        return $this;
    }


    /**
     * @param string[] $linkAttributes
     * @return BrowserField
     */
    public function setLinkAttributes($linkAttributes)
    {
        $this->linkAttributes = $linkAttributes;
        return $this;
    }



    /**
     * @param string $align
     * @return BrowserField
     */
    public function setAlign($align)
    {
        $this->align = $align;
        return $this;
    }

    /**
     * @param boolean $ordering
     * @return BrowserField
     */
    public function setOrdering($ordering)
    {
        $this->ordering = $ordering;
        return $this;
    }

    /**
     * @param boolean $wrap
     * @return BrowserField
     */
    public function setWrap($wrap)
    {
        $this->wrap = $wrap;
        return $this;
    }

    /**
     * Nastavi texty, ktere se zobrazi pro jednotlive hodnoty
     * @param array $options
     * @return BrowserField
     */
    public function setOptions($options)
    {
        $this->options = $options;
        return $this;
    }

    /**
     * @param mixed $style
     * @return BrowserField
     */
    public function setStyle($style)
    {
        $this->style = $style;
        return $this;
    }

    /**
     * @param mixed $className
     * @return BrowserField
     */
    public function setClassName($className)
    {
        $this->className = $className;
        return $this;
    }

    /**
     * @param mixed $rowSpan
     * @return BrowserField
     */
    public function setRowSpan($rowSpan)
    {
        $this->rowSpan = $rowSpan;
        return $this;
    }

    /**
     * @param boolean $htmlConvert
     * @return BrowserField
     */
    public function setHtmlConvert($htmlConvert)
    {
        $this->htmlConvert = $htmlConvert;
        return $this;
    }


    /**
     * @param mixed $filterValue
     * @return BrowserField
     */
    public function setFilterValue($filterValue)
    {
        $this->filterValue = $filterValue;
        return $this;
    }



    /**
     * Nacte nastaveni jedne vlastnosti (atributu) z konfigurace
     * @param $key
     * @param $value
     * @return BrowserField
     */
    function loadConfigurationItem($key, $value)
    {
        switch ($key) {
            case 'align' :
            case 'sqlFieldName' :
            case 'sortSQL' :
            case 'sortSQLDesc' :
            case 'format' :
            case 'link' :
            case 'linkAttributes' :
            case 'style' :
            case 'className' :
            case 'filterValue' :
            case 'translationPrefix' :
            case 'titleTranslationPrefix' :
                $this ->{$key} = $value;
                break;

            case 'class' :
                $this ->className = $value;
                break;

            case 'addClass' :
                $this ->className .= ($this ->className ? ' ' : '') . $value;
                break;

            case 'header' :
            case 'footer' :
            case 'text' :
            case 'titlePrefix' :
                $this ->{$key} = TextManager::_($value);
                break;

            case 'visible' :
            case 'wrap' :
            case 'ordering' :
            case 'sqlFieldIndex' :
            case 'headerColSpan' :
            case 'footerColSpan' :
            case 'htmlConvert' :
            case 'translateText' :
            case 'excludeFromGroupBy' :
                $this ->{$key} = (int)$value;
                break;

            case 'sqlFieldIndex2' :
            case 'titleFieldIndex' :
                $this ->{$key} = ($value !== '') ? (int)$value : null;
                break;

            case 'translationValueIndex' :
                $this ->{$key} = ($value !== '')
                    ? ( ($value[0] >= '0'  &&  $value[0] <= '9') ? (int)$value : $value ) // muze byt cislo i nazev pole
                    : null;
                break;
        }

        return $this;
    }


    /**
     * Zpracuje konfiguraci sloupce nactenou z XML pomoci @XmlLoader
     * @param \ArrayAccess $confArray
     * @return BrowserField
     */
    function loadConfigurationArray($confArray)
    {
        if (!$confArray instanceof \ArrayAccess) {
            return $this;
        }

        foreach ($confArray as $key => $value) {
            if ($value instanceof \ArrayAccess) {
                // hodnoty definovane pomoci vnorenych tagu spoji do jednoho textu
                $newVal = '';
                foreach ($value as $valA) {
                    if (isset($valA['#text'])) {
                        $newVal .= ($newVal ? "\n" : '') . $valA['#text'];
                    }
                }

                $value = $newVal;
            }

            $this ->loadConfigurationItem($key, $value);
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getId()
    {
        return $this->id ?: $this ->sqlFieldName;
    }


    /**
     * Vraci true, pokud se jedna o ciselna data
     * @return bool
     */
    public function isNumberFormat()
    {
        switch ($this ->format) {
            case 'int' :
            case 'kc' :
            case 'curr' :
            case 'float' :
            case 'number0' :
            case 'number1' :
            case 'number_1' :
            case 'number2' :
            case 'number_2' :
            case 'hodiny' :
            case 'minuty' :
            case 'sekundy' :
                return true;
        }

        return false;
    }


    function getFieldClass()
    {
        $class = $this ->className ?: '';

        if ($this ->align) {
            $class .= ($class ? ' ' : '') . 'align-' . $this ->align;
        }

        if (!$this ->wrap) {
            $class .= ($class ? ' ' : '') . 'no-wrap';
        }

        return $class;
    }


    /**
     * Vraci class pro bunku hlavicky
     * @param int $sort     Priznak, ze je seznam podle tohoto pole serazen
     * @return string
     */
    function getHeaderClass($sort = 0)
    {
        $class = $this ->getFieldClass();

        if ($sort > 0) {
            $class .= ($class ? ' ' : '') . 'sorted';
        } else if ($sort < 0) {
            $class .= ($class ? ' ' : '') . 'sorteddesc';
        }

        return $class;
    }


    /**
     * @param $value
     * @param $rowNumber
     * @param $recordId
     * @param $rowData
     * @return string
     */
    function getDataCellClass($value, $rowNumber, $recordId, $rowData)
    {
        $result = $this ->getFieldClass();

        if ($this ->isNumberFormat()  &&  $value < 0) {
            $result .= ($result ? ' ' : '') . 'minus';
        }

        return $result;
    }


    function getFooterClass()
    {
        return $this ->getFieldClass();
    }


    /**
     * @param int $fieldIndex
     * @param int $sortField
     * @param string $url
     * @return string
     */
    function getHeaderText($fieldIndex, $sortField, $url = null)
    {
        return $this ->header;
    }


    /**
     * @param int $fieldIndex
     * @param int $sortField
     * @param string $url
     * @return string
     */
    function getHeader($fieldIndex, $sortField, $url = null)
    {
        $sort = 0;
        if ($sortField == $fieldIndex + 1) {
            $sort = 1;
        } else if ($sortField == -$fieldIndex - 1) {
            $sort = -1;
        }

        $class = $this ->getHeaderClass($sort);
        $classStr = $class ? " class='{$class}' " : '';

        switch ($this ->type) {
            case self::FIELD_TYPE_HIDDEN :
                return '';

            case self::FIELD_TYPE_LINE :
                return "<th $classStr" . ($this ->code ? " data-code='{$this ->code}'" : '') . "></th>";
        }


        $result = '<th' . $classStr;

        if ($this ->code) {
            $result .= " data-code='{$this ->code}'";
        }

        if ((int)$this->headerColSpan > 1) {
            $result .= ' colspan="' . $this ->headerColSpan . '"';
        }

        $result .= '>';

        if ($this ->ordering  &&  $url) {
            if ($this ->sqlFieldName || $this ->sortSQL) {
                $result .= '<a href="' . StringUtils::concatenateHtmlParams($url,
                        'sort=' . ($fieldIndex + 1 == abs($sortField) ? -$sortField : ($fieldIndex + 1))) .
                    '">';
            }

            $result .= $this ->getHeaderText($fieldIndex, $sortField, $url);

            if ($this ->sqlFieldName || $this ->sortSQL) {
                $result .= '</a>';
            }
        } else {
            $result .= $this ->header;
        }

        if ($sort > 0) {
            $result .= '<i class="inline-glyph fa glyph-sort-up"></i>';
        } else if ($sort < 0) {
            $result .= '<i class="inline-glyph fa glyph-sort-down"></i>';
        }

        $result .= '</th>';

        return $result;
    }


    /**
     * @param int $fieldIndex
     * @param string $url
     * @return string
     */
    function getFooterText($fieldIndex, $url = null)
    {
        return $this ->footer;
    }


    /**
     * @param int $fieldIndex
     * @param null $url
     * @return string
     */
    function getFooter($fieldIndex, $url = null)
    {
        if ($this ->type == self::FIELD_TYPE_HIDDEN) {
            return '';
        }

        $class = $this ->getFieldClass();

        $result = '<td class="browserfooter ' . ($class ?: '') . '"';
        if ( (int)$this ->footerColSpan > 1) {
            $result .= ' colspan="' . (int)$this ->footerColSpan . '"';
        }

        $result .= '>';

        return $result . $this ->getFooterText($fieldIndex, $url) . '</td>';
    }


    /**
     * @param string $text
     * @param mixed $recordId
     * @return string
     */
    function getLink($text, $recordId)
    {
        $result = '';

        if ($this ->link) {
            $recordStr = substr($this ->link, -1) == '='
                ? ''
                : '&record=';


            $attributesStr = $this ->linkAttributes
                ? GuiUtils::getAttributesHtml($this ->linkAttributes)
                : '';

            $result .=
                '<a href="' . $this ->link.
                (($recordId != '') ? $recordStr . $recordId : '') .
                '" ' . $attributesStr . '>';
        }

        $result .= $text;

        if ($this ->link) {
            $result .= '</a>';
        }

        return $result;
    }


    /**
     * Funkce urcuje, jestli ma byt pole pro zadanou hodnotu zobrazeno
     * @param $value
     * @param $rowData
     * @return bool
     */
    function isValueVisible($value, $rowData)
    {
        if (!isset($this ->filterValue)) {
            return true;
        }

        if (is_callable($this ->filterValue)) {
            $func = $this ->filterValue;
            return $func($value, $rowData);
        }

        if ($this ->filterValue === true) {
            return (bool)$value;
        }

        if ($this ->filterValue === false) {
            return !(bool)$value;
        }

        return $value == $this ->filterValue;
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!$this ->isValueVisible($value, $rowData)) {
            return '';
        }

        $text2 = (isset($this ->sqlFieldIndex2)  &&  isset($rowData[$this ->sqlFieldIndex2])  &&  $this ->sqlFieldIndex2 !== ''  &&  $rowData[$this ->sqlFieldIndex2] !== '')
            ? ' (' . StringUtils::htmlTextConvert(
                $this ->translateText ? TextManager::_($rowData[$this ->sqlFieldIndex2]) : $rowData[$this ->sqlFieldIndex2]) .
            ')'
            : '';

        $translationIndex = isset($this ->translationValueIndex) ? $this ->translationValueIndex : $this ->sqlFieldIndex;
        if ($translationIndex < 0  &&  $rowData) {
            $translationIndex = count($rowData) + $translationIndex;
        }
        if ($this ->translationPrefix && isset($rowData[$translationIndex])  &&  $rowData[$translationIndex] !== '') {
            $value = TextManager::_($this ->translationPrefix . $rowData[$translationIndex], $value);
//            if (isset($translation)) {
//                $value = $translation;
//            }
        } else if ($this ->translateText  &&  $value) {
            $value = TextManager::_($value);
        }

        switch ($this ->type) {
            case self::FIELD_TYPE_LINE :
                return ($rowNumber > 0)
                    ? $rowNumber
                    : '';

            case self::FIELD_TYPE_DEFAULT :
                return $this ->getLink(
                    (($this ->htmlConvert ||  $this ->format) ? DBUtils::getFormatedValue($this ->database, $this ->format, $value) : $value) . $text2,
                    $recordId);

            case self::FIELD_TYPE_TEXT :
                return $this ->getLink($this ->text . $text2, $recordId);

            case self::FIELD_TYPE_URL :
                if (!$value) {
                    return '';
                }
                return
                    '<a href="' . $value . '" ' . GuiUtils::getAttributesHtml($this ->linkAttributes) . '>' .
                    ($this ->text
                        ? ($this ->text === 'IMG'
                            ? '<i class="inline-glyph fa glyph-link"></i>'
                            : $this ->text
                        )
                        : $value
                    ) .
                    '</a>' .
                    $text2;

            case self::FIELD_TYPE_SELECT :
                return isset($value)
                    ? $this ->getLink($this ->options[$value] . $text2, $recordId)
                    : '';                
        }

        return $text2;
    }


    function getHtmlTitle($rowNumber, $recordId, $rowData)
    {
        if (isset($this ->titleFieldIndex)  &&  isset($rowData[$this ->titleFieldIndex])) {
            $title = ($this ->titlePrefix ?: '') . $rowData[$this ->titleFieldIndex];
        } else {
            $title = null;
        }

        if ($this ->titleTranslationPrefix) {
            $translationIndex = isset($this->translationValueIndex) ? $this->translationValueIndex : $this->titleFieldIndex;

            if (isset($rowData[$translationIndex])  &&  $rowData[$translationIndex] !== '') {
                return TextManager::_($this ->translationPrefix . $rowData[$translationIndex], $title);
            }
        }

        return $title;
    }


    function getAttribute($name, $rowData, $index)
    {
        return $rowData && isset($rowData[$index])
            ? $rowData[$index]
            : null;
    }


    function getAttributes($rowNumber, $recordId, $rowData)
    {
        $title = $this ->getHtmlTitle($rowNumber, $recordId, $rowData);
        $attrsStr = $title
            ? ' title="' . StringUtils::htmlTextConvert($title) . '"'
            : '';

        if ($this ->attributeIndexes) {
            foreach ($this ->attributeIndexes as $attrName => $index) {
                $value = $this ->getAttribute($attrName, $rowData, $index);

                if (isset($value)) {
                    $attrsStr .=
                        ($attrsStr ? ' ' : '') .
                        $attrName . '="' . StringUtils::htmlTextConvert($value) . '"';
                }
            }
        }

        return $attrsStr;
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array  $rowData
     * @return string
     */
    function getFieldCellText($value, $rowNumber, $recordId, $rowData)
    {
        $class = $this ->getDataCellClass($value, $rowNumber, $recordId, $rowData);
        $classStr = $class ? " class='{$class}' " : '';

        $attrsStr = $this ->getAttributes($rowNumber, $recordId, $rowData);

        switch ($this ->type) {
            case self::FIELD_TYPE_HIDDEN :
                return '';

            case self::FIELD_TYPE_LINE :
                if ($rowNumber > 0) {
                    return "<td $classStr $attrsStr>$rowNumber</td>";
                }
                return "<td $classStr $attrsStr></td>";


            case self::FIELD_TYPE_DEFAULT :
            case self::FIELD_TYPE_TEXT :
            case self::FIELD_TYPE_SELECT :
            default :
                return
                    '<td' . $classStr . $attrsStr .
                    ($this ->style ? ' style="' . $this ->style . '"' : '') .
                    (($this ->rowSpan  &&  (int)$this ->rowSpan > 1) ? ' rowspan="' . (int)$this ->rowSpan . '"' : '') .
                    '>' .
                    $this ->getViewText($value, $rowNumber, $recordId, $rowData) .
                    '</td>';
        }
    }

}
