<?php
/**
 * stanislav.elbl, 21.02.2021
 */

namespace Ron\Controls;

use Ron\DB\Database;
use Ron\DB\Parameters;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\StringUtils;

class Option
{
    var $key;
    var $value;

    var $title;
    var $cssClass;

    /**
     * Asociativni pole dalsich atributu (napr. data)
     * @var array
     */
    var $params = [];

    function __construct($key, $value)
    {
        $this ->key = $key;
        $this ->value = $value;
    }


    function getJson()
    {
        $result = [
            'key' => StringUtils::jsonText($this ->key),
            'value' => StringUtils::jsonText($this ->value)
        ];

        if ($this ->cssClass) {
            $result['cssClass'] = $this ->cssClass;
        }

        if ($this ->title) {
            $result['title'] = StringUtils::jsonText($this ->title);
        }

        foreach ($this ->params as $paramName => $paramValue) {
            $result[$paramName] = StringUtils::jsonText($paramValue);
        }

        return $result;
    }


    public static function createItem($row, $keyIndex = 0, $captionIndex = 1, $titleIndex = null, $cssClassIndex = null)
    {
        $option = new Option($row[$keyIndex], $row[$captionIndex]);

        if (isset($titleIndex)) $option ->title = $row[$titleIndex];
        if (isset($cssClassIndex)) $option ->cssClass = $row[$cssClassIndex];

        return $option;
    }


    /**
     * Nacte polozky ze zadaneho dotazu.
     * @param Database $database
     * @param string|SqlStatement $sql
     * @param Parameters $sqlParams
     * @param int $keyIndex Index pole s klicem v sql dotazu
     * @param int $captionIndex Index pole s hodnotou v sql dotazu
     * @param null $emptyValue
//     * @param int $titleIndex Index pole s html titulkem
//     * @param int $cssClassIndex Index pole s css tridou
//     * @param array $attrIndexes Asociativni pole indexu poli, ktere se maji zapsat do params (jmeno parametru => index)
//     * @param mixed[] $preferredValues Pole "preferovanych" hodnot - nactou se na zacatek (mimo poradi z sql)
//     * @param callable $filterFunction  Funkce, ktera slouzi pro odfiltrovani nactenych radku. Pokud je zadana, tak se polozka do seznamu prida jen v pripade, ze funkce vrati true
     * @return Option[]
     * @throws DBException
     */
    public static function loadSQL($database, $sql, $sqlParams, $keyIndex = 0, $captionIndex = 1, $emptyValue = null) //, $titleIndex = null, $cssClassIndex = null, $attrIndexes = null, $preferredValues = null, $filterFunction = null)
    {
        $result = [];

        if (isset($emptyValue)) {
            // prida polozku pro "emptyValue"
            $result[] = new Option('', $emptyValue);
        }

        $cursor = $database ->getSqlResult($sql, $sqlParams);

        while ($row = $cursor ->fetch()) {
                $result[] = static::createItem($row, $keyIndex, $captionIndex);
        }

        $cursor ->close();

        return $result;
    }


    /**
     * @param Database $database
     * @param string|SqlStatement   $sql
     * @param Parameters    $sqlParams
     * @param ICreateItem   $createItemInterface
     * @return array
     */
    public static function loadSQLCustomCreate($database, $sql, $sqlParams, $createItemInterface) // , $emptyValue = false
    {
        $result = [];

//        if ($emptyValue) {
//            $result[] = $createItemInterface ->createItem(null);
//        }

        $cursor = $database ->getSqlResult($sql, $sqlParams);

        while ($row = $cursor ->fetch()) {
            $result[] = $createItemInterface ->createItem($row);
        }

        $cursor ->close();

        return $result;
    }
}
