<?php
/**
 * Roman.Szablatura RON Software 27.3.2017
 */

namespace RonPortal\Common;

use Exception;
use Ron\Controls\BrowserField;
use Ron\DB\DBException;
use Ron\Controls\Option;
use Ron\Controls\DateInput;
use Ron\Controls\ComboBox;
use Ron\DB\SqlStatement;
use Ron\DB\Database;
use Ron\DateUtils;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;


/**
 * Class NavstevyFilter
 */
class NavstevyFilter extends RonPortalFilterForm
{
    /** @var  PravaNaOsoby $prava */
    public $prava;

    /** @var int    0 = ocekavane, 1 = pritomni, 2 = od data */
    public $omezeniNavstev = 2;

    /** @var int */
    public $datumOd;
    /** @var int */
    public $datumDo;
    /** @var int */
    public $pocetDnu = 1;

    public $omezeniVratnice = 1; // 0=vsechny, 1=pouze moje

    public $jenTypNavstevy = 0;
    public $typNavstevy = 0;

    public $jenPrijmeniNavstevy = 0;
    public $prijmeniNavstevy = null;

    public $jenNavstivenaOsoba = 0;
    public $navstivenaOsoba = null;

    public $jenFirma = 0;
    public $firma = null;

    public $jenDuvod = 0;
    public $duvod = null;

    public $jenVozidlo = 0;
    public $sVozidlem = 0; // bez vozidla/s vozidlem

    public $filtrovatSchvaleni = 0;
    public $schvalene = 0;

    public $jenMedium = 0;
    public $kodMedia = null;

    public $zobrazitUzivatelskePoznamky = 0;

    /**
     * NavstevyFilter constructor.
     * @param Database $database
     * @param string $action
     * @param bool $useGet
     */
    public function __construct(Database $database, $action, $useGet)
    {
        parent::__construct($database, $action, $useGet);

        $this->prava = Prava::vratPrava('navstevy');
        Prava::nastavObdobiProPrava(time(), time());

        $this->f_formaction = '?menuid=navstevy&';
        $this->f_classname = 'filtercontainer leftcaptions';

        //Nastaveni timestamp (pokud je datum ve spatnem formatu nebo neni v session nebo neni, nastavi se na aktu. datum)
//        if (isset($_POST['datum'])){
//            try {
//                $this->timestamp = DateUtils::dateStringToTimestamp($_POST['datum']);
//            } catch(Exception $e) {
//                MessageManager::addErrorText( 'Bad_time_format' );
//                $this->timestamp = time();
//            }
//        } else {
//            if (isset($_SESSION['datum'])) {
//                $this->timestamp = $_SESSION['datum'];
//            } else {
//                $this->timestamp = time();
//            }
//        }

//        if (isset($_SESSION['navstevy_pocetdnu'])) {
//            $this ->pocetDnu = $_SESSION['navstevy_pocetdnu'];
//        }

//        $_SESSION['datum'] = DateUtils::startOfTheDay($this->timestamp);
//        $_SESSION['datumdodata'] = ((DateUtils::incDay($_SESSION['datum'], $this ->pocetDnu)) - 1);
    }

    /**
     * @param $pocetDni
     * @return string
     */
    private function textTitulkuZaznamyOd($pocetDni)
    {
        switch ($pocetDni){
            case 1:
                $titulek = TextManager::_('1_den');
                break;

            case 10:
                $titulek = TextManager::_('10_dni');
                break;

            case 20:
                $titulek = TextManager::_('20_dni');
                break;

            case 31:
                $titulek = TextManager::_('31_dni');
                break;

            default:
                $titulek = "";
        }
        return $titulek;
    }

    function renderOmezeniNavstev()
    {
        echo '<div class="filterrow">';
        echo
            '<span class="filtercaption">' .
            // jen ocekavane
            '<label class="margin-right-2">' .
            "<input type='radio' class='clickAutoSubmit' name='omezeniNavstev' value='0' " . ($this ->omezeniNavstev == 0 ? 'checked="checked"' : "") . '> ' .
            TextManager::_('jenOcekavany') .
            '</label>' .
            // pritomne
            '<label>' .
            "<input type='radio' class='clickAutoSubmit' name='omezeniNavstev' value='1' " . ($this ->omezeniNavstev == 1 ? 'checked="checked"' : "") . '> ' .
            TextManager::_('pritomni') .
            '</label>' .
            '</span>';

        //Combo volby dni a datumu
        $zvolenaDoba =
            TextManager::_('zvolena_doba') . ': ' .
            date('j.n.Y', $this ->datumOd) . ' - ' . date('j.n.Y', $this ->datumDo);

        echo "<span title='$zvolenaDoba'>";

        echo
            '<label class="zaznamy_od">' .
            "<input type='radio' class='clickAutoSubmit' name='omezeniNavstev' value='2' " .
            ($this ->omezeniNavstev == 2 ? 'checked="checked"' : "") . '> ' .
            TextManager::_('zobrazit_navstevy_za') .
            '</label> ';

        if ($this ->omezeniNavstev == 2) {
            $combo = new ComboBox('vyberpocetdnu', [
                    1 => TextManager::_('1_den'),
                    10 => TextManager::_('10_dni'),
                    20 => TextManager::_('20_dni'),
                    31 => TextManager::_('31_dni')]
            );
            $combo->className = 'vyber_dni_combo adsfilterforminput_kod';
            $combo->htmlParams = 'data-ron-autosubmit="1"';
            $combo->selectedOption = $combo->findOption($this ->pocetDnu ? $this ->pocetDnu : 1);
            $combo->render();

            $pouzeDnesniDen = TextManager::_('pouze_dnesni_den');
            echo
                "<span class='margin-left-2' title='$pouzeDnesniDen'>" .
                TextManager::_('Od') . ' ';
            DateInput::renderDateSelect('datum', date('j.n.Y', $this->datumOd), true);
            echo
            '</span>';
        } else {

            $text =
                "<input type='text' size='10' class='input_pocet_dni' disabled='disabled' value='" . $this->textTitulkuZaznamyOd($this ->pocetDnu) . "'/>" .
                ' ' . TextManager::_('od') . ' ' .
                "<input type='text' size='10' class='input_pocet_dni' disabled='disabled' value='" . date('j.n.Y', $this ->datumOd) . "'/>";
            echo $text;
        }
        echo '</span>';

        echo '</div>';


        echo
            '<div class="filterrow" id="filterrow_omezenivratnice">' .
            '<span class="filtercaption">' .
            // vsechny vratnice
            '<label class="margin-right-2">' .
            "<input type='radio' class='clickAutoSubmit' name='omezeniVratnice' value='0' " . (!$this ->omezeniVratnice ? 'checked="checked"' : '') . '> ' .
            TextManager::_('vsechnyVratnice') .
            '</label>' .
            // jen aktualni vratnice
            '<label>' .
            "<input type='radio' class='clickAutoSubmit' name='omezeniVratnice' value='1' " . ($this ->omezeniVratnice? 'checked="checked"' : '') . '> ' .
            TextManager::_('pouzeMojeVratnice') .
            '</label>' .
            '</span>' .
            '</div>';
    }

    function renderTypNavstevy()
    {
        echo '<div class="filterrow" id="filterrow_typnavstevy">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenTypNavstevy', TextManager::_('podle_typu_navstevy'), $this ->jenTypNavstevy,
            ['class' => 'clickAutoSubmit', 'id' => 'jen_typ_navstevy_checkbox']);
        echo '</span>';

        $combo = new ComboBox('typNavstevy', [
            new Option(0, TextManager::_('cizi')),
            new Option(1, TextManager::_('vlastni'))
        ]);
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_typ_navstevy_checkbox'];
        $combo->selectedOption = $combo->findOption($this ->typNavstevy); // $_SESSION['typNavstevy'] != '' ? (int)$_SESSION['typNavstevy'] : 0);
        $combo->showCode = 0;
        $combo->render();
        echo '</div>';
    }

    /**
     * @throws DBException
     */
    function renderDuvodNavstevy()
    {
        echo '<div class="filterrow" id="filterrow_duvodnavstevy">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenDuvodNavstevy', TextManager::_('podle_duvodu_navstevy'), $this ->jenDuvod,
            ['class' => 'clickAutoSubmit', 'id' => 'jen_duvod_navstevy_checkbox']);
        echo '</span>';

        $combo = new ComboBox('duvodNavstevy');
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_duvod_navstevy_checkbox'];
        $combo->loadData($this->database,
            'SELECT Kod, Popis FROM DuvodNavstevy ORDER BY Popis',
            $this ->duvod);
        $combo->render();

        echo '</div>';
    }

    /**
     * @throws DBException
     */
    function renderOsobaNavstevy()
    {
        echo '<div class="filterrow" id="filterrow_osobanavstevy">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenOsoba', TextManager::_('podle_navstivene_osoby'), $this ->jenNavstivenaOsoba,
            ['class' => 'clickAutoSubmit', 'id' => 'jen_navstivena_osoba_checkbox']);
        echo '</span>';

        $params = null;
        if ($this ->omezeniVratnice  &&  RonPortalSession::getValue('rozdelenivratnice') != '') {
            $params = $this->database->createParameters();
            $sql =
                'SELECT DISTINCT JmenoNavstiveneOsoby, JmenoNavstiveneOsoby Jmeno FROM Navsteva' .
                ' WHERE Navsteva.Rozdeleni_Vratnice = ' . $params->addParameter(RonPortalSession::getValue('rozdelenivratnice')) .
                ' ORDER BY JmenoNavstiveneOsoby';
        } else {
            $sql =
                'SELECT DISTINCT JmenoNavstiveneOsoby, JmenoNavstiveneOsoby Jmeno FROM Navsteva ORDER BY jmenoNavstiveneOsoby';
        }

        $combo = new ComboBox('osoba');
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_navstivena_osoba_checkbox'];
        $combo->showCode = 0;
        $combo->loadData($this->database, $sql, $this ->navstivenaOsoba, $params);
        $combo->render();
        echo '</div>';
    }

    /**
     * @throws DBException
     */
    function renderFirma()
    {
        echo '<div class="filterrow"  id="filterrow_firmanavstevy">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenFirma', TextManager::_('podle_firmy'), $this ->jenFirma,
            ['class' => 'clickAutoSubmit', 'id' => 'jen_firma_checkbox']);
        echo '</span>';

        $params = null;
        if ($this ->omezeniVratnice  &&  RonPortalSession::getValue('rozdelenivratnice') != '') {
            $params = $this->database->createParameters();
            $sql =
                'SELECT DISTINCT Firma FROM Navsteva' .
                ' WHERE Navsteva.Rozdeleni_Vratnice = ' . $params->addParameter(RonPortalSession::getValue('rozdelenivratnice')) .
                ' ORDER BY Firma';
        } else {
            $sql =
                'SELECT DISTINCT Firma FROM Navsteva ORDER BY Firma';
        }
        $combo = new ComboBox('firma');
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_firma_checkbox'];
        $combo->showCode = 0;
        $combo ->captionIndex = 0;
        $combo->loadData($this->database, $sql, $this ->firma, $params);
        $combo->render();
        echo '</div>';
    }


    /**
     * @throws Exception
     */
    function renderSchvaleniNavstevy()
    {
        echo '<div class="filterrow" id="filterrow_schvaleninavstevy">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenSchvaleno', TextManager::_('podle_schvaleni'),
            $this ->filtrovatSchvaleni,
            ['id' => 'checkbox_jen_schvaleno'], 'clickAutoSubmit');
        echo '</span>';

        $combo = new ComboBox(
            'schvaleniNavstevy',
            [0 => TextManager::_('navsteva_neschvalena'), 1 => TextManager::_('navsteva_schvalena')]
        );
        $combo->className = 'adsfilterforminput_full';
        //$combo->htmlParams = 'onChange="if (jenSchvaleno.checked) submit();"';
        $combo->htmlParams = 'data-ron-autosubmit="1" data-ron-autosubmit-check="#checkbox_jen_schvaleno"';
        $combo->selectedOption = $combo->findOption($this ->schvalene ? 1 : 0);
        $combo->render();
        echo '</div>';
    }

    /**
     * @throws DBException
     */
    function renderPrijmeni()
    {
        echo '<div class="filterrow">';

        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenPrijmeni', TextManager::_('podle_prijmeni'),
            $this ->jenPrijmeniNavstevy,
            ['id' => 'checkbox_jen_prijmeni'], 'clickAutoSubmit');
        echo '</span>';

        $params = null;
        if ($this ->omezeniVratnice  &&  RonPortalSession::getValue('rozdelenivratnice') != '') {
            $params = $this->database->createParameters();
            $sql =
                'SELECT DISTINCT prijmeni, prijmeni p FROM Navsteva' .
                ' WHERE Navsteva.Rozdeleni_Vratnice = ' . $params->addParameter(RonPortalSession::getValue('rozdelenivratnice')) .
                ' ORDER BY p';
        } else {
            $sql =
                'SELECT DISTINCT prijmeni, prijmeni p FROM Navsteva ORDER BY p';
        }
        $combo = new ComboBox('prijmeni');
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = 'data-ron-autosubmit="1" data-ron-autosubmit-check="#checkbox_jen_prijmeni"';
        //$combo->htmlParams = 'onChange="if (jenPrijmeni.checked) submit();"';
        $combo->showCode = 0;
        $combo->loadData($this->database, $sql, $this ->prijmeniNavstevy, $params);
        $combo->render();

        echo '</div>';
    }


    /**
     * @throws DBException
     */
    function renderMedium()
    {
        echo '<div class="filterrow">';
        $titulekFiltruZapujcenehoMedia = TextManager::_('filtr_zapujceneho_media');
        echo "<span class='filtercaption' title='$titulekFiltruZapujcenehoMedia'>";
        GuiUtils::renderCheckbox('jenMedium', TextManager::_('vyhledat_zapujcena_media'), $this ->jenMedium,
            ['id' => 'jen_medium_checkbox'], 'clickAutoSubmit');
        echo '</span>';

        $params = $this->database->createParameters();

        $sql =
            'SELECT DISTINCT Karta.Kod, Karta.OznaceniMedia' .
            ' FROM Navsteva LEFT JOIN PrirazeniKarty' .
            ' ON (Navsteva.osobaRC = PrirazeniKarty.RC' .
            '  AND Navsteva.osobniCislo = PrirazeniKarty.osobniCislo' .
            '  AND Navsteva.datumNastupu = PrirazeniKarty.datumNastupu)' .
            ' LEFT JOIN Karta ON (Karta.Kod = PrirazeniKarty.kodKarty)' .
            ' WHERE Navsteva.Prichod IS NOT NULL' .
            ' AND Navsteva.Odchod IS NULL AND Karta.Kod IS NOT NULL';

        if ($this ->omezeniVratnice  &&  RonPortalSession::getValue('rozdelenivratnice') != '') {
            $sql .= ' AND Navsteva.Rozdeleni_Vratnice = ' . $params->addParameter(RonPortalSession::getValue('rozdelenivratnice'));
        }

        $sql .= ' ORDER BY Karta.OznaceniMedia';

        $combo = new ComboBox('medium');
        $combo->className = 'adsfilterforminput_full';
        $combo->emptyRow = TextManager::_("nevybrano");
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_medium_checkbox'];
        $combo->showCode = 0;
        $combo->loadData($this->database, $sql, $this ->kodMedia, $params);
        $combo->render();
        echo '</div>';
    }


    public function renderUzivatelskePolozkyVPoznamceBrowseru()
    {
        echo '<div class="filterrow">';
        echo '<label>';
        GuiUtils::renderCheckbox('uzivatelskePoznamky', TextManager::_('navstevyUzivatelskePoznamky'),
            $this ->zobrazitUzivatelskePoznamky,
            '', 'clickAutoSubmit');
        echo '</label>';
        echo '</div>';
    }

    function renderVozidloNavstevy()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenVozidloNavstevy', TextManager::_('podle_typu_vozidla'), $this ->jenVozidlo,
            ['id' => 'jen_vozidlo_navstevy_checkbox'], 'clickAutoSubmit');
        echo '</span>';

        $combo = new ComboBox('typVozidla', [0 => TextManager::_("bez_vozidla"), 1 => TextManager::_("s_vozidlem")]);
        $combo->className = 'adsfilterforminput_full';
        $combo->htmlParams = ['data-ron-autosubmit' => '1', 'data-ron-autosubmit-check' => '#jen_vozidlo_navstevy_checkbox'];
        $combo->selectedOption = $combo->findOption($this ->sVozidlem ? 1 : 0);
        $combo->render();

        echo '</div>';
    }

    function renderZapisNoveNavstevy()
    {
        echo '<ul class="linkslist">';

        echo "<li class='selectedlink'><a href='?menuid=navstevy&formaction=new&ocekavana=1'>" . TextManager::_('ocekavana_navsteva') . "</a></li>";

        if (!$this ->prava ->priznak) { // zapis nove nasvtevy se nezobrazuje, pokud ma pravo jen na ocekavane navstevy
            echo "<li class='selectedlink'><a href='?menuid=navstevy&formaction=new&ocekavana=0'>" . TextManager::_('zapis_nove_navstevy') . "</a></li>";
        }

        echo "<li class='selectedlink'><a id='najit_navstevu_pomoci_id_medium'>" . TextManager::_('najit_navstevu_pomoci_id_medium') . "</a></li>";

        echo "</ul>";
    }

    private function loadTypNavstevy()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenTypNavstevy = isset($_POST['jenTypNavstevy']) ? (int)$_POST['jenTypNavstevy'] : 0;
            $this ->typNavstevy = (int)$_POST['typNavstevy'];

            $_SESSION['jenTypNavstevy'] = $this ->jenTypNavstevy;
            $_SESSION['typNavstevy'] = $this ->typNavstevy;
        } else {
            $this ->jenTypNavstevy = (int)RonPortalSession::getValue('jenTypNavstevy');
            $this ->typNavstevy = RonPortalSession::getValue('typNavstevy');
        }
    }

    private function loadOsobaNavstevy()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenNavstivenaOsoba = isset($_POST['jenOsoba']) ? (int)$_POST['jenOsoba'] : 0;
            $this ->navstivenaOsoba = $_POST['osoba'];
            $_SESSION['jenNavstivenaOsoba'] = $this ->jenNavstivenaOsoba;
            $_SESSION['navstivenaOsoba'] = $this ->navstivenaOsoba;
        } else {
            $this ->jenNavstivenaOsoba = (int)RonPortalSession::getValue('jenNavstivenaOsoba');
            $this ->navstivenaOsoba = RonPortalSession::getValue('navstivenaOsoba');
        }
    }

    private function loadUzivatelskePoznamky()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->zobrazitUzivatelskePoznamky = isset($_POST['uzivatelskePoznamky']) ? (int)$_POST['uzivatelskePoznamky'] : 0;

            $_SESSION['uzivatelskePoznamkyNavstev'] = $this ->zobrazitUzivatelskePoznamky;
        } else {
            $this ->zobrazitUzivatelskePoznamky = (int)RonPortalSession::getValue('uzivatelskePoznamkyNavstev');
        }
    }

    private function loadVozidloNavstevy()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenVozidlo = isset($_POST['jenVozidloNavstevy']) ? (int)$_POST['jenVozidloNavstevy'] : 0;
            $this ->sVozidlem = $_POST['typVozidla'] ? 1 : 0;

            $_SESSION['jenVozidloNavstevy'] = $this ->jenVozidlo;
            $_SESSION['vozidloNavstevy'] = $this ->sVozidlem;
        } else {
            $this ->jenVozidlo = (int)RonPortalSession::getValue('jenVozidloNavstevy');
            $this ->sVozidlem = (int)RonPortalSession::getValue('vozidloNavstevy');
        }
    }

    private function loadDuvodNavstevy()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenDuvod = isset($_POST['jenDuvodNavstevy']) && (int)$_POST['jenDuvodNavstevy'];
            $this ->duvod = $_POST['duvodNavstevy'];

            $_SESSION['jenDuvodNavstevy'] = $this ->jenDuvod;
            $_SESSION['duvodNavstevy'] = $this ->duvod;
        } else {
            $this ->jenDuvod = (int)RonPortalSession::getValue('jenDuvodNavstevy');
            $this ->duvod = RonPortalSession::getValue('duvodNavstevy');
        }
    }

    private function loadFirma()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenFirma = isset($_POST['jenFirma']) ? (int)$_POST['jenFirma'] : 0;
            $this ->firma = $_POST['firma'];
            $_SESSION['jenFirmaNavstevy'] = $this ->jenFirma;
            $_SESSION['firmaNavstevy'] = $this ->firma;
        } else {
            $this ->jenFirma = (int)RonPortalSession::getValue('jenFirmaNavstevy');
            $this ->firma = RonPortalSession::getValue('firmaNavstevy');
        }
    }


    private function loadSchvaleniNavstevy()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->filtrovatSchvaleni = isset($_POST['jenSchvaleno']) && (int)$_POST['jenSchvaleno'];
            $this ->schvalene = (int)$_POST['schvaleniNavstevy'];

            $_SESSION['filtrovatSchvaleniNavstevy'] = $this ->filtrovatSchvaleni;
            $_SESSION['schvaleniNavstevy'] = $this ->schvalene;
        } else {
            $this ->filtrovatSchvaleni = (int)RonPortalSession::getValue('filtrovatSchvaleniNavstevy');
            $this ->schvalene = (int)RonPortalSession::getValue('schvaleniNavstevy');
        }
    }


    private function loadPrijmeni()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenPrijmeniNavstevy = (isset($_POST['jenPrijmeni']) && (int)$_POST['jenPrijmeni']) ? 1 : 0;
            $this ->prijmeniNavstevy = $_POST['prijmeni'];

            $_SESSION['jenPrijmeniNavstevy'] = $this ->jenPrijmeniNavstevy;
            $_SESSION['prijmeniNavstevy'] = $this ->prijmeniNavstevy;
        } else {
            $this ->jenPrijmeniNavstevy = (int)RonPortalSession::getValue('jenPrijmeniNavstevy');
            $this ->prijmeniNavstevy = RonPortalSession::getValue('prijmeniNavstevy');
        }
    }

    private function loadMedium()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->jenMedium = isset($_POST['jenMedium']) && (int)$_POST['jenMedium'];
            $this ->kodMedia = $_POST['medium'];

            $_SESSION['jenMediumNavstevy'] = $this ->jenMedium;
            $_SESSION['mediumNavstevy'] = $this ->kodMedia;
        } else {
            $this ->jenMedium = (int)RonPortalSession::getValue('jenMediumNavstevy');
            $this ->kodMedia = RonPortalSession::getValue('mediumNavstevy');
        }
    }


    private function loadOmezeniNavstev()
    {
        if (isset($_POST['omezeniNavstev'])) {
            $this ->omezeniNavstev = (int)$_POST['omezeniNavstev'];
            $_SESSION['omezeniNavstev'] = $this ->omezeniNavstev;
        } else if (isset($_SESSION['omezeniNavstev'])) {
            $this ->omezeniNavstev = $_SESSION['omezeniNavstev'];
        }

        if (isset($_POST['vyberpocetdnu'])  &&  $_POST['vyberpocetdnu'] != '') {
            $this ->pocetDnu = (int)$_POST['vyberpocetdnu'];
            $_SESSION['navstevy_pocetdnu'] = $this ->pocetDnu;
        } else if (isset($_SESSION['navstevy_pocetdnu'])) {
            $this ->pocetDnu = $_SESSION['navstevy_pocetdnu'];
        }

        if (isset($_POST['datum'])) {
            try{
                //V pripade ze se zada neexistujici den v mesici tak skript skoncil chybou, ze ktere se jen tak neda odejit - proto jsem toto osetril
                // a nastavuji v pripade chyby aktualni datum
                $this ->datumOd = DateUtils::dateStringToTimestamp($_POST['datum']);
            } catch (Exception $ex) {
                MessageManager::addErrorText( 'Bad_time_format' );
                $this ->datumOd = DateUtils::today();
            }
            $_SESSION['navstevy_datumod'] = $this ->datumOd;
        } else if (isset($_SESSION['navstevy_datumod'])) {
            $this ->datumOd = $_SESSION['navstevy_datumod'];
        } else {
            $this ->datumOd = DateUtils::today();
        }

        $this ->datumDo = DateUtils::incDay($this ->datumOd, $this->pocetDnu) - 1;

//        $_SESSION['datum'] = DateUtils::startOfTheDay($this->timestamp);
//        $_SESSION['datumdodata'] = ((DateUtils::incDay($_SESSION['datum'], $this->pocetDnu)) - 1);
    }


    private function loadOmezeniVratnice()
    {
        if (isset($_POST['adsfilterform'])) {
            $this ->omezeniVratnice = (int)$_POST['omezeniVratnice'];
            $_SESSION['omezeniVratnice'] = $this ->omezeniVratnice;
        } else if (isset($_SESSION['omezeniVratnice'])) {
            $this ->omezeniVratnice = (int)RonPortalSession::getValue('omezeniVratnice');
        }
    }

    function loadData()
    {
        $this->loadOmezeniVratnice();

        $this->loadOmezeniNavstev();
        $this->loadTypNavstevy();
        $this->loadOsobaNavstevy();
        $this->loadPrijmeni();
        $this->loadFirma();
        $this->loadSchvaleniNavstevy();
        $this->loadMedium();
        $this->loadDuvodNavstevy();
        $this->loadVozidloNavstevy();
        $this->loadUzivatelskePoznamky();

        parent::loadData();
    }


    /**
     * @throws DBException
     * @throws Exception
     */
    function renderFilters()
    {
        $this->renderOmezeniNavstev();
        parent::renderFilters();
        $this->renderOsobaNavstevy();
        $this->renderPrijmeni();
        $this->renderTypNavstevy();
        $this->renderFirma();
        $this->renderSchvaleniNavstevy();
        $this->renderMedium();
        $this->renderDuvodNavstevy();
        $this->renderVozidloNavstevy();
        $this->renderUzivatelskePolozkyVPoznamceBrowseru();
        $this->renderZapisNoveNavstevy();
    }
}


/**
 * Class TypNavstevy
 */
class TypNavstevy extends BrowserField
{

    /**
     * TypNavstevy constructor.
     * @param Database $database
     * @param $options
     */
    public function __construct($database, $options)
    {
        parent::__construct($database, $options);
        $this->header = TextManager::_('typ_navstevy');
        $this->ordering = 1;
        $this->align = 'center';
        $this->sortSQL = 'TypNavstevy, Navsteva.OcekavanyPrichod, prichod';
        $this->sortSQLDesc = 'TypNavstevy DESC, Navsteva.OcekavanyPrichod DESC, prichod DESC';
        $this->sqlFieldIndex = 1;
        $this->sqlFieldName = 'TypNavstevy';
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            '<a href="?menuid=navstevy&formaction=edit&record=' . (int)$rowData[0] . '" title="' . TextManager::_($rowData[1] ? 'vlastni' : 'cizi') . '">' .
            ($rowData[1] ? '<strong>Z</strong>' : '-->') .
            '</a>';
    }
}

/**
 * Class CasNavstevy
 */
class CasNavstevy extends BrowserField
{
    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return int|string
     * @throws DBException
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = parent::getViewText($value, $rowNumber, $recordId, $rowData);

        $time = $this->database->stringToTimestamp($rowData[$this->sqlFieldIndex]);
        if (DateUtils::startOfTheDay($time) == DateUtils::today()) {
            $result =
                '<strong>' . $result . '</strong>';
        }

        return $result;
    }
}


/**
 * Class PotvrzeniOdchoduNavstevyField
 */
class PotvrzeniOdchoduNavstevyField extends BrowserField
{
    var $lzeZapsatOdchod;

    /**
     * PotvrzeniPrijetiField constructor.
     * @param Database $database
     * @param array|null $options
     */
    public function __construct($database, $options)
    {
        parent::__construct($database, $options);
        $this->lzeZapsatOdchod = !Prava::vratPrava('navstevy') ->priznak;
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        // Jestlize je zadan prichod a odchod jeste ne
        if (!$rowData[$this ->sqlFieldIndex]  &&  $this ->lzeZapsatOdchod  &&  $rowData[14]) {
            return GuiUtils::changeLocationQuest(
                TextManager::_('vlozit_odchod_navstevy'), TextManager::_('opravdu_ukoncit_navstevu'),
                '?menuid=navstevy&action=potvrzeniodchodu&id=' . $rowData[0]);
        }

        return parent::getViewText($value, $rowNumber, $recordId, $rowData);
    }
}


/**
 * Class SchvaleniNavstevyField
 */
class SchvaleniNavstevyField extends BrowserField
{

    /** @var PravaNaOsoby $pravo_schvaleni */
    private $pravo_schvaleni;

    /**
     * PotvrzeniPrijetiField constructor.
     * @param Database $database
     * @param array|null $options
     * @param PravaNaOsoby $pravo_schvaleni
     */
    public function __construct($database, $options, $pravo_schvaleni)
    {
        parent::__construct($database, $options);
        $this->header = TextManager::_('navstevu_schvalil');
        $this->align = "center";
        $this->pravo_schvaleni = $pravo_schvaleni;
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = "";

        //Jestlize neschvaleno
        if (!$rowData[47]) {
            //
            if ($this->pravo_schvaleni->jsouNejakePrava() && $rowData[27]) {  // pokud je to ocekavana navsteva
                $result = GuiUtils::changeLocationQuest(TextManager::_('Schvalit'), TextManager::_('opravdu_schvalujete_navstevu'),
                    ' ?menuid=navstevy&action=schvaleninavstevy&id=' . $rowData[0]);
            }
        } else {
            $result = StringUtils::htmlTextConvert($rowData[47]) . " (" .StringUtils::format('datetime', $this->database->stringToTimestamp($rowData[48])) . ")";
        }
        return $result;
    }
}


/**
 * Class NavstevuSchvalilaOsoba
 */
class NavstevuSchvalilaOsoba extends BrowserField
{

    /** @var Database $database */
    public $database;

    /** @var PravaNaOsoby $pravo_schvaleni */
    private $pravo_schvaleni;


    /**
     * NavstevuSchvalilaOsoba constructor.
     * @param Database $database
     * @param PravaNaOsoby $pravo_schvaleni
     */
    public function __construct($database, $pravo_schvaleni)
    {
        parent::__construct($database);
        $this->header = TextManager::_('navstevu_schvalil');
        $this->database = $database;
        $this->pravo_schvaleni = $pravo_schvaleni;
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = "";

        //Jestlize neschvaleno
        if ($rowData[47] == "") {
            //
            $rcNavstiveneOsoby = $rowData[21];
            $maPravoNaOsobu = $this->pravo_schvaleni->lzeZobrazitRC($rcNavstiveneOsoby);
            if ($maPravoNaOsobu && $rowData[27]) {
                $result = GuiUtils::changeLocationQuest(TextManager::_('Schvalit'), TextManager::_('opravdu_schvalujete_navstevu'),
                    ' ?menuid=navstevy&action=schvaleninavstevy&id=' . $rowData[0] .
                    '&browser=1');
            }
        } else {
            $result = StringUtils::htmlTextConvert($rowData[47]) . " (" .StringUtils::format('datetime', $this->database->stringToTimestamp($rowData[48])) . ")";
        }
        return $result;
    }
}



/**
 * Class NavstevyBrowser
 */
class NavstevyBrowser extends RonPortalBrowser
{

    /** @var  PravaNaOsoby $prava */
    private $prava;

    /** @var  PravaNaOsoby $pravo_schvaleni */
    private $pravo_schvaleni;

    /**
     * NavstevyBrowser constructor.
     * @param Database $database
     * @throws Exception
     */
    public function __construct(Database $database)
    {
        parent::__construct($database, 'navstevy');
        $this->prava = Prava::vratPrava('navstevy');
        $this->pravo_schvaleni = Prava::vratPrava('navstevy_schvaleni');
        Prava::nastavObdobiProPrava(time(),time());

        $this->code = 'browsernavstevy';
        $this->tableId = 'browsernavstevy';
        //$this->browserUrl = "?menuid=navstevy&";

        $this->filterForm = new NavstevyFilter($database, null, null);
        $this->filterForm->loadData();

        $this->title = TextManager::_('navstevy') . ' ' .
            ($this ->filterForm ->omezeniVratnice == 1
                ? $this->rozdeleniVratnice($database)
               : (!$this ->filterForm ->omezeniVratnice ? TextManager::_('vsechnyVratnice') : '')
            );

        $this->sqlSelectPart =
            'Navsteva.id, TypNavstevy, Navsteva.kod, Navsteva.titul, Navsteva.prijmeni, Navsteva.jmeno, zamestnanecRC, zamestnanecOsobniCislo,' .   //0 - 7
            ' ZamestnanecDatumNastupu, ZamestnanecTypRozdeleni, ZamestnanecRozdeleni, Firma, ' .                                                    //8 - 11
            ' KodTypuRozdeleni_Firma, Rozdeleni_Firma, prichod, Navsteva.odchod, Navsteva.osobaRC, Navsteva.osobniCislo, Navsteva.datumNastupu,' .  //12 - 18
            ' PristeStejneMedium, Vozidlo, NavstivenaOsobaRC, JmenoNavstiveneOsoby, Doklad,' .                                                      //19 - 23
            $database ->castWideMemo('duvodNavstevy') . ',' .                                                                                       //24
            ' KodTypuRozdeleni, Rozdeleni, PredemOcekavanaNavsteva, Navsteva.OcekavanyPrichod, KodTypuRozdeleni_Vratnice, Rozdeleni_Vratnice,' .    //25 - 29
            ' Navsteva.Uzivatelska1, Navsteva.Uzivatelska2, Navsteva.Uzivatelska3, Navsteva.Uzivatelska4, Navsteva.Uzivatelska5,' .                 //30 - 35
            ' Navsteva.Uzivatelska6, Navsteva.Uzivatelska7, Navsteva.Uzivatelska8, Navsteva.Uzivatelska9, Navsteva.Uzivatelska10,' .                //36 - 40
            ' NavstivenaOsoba.Telefon,' .                                           // 41
            " COALESCE(Zapsal.Jmeno,'') {fn_concat()} ' ' {fn_concat()} COALESCE(Zapsal.Prijmeni,''), " .   // 42
            ' Karta.OznaceniMedia, PrichodZapsalRC, Karta.Kod,' .                   // 43 - 45

            ' (Select Rozdeleni.Popis FROM TypRozdeleni LEFT JOIN Rozdeleni ON (TypRozdeleni.Kod = Rozdeleni.KodTypuRozdeleni)' .
            '  WHERE TypRozdeleni.Kod = KodTypuRozdeleni_Vratnice AND Rozdeleni.Kod = Rozdeleni_Vratnice) AS Rozdeleni_vratnice_popis,' .           //46
            ' Navsteva.Schvalil, Navsteva.DT_Schvaleni, DuvodNavstevy.Popis';                                                                       //47..49

        $this->primaryField = 0;

        $this->sqlFromPart =
            'Navsteva LEFT JOIN Osoba NavstivenaOsoba ON (Navsteva.navstivenaOsobaRC = NavstivenaOsoba.RC) ' .
            ' LEFT JOIN Osoba Zapsal ON (Navsteva.prichodZapsalRC = Zapsal.RC)' .
            ' LEFT JOIN PrirazeniKarty' .
            '  ON (Navsteva.OsobaRC = PrirazeniKarty.RC) AND (Navsteva.OsobniCislo = PrirazeniKarty.OsobniCislo) AND (Navsteva.DatumNastupu = PrirazeniKarty.DatumNastupu)' .
            '  AND PrirazeniKarty.DatumPrideleni <= Navsteva.Prichod' .
            '  AND (PrirazeniKarty.DatumVraceni >= Navsteva.Prichod  OR  PrirazeniKarty.DatumVraceni IS NULL)' .
            ' LEFT JOIN Karta ON (Karta.Kod = PrirazeniKarty.kodKarty)' .
            ' LEFT JOIN S_AnoNe schvalenaNavsteva ON (Navsteva.Schvalil = PrirazeniKarty.kodKarty)' .
            ' LEFT JOIN DuvodNavstevy ON ( (DuvodNavstevy.Kod = Navsteva.duvodNavstevy2))';

        // Typ navstevy
        $this->addField( new TypNavstevy($database, null))
            ->setCode('col-typnavstevy');

        // Vratnice
        $this->addField()
            ->setSqlFieldName('Rozdeleni_vratnice_popis', 46) ->setHeaderText('vratnice')
            ->setCode('col-vratnice')
            ->setVisible(!$this ->filterForm ->omezeniVratnice);
        //->setVisible(!$_SESSION['omezeniVratnice']);

        // Duvod navstevy
        $this->addField()
            ->setSqlFieldName('DuvodNavstevy.Popis', 49) ->setHeaderText('duvod_navstevy')
            ->setCode('col-duvodnavstevy');

        //Ocekavany?
        $this->addField(BrowserField::FIELD_TYPE_SELECT)
            ->setSqlFieldName('Navsteva.PredemOcekavanaNavsteva', 27) ->setHeaderText('ocekavany') ->setOrdering(1)
            ->setCode('col-ocekavany')
            ->setOptions([0 => TextManager::_('Str_No'), 1 => TextManager::_('Str_Yes')])
            ->setAlign('center');

        //Navsteva.prijmeni
        $this->addField()
            ->setSqlFieldName('Navsteva.prijmeni', 4) ->setHeaderText('Prijmeni')
            ->setCode('col-prijmeni')
            ->setOrdering(1) ->setClassName('font-weight-bold')
            ->setLink('?menuid=navstevy&action=zaznam');

        //Navsteva.jmeno
        $this->addField()
            ->setSqlFieldName('Navsteva.jmeno', 5) ->setHeaderText('Jmeno')
            ->setCode('col-jmeno')
            ->setOrdering(1)
            ->setLink('?menuid=navstevy&action=zaznam');

        //Ocekavany prichod
        $this->addField( new CasNavstevy($database))
            ->setSqlFieldName('OcekavanyPrichod', 28) ->setHeaderText('ocekavany_datum') ->setFormat('weektimestamp')
            ->setCode('col-ocekavanyprichod')
            ->setOrdering(1)
            ->setLink('?menuid=navstevy&formaction=edit');

        //doklad
        $this->addField()
            ->setSqlFieldName('doklad', 23) ->setHeaderText('doklad')
            ->setCode('col-doklad');

        //vozidlo
        $this->addField()
            ->setSqlFieldName('vozidlo', 20) ->setHeaderText('vozidlo')
            ->setCode('col-vozidlo');

        //firma
        $this->addField()
            ->setSqlFieldName('firma', 11) ->setHeaderText('firma') ->setOrdering(1)
            ->setCode('col-firma');

        //OznaceniMedia
        $this->addField()
            ->setSqlFieldName('OznaceniMedia', 43) ->setHeaderText('oznaceni_media') ->setOrdering(1)
            ->setCode('col-oznacenimedia');

        //Prichod
        $this->addField( new CasNavstevy($database))
            ->setSqlFieldName('Prichod', 14) ->setHeaderText('prichod') ->setFormat('weektimestamp') ->setOrdering(1)
            ->setCode('col-prichod')
            ->setTitleFieldIndex(42, TextManager::_('prichod_zapsal') . ': ') ->setLink('?menuid=navstevy&formaction=edit');

        $this->defaultSort = -count($this ->fields);

        //Odchod
        $this->addField(new PotvrzeniOdchoduNavstevyField($database, null))
            ->setSqlFieldName('Odchod', 15) ->setHeaderText('Odchod') ->setFormat('weektimestamp') ->setOrdering(1)
            ->setCode('col-odchod');

        //NavstivenaOsoba
        $this->addField()
            ->setSqlFieldIndex(22) ->setTitleFieldIndex(41, TextManager::_('telefon') . ': ') ->setHeaderText('navstivena_osoba')
            ->setCode('col-navstivenaosoba');

        $this->addField( new NavstevuSchvalilaOsoba($database, $this->pravo_schvaleni))
            ->setCode('col-schvalil');
    }


    function setFilterForm()
    {
        // nedela nic - filter nastaven v constructoru
    }


    /**
     * @param array $values
     * @param string $className
     * @param int $rowNumber
     * @param bool $edit
     */
    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        if ($values[24]) {
            echo
                "<tr class='$className poznamka-navstevy'>" .
                '<td></td>' .
                '<td colspan="' . ($this->columnCount - 1) . '">' .
                '<span class="browserpoznamka">' . TextManager::_('duvod_navstevy') . ': ' . StringUtils::htmlTextConvert($values[24]) . '</span>' .
                '</td>' .
                '</tr>';
        }

        if ($this ->filterForm ->zobrazitUzivatelskePoznamky) {
            for ($x = 1; $x <= 10; $x++) {
                if ($values[30 + $x]) {
                    echo
                        "<tr class='$className uzivatelska-pole-navstev'>" .
                        '<td></td><td></td>' .
                        '<td colspan="' . ($this->columnCount - 2) . '">' .
                        '<span class="browserpoznamka">'.
                        RonPortalSettings::getValue('navstevy_uzivatelska' . $x) . ': ' .
                        StringUtils::htmlTextConvert($values[30 + $x]) .
                        '</span>' .
                        '</td>' .
                        '</tr>';
                }
            }
        }
    }

    /**
     * @param array $values
     * @return bool
     * @throws Exception
     */
    function enableLine($values)
    {
        //Zobrazi pokud ma na RC navstivene osoby pravo
        return $this->prava->lzeZobrazitRC($values[21]);
    }

    /**
     * @param Database $database
     * @return mixed
     * @throws DBException
     */
    private function rozdeleniVratnice($database)
    {
        $kod = RonPortalSession::getValue('rozdelenivratnice');
        if (!$kod) {
            return '';
        }

        $params = $database->createParameters();
        $sql =
            'SELECT Rozdeleni.Popis' .
            ' FROM Rozdeleni' .
            ' WHERE KodTypuRozdeleni = ' . $params ->addParameter(RonPortalSettings::getIntValue('typrozdelenivratnice')) .
            ' AND Rozdeleni.Kod = ' . $params->addParameter($kod);

        $cursor = $database->getSqlResult($sql, $params);
        $row = $cursor->fetch();
        return $row[0];
    }


    /**
     * @return SqlStatement|string
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $dnesZacatekDne = DateUtils::today();
        $result = '';

        if (RonPortalSession::getValue('omezeniVratnice') == 1 && RonPortalSession::getValue('rozdelenivratnice') != '') {
            $result =
                'Navsteva.Rozdeleni_Vratnice = ' . $params->addParameter(RonPortalSession::getValue('rozdelenivratnice'));
        }

        if ($this ->filterForm ->jenMedium){
            $result .=
                ($result ? ' AND ' : '') .
                ' Karta.Kod = ' . $params->addParameter($this ->filterForm ->kodMedia) .
                ' AND Prichod IS NOT NULL AND Odchod IS NULL';
        } else {
            //timestamp -> string
            if ($this ->filterForm ->omezeniNavstev == 0) {
                $result .=
                    ($result ? ' AND ' : '') .
                    " (Navsteva.OcekavanyPrichod >= " . $params->addParameter($this->database->timestampToParam($dnesZacatekDne)) .
                    " AND Navsteva.prichod IS NULL AND Navsteva.odchod IS NULL )";

            } else if ($this ->filterForm ->omezeniNavstev == 1) {
                $result .=
                    ($result ? ' AND ' : '') .
                    //' (Navsteva.prichod >= ' . $params->addParameter($this->database->timestampToParam($dnesZacatekDne)) .
                    ' (Navsteva.prichod <= ' . $params->addParameter($this->database->timestampToParam(time())) . // uz prisla a jeste neodesla
                    ' AND Navsteva.odchod IS NULL';
                $result .= ")";

            } else if ($this ->filterForm ->omezeniNavstev == 2) {
                $result .=
                    ($result ? ' AND ' : '') .
                    " ((Navsteva.OcekavanyPrichod >= " . $params->addParameter($this->database->timestampToParam($this ->filterForm ->datumOd)) .
                    " AND Navsteva.OcekavanyPrichod <= " . $params->addParameter($this->database->timestampToParam($this ->filterForm ->datumDo)) .
                    " ) OR (" .
                    " Navsteva.prichod >= " . $params->addParameter($this->database->timestampToParam($this ->filterForm ->datumOd)) .
                    " AND Navsteva.prichod <= " . $params->addParameter($this->database->timestampToParam($this ->filterForm ->datumDo)) .
                    "))";
            }

            //if (RonPortalSession::getValue('jenTypNavstevy')) {
            if ($this ->filterForm ->jenTypNavstevy) {
                $result .=
                    ($result ? ' AND ' : '') .
                    " Navsteva.TypNavstevy = " . $params->addParameter($this ->filterForm ->typNavstevy);
            }

            if ($this ->filterForm ->jenNavstivenaOsoba) {
                $result .=
                    ($result ? ' AND ' : '') .
                    " Navsteva.jmenoNavstiveneOsoby = " . $params->addParameter($this ->filterForm ->navstivenaOsoba);
            }

            if ($this ->filterForm ->jenFirma) {
                $result .=
                    ($result ? ' AND  ' : '') .
                    'Navsteva.firma = ' . $params->addParameter($this ->filterForm ->firma);
            }

            if ($this ->filterForm ->jenPrijmeniNavstevy && $this ->filterForm ->prijmeniNavstevy) {
                $result .=
                    ($result ? ' AND ' : '') .
                    ' Navsteva.prijmeni = ' . $params->addParameter($this ->filterForm ->prijmeniNavstevy);
            }

//            if (RonPortalSession::getValue('jenKod')) {
//                $result .=
//                    ($result ? ' AND ' : '') .
//                    " Navsteva.kod = " . $params->addParameter($_SESSION['kod']);
//            }

            if ($this ->filterForm ->jenDuvod  &&  $this ->filterForm ->duvod) {
                $result .=
                    ($result ? ' AND ' : '') .
                    ' Navsteva.duvodNavstevy2 = ' . $params->addParameter($this ->filterForm ->duvod);
            }


            if ($this ->filterForm ->jenVozidlo) {
                $result .=
                    ($result ? ' AND ' : '') .
                    ($this ->filterForm ->sVozidlem
                        ? 'Navsteva.vozidlo IS NOT NULL'
                        : 'Navsteva.vozidlo IS NULL'
                    );
            }

            if ($this ->filterForm ->filtrovatSchvaleni) {
                $result .=
                    ($result ? ' AND ' : '') .
                    ($this ->filterForm ->schvalene
                        ? 'Navsteva.Schvalil IS NOT NULL'
                        : 'Navsteva.Schvalil IS NULL'
                    );
            }
        }

        return new SqlStatement($result, $params);
    }
}
