<?php
/**
 * seznam planovanych absenci
 */

namespace RonPortal\Dochazka;

use Ron\Controls\BrowserField;
use Ron\Controls\ComboBox;
use Ron\Controls\LinksList;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\NastaveniUzivatele;
use RonPortal\Obdobi;
use RonPortal\PoznamkaKeDni;
use RonPortal\Prava;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use RonPortal\RozdeleniUtils;
use RonPortal\Security;


class AbsenceFilterForm extends RonPortalFilterForm
{
    function __construct($database, $action)
    {
        parent::__construct($database, $action);
    }


    function loadData()
    {
        if (isset($_GET['operace'])) {
            $_SESSION['absence_operace'] = $_GET['operace'];
        }

        // zjisti hodnoty filtru zadane uzivatelem - nutne provest pred nastavovanim filtru Obdobi kvuli checkboxu
        if (isset($_GET['planovani_filtr'])) {
            $filtr = $_GET['planovani_filtr'];

            NastaveniUzivatele::setUserSettingsItem($this ->database, 'browser_absence_filtr', $filtr);
        } else if ( isset($_SESSION['planovani_filtr']) ) {
            $filtr = $_SESSION['planovani_filtr'];
        } else {
            $filtr = NastaveniUzivatele::getUserSettingsItem($this ->database, 'browser_absence_filtr');
        }

        $_SESSION['planovani_filtr'] = $filtr;

        // nastaveni "skryt/zobrazit automaticky schvalovane"
        if (isset($_GET['skrytauto'])) {
            $skrytauto = (int)$_GET['skrytauto'];
            NastaveniUzivatele::setUserSettingsItem($this ->database, 'browser_absence_skrytauto', $skrytauto);
        }
        else if ( isset($_SESSION['planovani_skrytauto']) ) {
            $skrytauto = $_SESSION['planovani_skrytauto'];
        }
        else {
            $skrytauto = NastaveniUzivatele::getUserSettingsItem($this ->database, 'browser_absence_skrytauto');
        }

        $_SESSION['planovani_skrytauto'] = $skrytauto;

        // pokud se ma zobrazit "vse" nebo "zrusene" tak je filtr na obdobi povinny
        $this ->obdobiPovinne = $_SESSION['planovani_filtr'] == 1 || $_SESSION['planovani_filtr'] == 2;

        parent::loadData();
    }


    function renderKodOperace()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">' . TextManager::_('Jen_typ_absence') . '</span>';

        $sql = 'SELECT Kod, Popis FROM OperaceDochazky WHERE Absence_Intraweb = 1';

        $combo = new ComboBox('operace');
        $combo->showCode = true;
        $combo->className = 'adsfilterforminput_popis';
        $combo->emptyRow = TextManager::_('_vse_');
        $combo->translationPrefix = 'db_operacedochazky_popis_';
        $combo->translationValueIndex = 0;
        $combo->loadData($this->database, $sql . ' ORDER BY Absence DESC, Popis, Kod', RonPortalSession::getValue('absence_operace'));
        $combo->htmlParams = ['id' => 'filtr_operace', 'data-ron-select2' => '#filtr_operace_kod', 'data-ron-autosubmit' => '1'];
        $combo->render();

        $combo = new ComboBox('');
        $combo->className = 'adsfilterforminput_kod desktop-only'; // na mobilu se zobrazi jen popis
        $combo->keyIndex = 0;
        $combo->captionIndex = 0;
        $combo->emptyRow = TextManager::_('_vse_');
        $combo->loadData($this->database, $sql . ' ORDER BY Absence DESC, Kod', RonPortalSession::getValue('absence_operace'));
        $combo->htmlParams = 'id="filtr_operace_kod" data-ron-select2="#filtr_operace" data-ron-autosubmit="1"';
        $combo->render();
        echo '</div>';
    }


    function renderFilterStav()
    {
        $filterarray = [0 => TextManager::_('Absence_aktualni'), 1 => TextManager::_('Absence_vse'), 2 => TextManager::_('Absence_zrusene')];

        if (RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI)) {
            $filterarray[3] = TextManager::_('Absence_bez_schvaleni');

            if (Prava::vratHodnotuPrava('prohlizeni') != Prava::vratHodnotuPrava('absence_schval')) {
                // POZOR! Neresi situaci, kdy je uzivatelsky vytvorene pravo pro konkretni absenci
                $filterarray[4] = TextManager::_('Absence_ke_schvaleni');
            }
        }

        echo '<div class="filterrow" id="filtr_urovenschvaleni">';
        echo '<span class="filtercaption"></span>';
        LinksList::renderLinks($filterarray, $_SESSION['planovani_filtr'], $this ->f_formaction . '&planovani_filtr=', '', false);
        echo "</div>\n";

        echo '<div class="filterrow" id="filtr_automatickyschvalovane">';
        echo '<span class="filtercaption"></span>';
        if ( $_SESSION['planovani_skrytauto'] ) {
            echo '<a href="' . $this ->f_formaction . '&skrytauto=0">' . TextManager::_('Zobrazit_automaticky_schvalovane') . '</a>';
        } else {
            echo '<a href="' . $this ->f_formaction . '&skrytauto=1">' . TextManager::_('Skryt_automaticky_schvalovane') . '</a>';
        }
        echo "</div>\n";
    }


    function renderFilters()
    {
        parent::renderFilters();

        $this ->renderKodOperace();

        // vsechno / nezpracovano / nezkontrolovano / neschvaleno
        $this->renderFilterStav();
    }
}


/**
 * Zobrazeni delky absence - bud popis delky nebo cas od - do
 * Class DelkaAbsenceField
 * @package Ron\RonPortal
 */
class DelkaAbsenceField extends BrowserField
{
    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $this ->code = 'col-delka';
        $this ->align = 'left';
        $this ->header = TextManager::_('Delka_absence');
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        switch ($rowData[12]) {
            case 0 :
                return TextManager::_('Absence_cela_smena');

            case 1 :
                return TextManager::_('Absence_pulka_smeny1');

            case 2 :
                return TextManager::_('Absence_pulka_smeny2');

            case 3 : // cas od-do
                return
                    DateUtils::minutesToString((int)($this ->database ->stringToSecondsOfDay($rowData[14]) / 60)) .
                    ' - ' .
                    DateUtils::minutesToString((int)($this ->database ->stringToSecondsOfDay($rowData[15]) / 60));

            case 4 : // kontinualne
                return
                    date('j.n.', $this ->database ->stringToTimestamp($rowData[2]) ) . ' ' . date('G:i', $this ->database ->stringToTimestamp($rowData[14])) .
                    ' - ' .
                    date('j.n.', $this ->database ->stringToTimestamp($rowData[3]) ) . ' ' . date('G:i', $this ->database ->stringToTimestamp($rowData[15]));
        }

        return $rowData[13]; // popis delky absence
    }
}



/**
 * Odkaz na zruseni absence
 * Class ZruseniAbsenceField
 */
class ZruseniAbsenceField extends BrowserField
{
    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);
        $this ->code = 'col-delete';
        $this ->align = 'left';
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!Prava::vratPrava('absence_delete', 'absence_delete_' . $rowData[8]) ->lzeZobrazitPP($rowData[11],
            $this ->database ->stringToTimestamp($rowData[2]), $this ->database ->stringToTimestamp($rowData[3])))
        {
            // nemuze smazat schvalene absence (pokud muze, tak neni potreba kontrolovat dalsi prava)
            $prava = Prava::vratPrava('absence', 'absence_' . $rowData[8]); // prava podle Absence.OperaceDochazky

            if (!$prava->lzeZobrazitPP($rowData[11],
                $this->database->stringToTimestamp($rowData[2]), $this->database->stringToTimestamp($rowData[3]))
            ) {
                // nemuze editovat => nemuze zrusit
                return '';
            }

            if ($rowData[9] == 4) { // jiz je zruseno
                return '';
            }

            if ($rowData[9] == 5) { // // zruseni zamitnuto -> zrusit jde jedine ve formulari
                return '';
            }

            // Pokud nemuze uzivatel schvalovat, tak muze zrusit jedine absenci, ktera jeste nebyla schvalena
            if (RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI))
                if ($rowData[9]) {
                    $pravaSchvalovani = Prava::vratPrava('absence_schval', 'absence_schval_' . $rowData[8]);

                    if (!$pravaSchvalovani->lzeZobrazitPP($rowData[11],
                        $this->database->stringToTimestamp($rowData[2]), $this->database->stringToTimestamp($rowData[3]))
                    ) {
                        return '';
                    }
                }
        }

        return GuiUtils::changeLocationQuest(TextManager::_('Zrusit'), TextManager::_('Opravdu_zrusit_absenci'),
            '?menuid=absence&action=zrusitabsenci&idpp=' . $rowData[11] .
            '&datum=' . DateUtils::dateToUrlString($this ->database ->stringToTimestamp($rowData[2])) .
            '&poradi=' . $rowData[16] . Security::csrfUrlParameter() . '&list=1');
    }
}


/**
 * Odkaz na zobrazeni absence: menuid=absence&action=zobrazabsenci&idpp=...&datum=...&poradi=...
 * Class EditaceAbsenceField
 * @package Ron\RonPortal
 */
class EditaceAbsenceField extends BrowserField
{
    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $this ->code = 'col-zobrazit';
        $this ->align = 'left';
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            '<a href="?menuid=absence&action=zobrazabsenci&idpp=' . $rowData[11] .
            '&datum=' . date('j.n.Y', $this ->database ->stringToTimestamp($rowData[2])) .
            '&poradi=' . $rowData[16] . '">' . TextManager::_('Zobrazit') . '</a>';
    }
}


/**
 * Odkaz na schvaleni absence
 * Class SchvaleniAbsenceField
 * @package Ron\RonPortal
 */
class SchvaleniAbsenceField extends BrowserField
{
    private $pravaDoporuceni;

    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $this ->code = 'col-schvaleni';
        $this ->header = TextManager::_('Schvaleno');
        $this ->align = 'center';

        $this ->pravaDoporuceni = Prava::vratPrava('absence_doporuc');
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        switch($rowData[9]) {
            case 1 :
                return TextManager::_('Str_Yes') . ($rowData[10] ? ' (' . StringUtils::htmlTextConvert($rowData[10]) . ')' : ''); // uz schvaleno

            case 2 :
                return TextManager::_('Str_No') . ($rowData[10] ? ' (' . StringUtils::htmlTextConvert($rowData[10]) . ')' : ''); // zamitnuto

            case 3 :
                return TextManager::_('Zadost_o_zruseni');

            case 4 :
                return TextManager::_('Zruseno') . ($rowData[10] ? ' (' . StringUtils::htmlTextConvert($rowData[10]) . ')' : ''); // zruseno

            case 5 :
                return TextManager::_('Zruseni_zamitnuto') . ($rowData[10] ? ' (' . StringUtils::htmlTextConvert($rowData[10]) . ')' : '');
        }

        $datumOd = $this ->database ->stringToTimestamp($rowData[2]);
        $datumDo = $this ->database ->stringToTimestamp($rowData[3]);

        $prava = Prava::vratPrava('absence_schval', 'absence_schval_' . $rowData[8]);
        $lzeSchvalit = $prava ->lzeZobrazitPP($rowData[11], $datumOd, $datumDo);

        $result = '';

        // schvaleni jeste neni urceno

        if (RonPortalSettings::getIntValue(AbsenceController::SETTINGS_DOPORUCOVANI)) {
            if ($rowData[18] == 2) {
                // nedoporuceno - zamitnout
                $result = TextManager::_('Nedoporuceno') . ($rowData[19] ? ' (' . StringUtils::htmlTextConvert($rowData[19]) . ')' : '') . '&nbsp;';

                if ($lzeSchvalit) {
                    $result .=
                        '<a href="?menuid=absence&action=zamitnoutabsenci&idpp=' . $rowData[11] .
                        '&datum=' . date('j.n.Y', $datumOd) .
                        '&poradi=' . $rowData[16] . '&list=1' . Security::csrfUrlParameter() . '">' . TextManager::_('Zamitnout') . '</a>';
                }

                return $result;

            } else if ($rowData[18] == 1) {
                // doporuceno
                $result = TextManager::_('Doporuceno') . ($rowData[19] ? ' (' . StringUtils::htmlTextConvert($rowData[19]) . ')' : '') . '&nbsp;';

                if ($lzeSchvalit) {
                    // muze schvalovat - prida odkaz na schvaleni
                    $result .=
                        '<a class="sabs_schvalit" href="?menuid=absence&action=schvalitabsenci&idpp=' . $rowData[11] .
                        '&datum=' . date('j.n.Y', $datumOd) .
                        '&poradi=' . $rowData[16] . '&list=1' . Security::csrfUrlParameter() . '">' . TextManager::_('Schvalit') . '</a>';
                }

                return $result;

            } else if (!$rowData[18]) {
                // doporuceni neni jeste nastaveno - pokud nemuze schvalovat, tak zobrazi "doporucit
                if (!$lzeSchvalit && $this ->pravaDoporuceni ->lzeZobrazitPP($rowData[11], $datumOd, $datumDo)) {
                    if ($this ->pravaDoporuceni ->priznak3ObsahujeKod($rowData[8])) {
                        return
                            '<a href="?menuid=absence&action=doporucitabsenci&idpp=' . $rowData[11] .
                            '&datum=' . date('j.n.Y', $datumOd) .
                            '&poradi=' . $rowData[16] . '&list=1' . Security::csrfUrlParameter() . '">' . TextManager::_('doporucit') . '</a>';
                    }
                }
            }
        }

        if ($lzeSchvalit) {
            // muze schvalovat
            $result .=
                '<a class="sabs_schvalit" href="?menuid=absence&action=schvalitabsenci&idpp=' . $rowData[11] .
                '&datum=' . date('j.n.Y', $datumOd) .
                '&poradi=' . $rowData[16] . '&list=1' . Security::csrfUrlParameter() . '">' . TextManager::_('Schvalit') . '</a>' .
                ' / ' .
                '<a class="sabs_zamitnout" href="?menuid=absence&action=zamitnoutabsenci&idpp=' . $rowData[11] .
                '&datum=' . date('j.n.Y', $datumOd) .
                '&poradi=' . $rowData[16] . '&list=1' . Security::csrfUrlParameter() . '">' . TextManager::_('Zamitnout') . '</a>';
        }

        return $result;
    }
}


/**
 * Poznamky ke dni v rozsahu zadane absence
 * Class Absence_PoznamkyKeDniField
 * @package Ron\RonPortal
 */
class Absence_PoznamkyKeDniField extends BrowserField
{
    private $typyPoznamek;

    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $typPoznamky = RonPortalSettings::getValue('absence_typpoznamky');
        $this ->typyPoznamek = ($typPoznamky == '*') ? null : explode(';', $typPoznamky);

        $this ->code = 'col-poznamkykedni';
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $poznamky = PoznamkaKeDni::nactiPoznamkyProOsobu($this ->database, $rowData[11],
            $this ->database ->stringToTimestamp($rowData[2]), $this ->database ->stringToTimestamp($rowData[3]),
            $this ->typyPoznamek);

        $result = '';
        if ($poznamky) {
            $title = '';
            foreach ($poznamky as $poznamka) {
                $title .= StringUtils::htmlTextConvert($poznamka ->text) . "\n";
            }

            $result = '<i class="inline-glyph fa glyph-info" title="' . $title . '"></i>';
        }

        return $result;
    }
}

class AbsenceBrowser extends RonPortalBrowser
{
    private $pravaProhlizeni;
    private $pravaSchvalovani;
    private $pravaPlanovani;

    private $RC; // pokud je zadano, zeobrazi se data jen pro jednu osobu
    private $menuId; // cilova stranka pro odkazy

    private $radekLzeSchvalit = false;    
    //private $jsonRowIndex;


    function __construct($database, $RC = null)
    {
        parent::__construct($database, 'planovani');

        $this ->title = TextManager::_('Prehled_planovanych_absenci');

        $this ->code = 'browserplanovaneabsence';
        $this ->tableId = 'schvalovaniAbsenciTable';

        $this ->RC = $RC;
        $this ->menuId = $RC ? 'planovani' : 'schvalovaniabsence';
        $this ->browserUrl = '?menuid=' . $this ->menuId . '&';

        // definice dotazu a hlavicky
        $this ->sqlSelectPart =
            'Osoba.Jmeno, Osoba.Prijmeni, ' . // 0,1
            'Absence.DatumOd, Absence.DatumDo, OperaceDochazky.Popis, ' . // 2..4
            'Absence.RC, Absence.OsobniCislo, Absence.DatumNastupu, ' . // 5..7
            'Absence.OperaceDochazky, Absence.Schvaleni, Absence.Schvalil, ' . // 8..10
            'PracovniPomer.Id, ' . // 11
            'Absence.Delka, S_DelkaAbsence.Popis, Absence.CasOd, Absence.CasDo, Absence.Poradi, ' . // 12..16
            $database ->castWideMemo('Absence.Poznamka') . ', Absence.Doporuceni, Absence.Doporucil, ' . // 17..19
            'Absence.KodTypuRozdeleni, Absence.Rozdeleni, Rozdeleni.Popis, PracovniPomer.OsobniCislo '; // 20..23


        $this ->sqlFromPart =
            '( ( ( ( Absence INNER JOIN OperaceDochazky ' .
            '        ON Absence.OperaceDochazky = OperaceDochazky.Kod ' .
            '      ) ' .
            '      INNER JOIN PracovniPomer ' .
            '       ON PracovniPomer.RC = Absence.RC' .
            '      AND PracovniPomer.OsobniCislo = Absence.OsobniCislo ' .
            '      AND PracovniPomer.DatumNastupu = Absence.DatumNastupu ' .
            '    ) ' .
            '    INNER JOIN Osoba ' .
            '     ON Osoba.RC = Absence.RC ' .
            '  ) ' .
            '  INNER JOIN S_DelkaAbsence ' .
            '   ON S_DelkaAbsence.Kod = Absence.Delka' .
            ') ' .
            'LEFT OUTER JOIN Rozdeleni ' .
            '  ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
            ' AND Rozdeleni.Kod = Absence.Rozdeleni ';


        if ($this ->RC) {
            // jen data jedne osoby (pri planovani)
            $params = $database ->createParameters();
            $this ->sqlWherePart = new SqlStatement('Osoba.RC = ' . $params ->addParameter($this ->RC), $params);
        }

        $this ->pravaProhlizeni = Prava::vratPrava('prohlizeni');
        $this ->pravaSchvalovani = Prava::vratPrava('absence_schval');
        $this ->pravaPlanovani = Prava::vratPrava('absence');

        $this ->primaryField = 0;

        $this ->addField()
            ->setSqlFieldName('Osoba.Jmeno', 0)
            ->setCode('col-jmeno') ->setHeaderText('Jmeno') ->setOrdering(1);

        $this ->addField()
            ->setSqlFieldName('Osoba.Prijmeni',  1)
            ->setCode('col-prijmeni') ->setHeaderText('Prijmeni') ->setOrdering(1);

        $this ->addField()
            ->setSqlFieldName('PracovniPomer.OsobniCislo', 23)
            ->setCode('col-osobnicislo') ->setHeaderText('Osobni_cislo') ->setOrdering(1);

        $this ->addField()
            ->setSqlFieldName('Absence.DatumOd', 2) ->setFormat('date')
            ->setCode('col-datumod') ->setHeaderText('Datum_od') ->setOrdering(1);
        $this ->defaultSort = count($this ->fields);

        $this ->addField()
            ->setSqlFieldName('Absence.DatumDo', 3) ->setFormat('date')
            ->setCode('col-datumdo') ->setHeaderText('Datum_do') ->setOrdering(1);

        $this ->addField()
            ->setSqlFieldName('OperaceDochazky.Popis', 4)
            ->setCode('col-operace') ->setHeaderText('Popis_absence') ->setOrdering(1)
            ->setTranslationPrefix('db_operacedochazky_popis_', 8);

        $this ->addField(new DelkaAbsenceField($database));
        $this ->addField(new EditaceAbsenceField($database));
        $this ->addField(new ZruseniAbsenceField($database));

        // pole pro schvaleni absence vcetne odkazu a osoby, ktera to schvalila
        $this ->addField(new SchvaleniAbsenceField($database))
            ->setVisible(RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI));

        // zjednodusene zobrazeni schvaleni - pouze textovy stav - implicitne se nezobrazuje
        $this ->addField(BrowserField::FIELD_TYPE_SELECT)
            ->setSqlFieldName('Absence.Schvaleni', 9) ->setHeaderText('Stav_absence') ->setOrdering(1)
            ->setCode('col-stav') ->setTitleFieldIndex(10) ->setVisible(false)
            ->setOptions([
                0 => TextManager::_('Stav_Absence_0'),
                1 => TextManager::_('Stav_Absence_1'),
                2 => TextManager::_('Stav_Absence_2'),
                3 => TextManager::_('Stav_Absence_3'),
                4 => TextManager::_('Stav_Absence_4'),
                5 => TextManager::_('Stav_Absence_5')
            ]);

        if (RonPortalSettings::getValue('absence_typpoznamky')) {
            $this ->addField(new Absence_PoznamkyKeDniField($database));
        }
    }


    function setFilterForm()
    {
        if (isset($_GET['poznamkyabsence'])) {
            $_SESSION['poznamkyabsence'] = (int)$_GET['poznamkyabsence'];
            setcookie('absence_zobrazitpoznamky', (int)$_GET['poznamkyabsence'], time() + 30000000);
        } else if (!isset($_SESSION['poznamkyabsence'])) {
            $_SESSION['poznamkyabsence'] = isset($_COOKIE['absence_zobrazitpoznamky']) ? (int)$_COOKIE['absence_zobrazitpoznamky'] : 0;
        }

        $this ->filterForm = new AbsenceFilterForm($this ->database, $this ->menuId);
        $this ->filterForm ->setUseGet(true, $this ->menuId);

        $this ->filterForm ->nastavObdobi(true, 'ADS', false, true); // jenotevrene = false, povinne - nastavi se v load

        if (!$this ->RC) {
            // filtr rozdeleni - v planovani se nezobrazuje
            $this ->filterForm ->nastavRozdeleni(true);

            $pravaPrehled = Prava::vratPrava('absence_prehled');
            //Nastavi pravo na rozdeleni, kde muze nekoho videt. POZOR: nejde nastavit soucet prav, pokud tedy u schvalovani ma pouze jednu osobu, uvidi pouze jeji rozdeleni.
            if ($pravaPrehled->jsouNejakePrava()) {
                $this->filterForm->f_pravarozdeleni = $pravaPrehled;
            }
            else if ($this->pravaSchvalovani->jsouNejakePrava()) {
                $this->filterForm->f_pravarozdeleni = $this->pravaSchvalovani;
            }
            else if ($this->pravaProhlizeni->jsouNejakePrava()) {
                $this->filterForm->f_pravarozdeleni = $this->pravaProhlizeni;
            }
            else if ($this->pravaPlanovani->jsouNejakePrava()) {
                $this->filterForm->f_pravarozdeleni = $this->pravaPlanovani;
            }

            if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) {
                $this ->filterForm ->nastavRozdeleni2(true);
            }

            $this->filterForm ->nastavOsoby(true, $this->filterForm->f_pravarozdeleni);
            $this->filterForm ->povolitVsechyOsoby = true;
        }
    }


    /**
     * Zobrazi formular pro hromadne schvalovani
     */
    function hromadneSchvalovaniForm()
    {
        if ( !RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI) ) {
            return;
        }
        if ( !$this ->pravaSchvalovani ->jsouNejakePrava() ) {
            return;
        }

        echo
            '<div id="absence_hromadneschvalovani">' .
            '<form method="POST" name="hromadneSchvalovaniForm" action="?menuid=schvalovaniabsence">' .
            '<input type="hidden" name="hromadneSchvaleni" value="1" />' .
            '<input type="hidden" name="akceHromadneSchvaleni" value="0" />' . // nastavi se tlacitkem 1=schvalit, 2=zamitnout
            '<input type="hidden" name="vybraneZaznamy" value="" />' .
            Security::csrfHiddenInput() .

            '<span class="buttons">' .
            '<input type="button" class="button midbutton" name="schvaleniMenuButton" id="schvaleniMenuButton" value="..." />' .

            '<input id="schvalitVybraneAbsence" type="button" class="button" name="schvalitVybrane" disabled="disabled" value="' . TextManager::_('Schvalit_vybrane') . '" />' .
            '<input id="zamitnoutVybraneAbsence" type="button" class="button" name="zamitnoutVybrane" disabled="disabled" value="' . TextManager::_('Zamitnout_vybrane') . '" />' .
            '<input id="schvalitVsechnyAbsence" type="button" class="button" name="schvalitVse" value="' . TextManager::_('Schvalit_vse') . '" />' .

            '</span>' .
            '</form>'.
            "</div>\n";

        echo
            '<ul class="popupmenu"  id="schvaleniMenu">' .
            "<li id='schvaleniMenuVse'>" . TextManager::_('Oznacit_vse') . "</li>" .
            "<li id='schvaleniMenuNic'>" . TextManager::_('Zrusit_oznaceni') . "</li>" .
            '</ul>';
    }


    private function zobrazitPoznamky()
    {
        return $_SESSION['poznamkyabsence'];
    }



    function renderFilter()
    {
        parent::renderFilter();

        echo '<div class="text_link" id="absence_poznamky" >';
        if ($this ->zobrazitPoznamky()) {
            echo '<a href="?menuid=' . $this ->menuId . '&poznamkyabsence=0">' . TextManager::_('Skryt_poznamky') . '</a>';
        } else {
            echo '<a href="?menuid=' . $this ->menuId . '&poznamkyabsence=1">' . TextManager::_('Zobrazit_poznamky') . '</a>';
        }
        echo "</div>\n";

        $this ->hromadneSchvalovaniForm();
    }


    /**
     * @return string
     */
    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        $result = '';

        $filtrSettings = isset($_SESSION['planovani_filtr']) ? $_SESSION['planovani_filtr'] : 0;

        switch ($filtrSettings) {
            case 1 : // vse
                break;

            case 2 : // zrusene
                $result = 'Absence.Schvaleni = 4';
                break;

            case 3 : // bez schvaleni
                $obdobiOd = Obdobi::prvniNeschvaleneObdobi($this ->database, 'ADS');
                $result =
                    'Absence.Schvaleni = 0' .
                    ($obdobiOd
                        ? ' AND Absence.DatumDo >= ' . $params ->addDateParameter($obdobiOd)
                        : '');
                break;

            case 4 : // ke schvaleni - jako bez schvaleni, ale jen ty, ktere muzu schvalovat
                $obdobiOd = Obdobi::prvniNeschvaleneObdobi($this ->database, 'ADS');
                $result =
                    '(Absence.Schvaleni = 0  OR  Absence.Schvaleni = 3)' .
                    ($obdobiOd
                        ? ' AND Absence.DatumDo >= ' . $params ->addDateParameter($obdobiOd)
                        : '');
                break;

            default : // aktualni a budouci
                $result =
                    'Absence.Schvaleni <> 4 ' . // vynecha zrusene
                    ' AND Absence.DatumDo >= ' . $params ->addDateParameter(time());
                break;
        }

        if ( $_SESSION['planovani_skrytauto'] ) {
            $result .=
                ($result ? ' AND ' : '') .
                'OperaceDochazky.Absence_AutoSchvalovat = 0';
        }

        if (isset($_SESSION['absence_operace'])  &&  $_SESSION['absence_operace'] !== '') {
            $result .=
                ($result ? ' AND ' : '') .
                'Absence.OperaceDochazky = ' . $params ->addParameter($_SESSION['absence_operace']);  // TODO: zrusit session
        }


        if ($this ->filterForm ->showOsoby  &&  !$this ->filterForm ->vsechnyOsoby) {
            // filtr na osobu
            $result .=
                ($result ? ' AND ' : '') .
                'PracovniPomer.Id = ' . $params ->addParameter((int)$this ->filterForm ->vybranaOsoba);
        }

        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP) && RonPortalSession::rozdeleni() !== null) {
            // rozdeleni
            $filtr = $this ->filterForm ->vratSQLFiltrRozdeleni('PracovniPomer', RonPortalSession::rozdeleniVcetnePodrizenych(), 0, 0, $params);

            if ($filtr) {
                $result .=
                    ($result ? ' AND ' : '') .
                    '(' . $filtr . ') ';
            }
        }

        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP) && RonPortalSession::rozdeleni2()) {
            $filtr = RozdeleniUtils::sqlFilterRozdeleniPP($this ->database, 'PracovniPomer',
                RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP), RonPortalSession::rozdeleni2(),
                RonPortalSession::obdobi(), RonPortalSession::konecObdobi(), RonPortalSession::rozdeleni2VcetnePodrizenych(),
                $params);

            if ($filtr) {
                $result .=
                    ($result ? ' AND ' : '') .
                    '(' . $filtr . ') ';
            }
        }

        // obdobi (pro "vse" a "zrusene" je povinne)
        if ($_SESSION['planovani_filtr'] == 1 || $_SESSION['planovani_filtr'] == 2 || $this ->filterForm ->jenObdobi) {
            $result .=
                ($result ? ' AND ' : '') .
                ' Absence.DatumDo >= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiOd) .
                ' AND Absence.DatumOd <= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiDo);
        }

        return $result ? new SqlStatement($result, $params) : null;
    }


    /**
     * @param array $values
     * @param string $className
     * @param int $rowNumber
     * @return string
     */
    function getRowAttributes($values, $className, $rowNumber)
    {
        $className .=
            ($className ? ' ' : '') .
            'absence-row' .
            ' absence-typ-' . str_replace(' ', '_', $values[8]);

        switch ($values[9]) {
            case 1 :
            case 5 : // zadost o zruseni zamitnuta = schvaleno
                $className .= ' absence_schvalena';
                break;

            case 2 :
                $className .= ' absence_zamitnuta';
                break;

            case 3 :
                $className .= ' absence_zadostozruseni';
                break;

            case 4 :
                $className .= ' absence_zrusena';
                break;

            default :
                $className .= ' absence_neschvalena';

                if (RonPortalSettings::getIntValue(AbsenceController::SETTINGS_DOPORUCOVANI)) {
                    if ($values[18] == 1) $className .= ' absence_doporucena';
                    else if ($values[18] == 2) $className .= ' absence_nedoporucena';
                }
                break;
        }


        $result = parent::getRowAttributes($values, $className, $rowNumber);

        if ($this ->radekLzeSchvalit) {
            $datumOd = $this ->database ->stringToTimestamp($values[2]);

            $result .=
                //" data-ron-indexabsence='{$this ->jsonRowIndex}' id='absencerow_{$this ->jsonRowIndex}'" .
                " data-lze-schvalit='1'" .
                " data-idpp='" . (int)$values[11] . "' data-datum='" . date('j.n.Y', $datumOd) . "' data-poradi='" . (int)$values[16] . "'";
        }

        return $result;
    }


    function enableLine($values)
    {
        $datumOd = $this ->database ->stringToTimestamp($values[2]);
        $datumDo = $this ->database ->stringToTimestamp($values[3]);

        $this ->radekLzeSchvalit = false;

        if (RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI)) {
            $pravo = Prava::vratPrava('absence_schval', 'absence_schval_' . $values[8]);

            if($pravo ->lzeZobrazitPP($values[11], $datumOd, $datumDo)) {
                $this ->radekLzeSchvalit = true; 
                return true;
            }

            $pravo = Prava::vratPrava('absence_doporuc');
            if ($pravo ->lzeZobrazitPP($values[11], $datumOd, $datumDo)) {
                // muze doporucit - jeste zkontroluje, jestli nema omezene typy absenci, ktere muze doporucit
                if ($pravo ->priznak3ObsahujeKod($values[8])) {
                    return true;
                }
            }

            if ($_SESSION['planovani_filtr'] == 4) {
                // filtr "ke schvaleni" - pokud nemuzu schvalovat, tak ho ani nezobrazuju
                return false;
            }
        }

        if ($this ->pravaProhlizeni ->lzeZobrazitPP($values[11], $datumOd, $datumDo)) {
            // ma pravo prohlizet
            return true;
        }

        $pravo = Prava::vratPrava('absence_prehled', 'absence_' .$values[8]);
        if ($pravo ->lzeZobrazitPP($values[11], $datumOd, $datumDo)) {
            return true;
        }

        $pravo = Prava::vratPrava('absence', 'absence_' . $values[8]);
        return $pravo ->lzeZobrazitPP($values[11], $datumOd, $datumDo);
    }


    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        // zobrazi poznamku a rozdeleni
        if ( $this ->zobrazitPoznamky()  &&  ($values[17]  ||  isset($values[21])) ) {
            echo "<tr class='$className'>";
            $colspan = $this ->visibleFieldsCount() - 1;

            echo "<td></td><td colspan='$colspan'>";

            // rozdeleni (kod - popis)
            if (isset($values[21])) {
                echo '<div class="poznamka browserpoznamka">' . StringUtils::htmlTextConvert($values[21]) . ' - ' . StringUtils::htmlTextConvert($values[22]) . '</div>';
            }

            // poznamka
            if ($values[17]) {
                echo '<div class="poznamka browserpoznamka">' . StringUtils::htmlTextConvert($values[17]) . '</div>';
            }

            echo '</td>';
            echo "</tr>\n";
        }
    }


    function render()
    {
        echo '<div id="browserabsence">';

        parent::render();

        echo '</div>';
    }
}

