<?php

namespace RonPortal\Hodnoceni;

use Exception;
use Ron\Controls\Browser;
use Ron\Controls\BrowserField;
use Ron\Controls\LinksList;
use Ron\DB\Database;
use Ron\DB\DBUtils;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\PredavaciProcesyUtils;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use RonPortal\Controls\RozdeleniOsobyBrowserField;
use RonPortal\User;
use Ron\StringUtils;
use function Ron\ronText;


/**
 * Sloupec s vysledkem hodnoceni, ktery je videt jen u ukoncenych hodnoceni
 * Class VysledekField
 * @package Ron\Personalistika
 */
class VysledekField extends BrowserField
{
    var $zobrazitVzdy;

    /**
     * @param bool $zobrazitVzdy
     * @param string $sqlFieldName
     * @param int $sqlFieldIndex
     */
    function __construct($zobrazitVzdy, $sqlFieldName, $sqlFieldIndex)
    {
        parent::__construct();

        // nastaveni, jestli se zobrazi vysledek i u nedokoncenych hodnoceni
        $this->zobrazitVzdy = $zobrazitVzdy;

        $this ->sqlFieldIndex = $sqlFieldIndex;
        $this ->sqlFieldName = $sqlFieldName;

        $this ->format = 'number_2';
        $this ->align = 'right';
        $this ->ordering = 1;

        global $STR_Vysledek; // kompat.
        $this ->header = $STR_Vysledek ?: ronText('Vysledek_hodnoceni');
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!$this->zobrazitVzdy)
            if (!$rowData[9]) return '-';  // uzivatel nesmi videt neukoncene a toto neni ukoncene

        $result = parent::getViewText($value, $rowNumber, $recordId, $rowData);
        if ($rowData[10]) {
            // upresneni vysledku
            $result .= ' (' . $rowData[10] . ')';
        }

        return $result;
    }
}



class VysledekHodnoceniBrowser extends Browser
{
    var $zobrazitPrubezneVysledky;

    /** @var bool   Nastavi se na true, pokud ma prava na podrizene (=je v predavacim procesu) */
    var $pravaNaPodrizene;

    /** @var  HodnoceniFilterForm */
    var $filterForm;

    /**
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $this->title = ronText('Vysledky_hodnoceni');
        $this->code = 'browservysledekhodnoceni';

        $this->sqlFromPart =
            '( (VysledekHodnoceni INNER JOIN Osoba ' .
            '   ON VysledekHodnoceni.HodnocenyRC = Osoba.RC ' .
            '  )' .
            '  INNER JOIN UcelHodnoceni ' .
            '  ON VysledekHodnoceni.KodUcelu = UcelHodnoceni.Kod ' .
            ') ';

        $this ->sqlSelectPart =
            'VysledekHodnoceni.ID, VysledekHodnoceni.HodnocenyRC, VysledekHodnoceni.HodnocenyOsobniCislo, VysledekHodnoceni.HodnocenyDatumNastupu, ' . // 0..3
            'Osoba.Jmeno, Osoba.Prijmeni, UcelHodnoceni.Popis, ' . // 4..6
            'VysledekHodnoceni.PocatekObdobi, VysledekHodnoceni.KonecObdobi, VysledekHodnoceni.Stav, ' . // 7..9
            'VysledekHodnoceni.UpresneniVysledku, VysledekHodnoceni.CelkovyVysledek, VysledekHodnoceni.CelkovyKoeficient '; // 10..12


        $this->defaultSort = 1;
        $this->primaryField = 0;


        // rozdeleni
        $fRozdeleni = new RozdeleniOsobyBrowserField($database, RonPortalSettings::getIntValue(RonPortalSettings::PREDAVANI_TYP_ROZDELENI));
        $fRozdeleni ->nastavIndexPole(1); // index pole HodnocenyRC
        $fRozdeleni ->indexDatumOd = 7;
        $fRozdeleni ->indexDatumDo = 8;
        $fRozdeleni->setCode('col-rozdeleni');
        $this ->addField($fRozdeleni);

        // osoba
        $this->addField()
            ->setSqlFieldName('Osoba.Jmeno')->setSqlFieldIndex(4)->setHeaderText('Jmeno')->setOrdering(true)->setCode('col-jmeno');
        $this->addField()
            ->setSqlFieldName('Osoba.Prijmeni')->setSqlFieldIndex(5)->setHeaderText('Prijmeni')->setOrdering(true)->setCode('col-prijmeni');
        // popis
        $this->addField()
            ->setSqlFieldName('UcelHodnoceni.Popis')->setSqlFieldIndex(6)->setHeaderText('Popis')->setOrdering(true)->setCode('col-popis');
        // Obdobi hodnoceni (od-do)
        $this->addField()
            ->setSqlFieldName('VysledekHodnoceni.PocatekObdobi')->setSqlFieldIndex(7)->setHeaderText('Datum_od')->setFormat('date')
            ->setOrdering(true)->setCode('col-pocatekobdobi');
        $this->addField()
            ->setSqlFieldName('VysledekHodnoceni.KonecObdobi')->setSqlFieldIndex(8)->setHeaderText('Datum_do')->setFormat('date')
            ->setOrdering(true)->setCode('col-konecobdobi');

        // stav
        global $STR_VH_Ukonceno; // kompat.
        global $STR_VH_Neukonceno; // kompat.
        global $STR_VH_Vyrazeno; // kompat
        $this->addField()
            ->setSqlFieldName('VysledekHodnoceni.Stav')->setSqlFieldIndex(9)->setHeaderText('Stav_hodnoceni')->setOrdering(true)
            ->setType(BrowserField::FIELD_TYPE_SELECT)->setCode('col-stavhodnoceni')->setOptions(
             [0 => $STR_VH_Neukonceno ?: ronText('Stav_vysledku_Neukonceno'), 1 => $STR_VH_Ukonceno ?: ronText('Stav_vysledku_Ukonceno'), -1 => $STR_VH_Vyrazeno ?: ronText('Stav_vysledku_Vyrazeno')]);

        // vysledek
        // nejdrive urci, jestli se zobrazi vysledek i u nedokoncenych hodnoceni
        // - bere se (alespon prozatim) stejne nastaveni jako pro povoleni hromadneho schvalovani
        //   tj. kdyz muze hromadne schvalovat, tak zaroven vidi prubezne vysledky hodnoceni
        $seznamUrovni = PredavaciProcesyUtils::seznamUrovniPredavaniUzivatele($this ->database);
        $this->zobrazitPrubezneVysledky = PredavaciProcesyUtils::muzeHromadneSchvalovatHodnoceni($seznamUrovni);

        if ( RonPortalSettings::getIntValue(RonPortalSettings::ZOBRAZIT_VYSLEDKY_HODNOCENI) & 1 ) { // znamka nebo oboji
            $vysledekField = new VysledekField($this->zobrazitPrubezneVysledky, 'VysledekHodnoceni.CelkovyVysledek', 11);
            $this->addField($vysledekField)->setCode('col-vysledek');
        }

        if ( RonPortalSettings::getIntValue(RonPortalSettings::ZOBRAZIT_VYSLEDKY_HODNOCENI) & 2 ) // koeficient nebo oboji
        {
            $vysledekField = new VysledekField($this->zobrazitPrubezneVysledky, 'VysledekHodnoceni.CelkovyKoeficient', 12);
            $this->addField($vysledekField)->setCode('col-vysledek');
        }

        $this ->pravaNaPodrizene = PredavaciProcesyUtils::jeVNejakemProcesu($this ->database);
    }


    /**
     * @param string $sqlFilter
     * @throws Exception
     */
    function load($sqlFilter = '')
    {
        $xml = RonPortalBrowser::loadBrowserConfiguration($this ->database, $this ->code);
        if ($xml) {
            $this ->loadConfigurationXml($xml);
        }

        if ($this ->pravaNaPodrizene) {
            if (isset($_GET['filtrhodnoceni'])) {
                $_SESSION['filtrvysledekhodnoceni'] = $_GET['filtrhodnoceni'];
            }
        } else {
            // neni v predavacim procesu - uvidi jen "moje hodnoceni"
            $_SESSION['filtrvysledekhodnoceni'] = 0;
        }

        $this ->filterForm = new HodnoceniFilterForm($this ->database, 'vysledkyhodnoceni', true);
        $this ->filterForm ->zobrazitZnamky = true;
        $this ->filterForm ->loadData();

        parent::load($sqlFilter);
    }


    function renderFilter()
    {
        if ($this ->pravaNaPodrizene) {
            LinksList::renderLinks(
                [0 => ronText('Moje_hodnoceni'), 1 => ronText('Hodnoceni_podrizenych')],
                (int)HodnoceniFilterForm::getFiltrVysledku(), '?menuid=vysledkyhodnoceni&filtrhodnoceni=');
        }

        $this ->filterForm ->render();
    }




    function getSQLFilter()
    {
        $result = ' (VysledekHodnoceni.Stav <> -1) '; // nezobrazuje vyrazene - bylo to zapoznamkovano (viz nahore) - nevim proc

        $typ = (int)HodnoceniFilterForm::getFiltrVysledku();
        $kodTypuRozdeleni = RonPortalSettings::getIntValue(RonPortalSettings::PREDAVANI_TYP_ROZDELENI);

        switch ($typ) {
            case 0 : // moje hodnoceni
                $result .= " AND VysledekHodnoceni.HodnocenyRC = '" . $this ->database ->addSlashes(User::getRC()) . "'";
                break;

            case 1 : // hodnoceni podrizenych
                if ($this->filterForm->showOsoby && !RonPortalSession::vsechnyOsoby())
                    $result .= " AND VysledekHodnoceni.HodnocenyRC = '" . $this ->database ->addSlashes($this->filterForm->vybranaOsobaRC) . "'";
                else {
                    $result .=
                        ' AND EXISTS ' .
                        '( SELECT PracovniPomer.Id ' .
                        '  FROM PracovniPomer, RozdeleniOsob R_PracovniMisto, PMProUrovne, PoradiPredavani, ' .
                        '       RozdeleniOsob R_JA, HierarchieRozdeleni H, RozdeleniOsob R_Hodnoceny, PredavaciProces ' .
                        " WHERE PracovniPomer.RC = '" . $this->database->addSlashes(User::getRC()) . "'" .
                        // jen "moje" urovne predavani podle pracovniho mista
                        '   AND R_PracovniMisto.RC = PracovniPomer.RC ' .
                        '   AND R_PracovniMisto.OsobniCislo = PracovniPomer.OsobniCislo ' .
                        '   AND R_PracovniMisto.DatumNastupu = PracovniPomer.DatumNastupu ' .
                        '   AND R_PracovniMisto.PlatnostOd <= ' . $this->database->timestampToString(time()) .
                        '   AND (R_PracovniMisto.PlatnostDo >= ' . $this->database->timestampToString(time()) . '  OR  R_PracovniMisto.PlatnostDo IS NULL) ' .
                        '   AND R_PracovniMisto.KodTypuRozdeleni = PMProUrovne.KodTypuRozdeleni ' .
                        '   AND R_PracovniMisto.Rozdeleni = PMProUrovne.KodRozdeleni ' .
                        '   AND PoradiPredavani.KodProcesu = UcelHodnoceni.KodProcesu ' .
                        '   AND PoradiPredavani.PocatecniUroven = VysledekHodnoceni.KodVstupniUrovne ' .
                        '   AND PoradiPredavani.KodUrovne = PMProUrovne.KodUrovne ' .

                        '   AND (PoradiPredavani.Vlastni = 0  OR  (PoradiPredavani.Vlastni = 1  AND  VysledekHodnoceni.HodnocenyRC = PracovniPomer.RC) )' .
                        // doplneno 11/2017 - pokud je uroven "pouze vlastni", tak to musi byt vlastni hodnoceni

                        '   AND PredavaciProces.Kod = PoradiPredavani.KodProcesu' .

                        // jen podrizena rozdeleni (vzhledem k PP!)
                        '   AND R_Ja.RC = PracovniPomer.RC ' .
                        '   AND R_Ja.OsobniCislo = PracovniPomer.OsobniCislo ' .
                        '   AND R_Ja.DatumNastupu = PracovniPomer.DatumNastupu ' .
                        '   AND H.TypNadrazene = R_Ja.KodTypuRozdeleni ' .
                        '   AND H.KodNadrazene = R_Ja.Rozdeleni ' .
                        '   AND H.TypPodrizene = R_Hodnoceny.KodTypuRozdeleni ' .
                        '   AND H.KodPodrizene = R_Hodnoceny.Rozdeleni ' .
                        "   AND (R_JA.KodTypuRozdeleni = PredavaciProces.KodTypuRozdeleni OR (PredavaciProces.KodTypuRozdeleni IS NULL AND R_JA.KodTypuRozdeleni = $kodTypuRozdeleni))" .
                        "   AND R_Hodnoceny.KodTypuRozdeleni = R_JA.KodTypuRozdeleni" .
                        '    AND R_Hodnoceny.RC = VysledekHodnoceni.HodnocenyRC' .
                        '    AND R_Ja.PlatnostOd <= VysledekHodnoceni.KonecObdobi' .
                        '    AND (R_Ja.PlatnostDo >= VysledekHodnoceni.PocatekObdobi  OR  R_Ja.PlatnostDo IS NULL)' .
                        '    AND R_Hodnoceny.PlatnostOd <= VysledekHodnoceni.KonecObdobi' .
                        '    AND (R_Hodnoceny.PlatnostDo >= VysledekHodnoceni.PocatekObdobi  OR  R_Hodnoceny.PlatnostDo IS NULL)' .

                        ')';
                }

                break;
        }

        // "Jen rozdeleni"
        if ($typ != 0 && HodnoceniFilterForm::getJenRozdeleniHodnoceni() && HodnoceniFilterForm::getRozdeleniHodnoceni()) {
            if ($result) $result .= '  AND  ';

            $result .=
                ' EXISTS ' .
                '( SELECT * ' .        // jsem ve stejnem nebo nadrazenem rozdeleni
                '  FROM HierarchieRozdeleni H, RozdeleniOsob R ' .
                '  WHERE R.KodTypuRozdeleni = ' . $kodTypuRozdeleni .
                '    AND R.RC = VysledekHodnoceni.HodnocenyRC ' .
                '    AND H.TypNadrazene = ' . $kodTypuRozdeleni .
                "    AND H.KodNadrazene = '" . $this ->database ->addSlashes(HodnoceniFilterForm::getRozdeleniHodnoceni()) . "'" .
                '    AND H.KodPodrizene = R.Rozdeleni ' .
                ')';
        }

        // "Jen ucel hodnoceni"
        if (HodnoceniFilterForm::getJenUcelHodnoceni() && HodnoceniFilterForm::getUcelHodnoceni()) {
            if ($result) $result .= '  AND  ';

            $result .= ' (VysledekHodnoceni.KodUcelu = ' . (int)HodnoceniFilterForm::getUcelHodnoceni() . ') ';
        }

        // Obdobi
        if (RonPortalSession::getDatumOd()) {
            if ($result) $result .= ' AND ';
            $result .= ' VysledekHodnoceni.KonecObdobi >= ' . $this ->database ->dateToString(RonPortalSession::getDatumOd());
        }

        if (RonPortalSession::getDatumDo()) {
            if ($result) $result .= ' AND ';
            $result .= ' VysledekHodnoceni.PocatekObdobi <= ' . $this ->database ->dateToString(RonPortalSession::getDatumDo());
        }

        if (HodnoceniFilterForm::getFiltrovatZnamky()) {
            if ($result) $result .= ' AND ';
            $result .= ' VysledekHodnoceni.CelkovyVysledek >= ' . (float)HodnoceniFilterForm::getZnamkaOd() .
                ' AND VysledekHodnoceni.CelkovyVysledek <= ' . (float)HodnoceniFilterForm::getZnamkaDo();
        }


        return $result;
    }


    /**
     * zobrazi (pod)radky se slozkama hodnoceni
     * @param $idVysledku
     * @param $className
     * @param $jeUzavreno
     * @throws Exception
     */
    function zobrazSlozky($idVysledku, $className, $jeUzavreno)
    {
        $sql =
            "SELECT PripraveneTemaHodnoceni.ID, PripraveneTemaHodnoceni.Stav, " .
            "   PripraveneTemaHodnoceni.DatumHodnoceni, PripraveneTemaHodnoceni.Hodnotici, " .
            "   TemaHodnoceni.PopisTematu, HodnoceniOsoby.Znamka, HodnoceniOsoby.Koeficient " .

            " FROM ( HodnoceniOsoby INNER JOIN PripraveneTemaHodnoceni " .
            "        ON HodnoceniOsoby.ID = PripraveneTemaHodnoceni.ID " .
            "      ) " .
            "      INNER JOIN TemaHodnoceni " .
            "      ON TemaHodnoceni.DruhHodnoceni = PripraveneTemaHodnoceni.DruhHodnoceni " .
            "      AND TemaHodnoceni.TemaCislo = PripraveneTemaHodnoceni.TemaCislo " .
            " WHERE HodnoceniOsoby.IdVysledku = " . (int)$idVysledku .
            "   AND ( HodnoceniOsoby.IdNadrazenehoHodnoceni IS NULL  OR  HodnoceniOsoby.IdNadrazenehoHodnoceni = 0)";

        $cursor = $this ->database ->getSqlResult($sql);

        while ($row = $cursor ->fetch()) {
            echo "<tr class='$className'>";
            echo "<td></td><td></td><td class='hodnocenipodrobnosti'>" . $row[3] . "</td>"; // hodnotici
            echo "<td class='hodnocenipodrobnosti'><a href='?menuid=hodnoceni&backaction=vysledkyhodnoceni&record={$row[0]}'>" . StringUtils::htmlTextConvert($row[4]) . "</a></td>"; // popis tematu
            echo "<td colspan='2' class='hodnocenipodrobnosti'>" . DBUtils::getFormatedValue($this ->database, "finedatetime", $row[2]) . "</td>"; // datum hodnoceni
            // stav
            global $STR_H_0; // kompat.
            global $STR_H_1;
            global $STR_H_2;
            global $STR_H_3;
            global $STR_H_4;
            global $STR_H_5;

            echo "<td class='hodnocenipodrobnosti'>";
            switch ($row[1]) {
                case 0 :
                    echo $STR_H_0 ?: ronText('Stav_hodnoceni_0');
                    break;
                case 1 :
                    echo $STR_H_1 ?: ronText('Stav_hodnoceni_1');
                    break;
                case 2 :
                    echo $STR_H_2 ?: ronText('Stav_hodnoceni_2');
                    break;
                case 3 :
                    echo $STR_H_3 ?: ronText('Stav_hodnoceni_3');
                    break;
                case 4 :
                    echo $STR_H_4 ?: ronText('Stav_hodnoceni_4');
                    break;
                case 5 :
                    echo $STR_H_5 ?: ronText('Stav_hodnoceni_5');
                    break;
                default :
                    echo $row[1];
            }
            echo "</td>";

            if ( RonPortalSettings::getIntValue(RonPortalSettings::ZOBRAZIT_VYSLEDKY_HODNOCENI) & 1 ) // znamka nebo oboji
            {
                echo "<td class='hodnocenipodrobnosti align-right'>";
                if ($this->zobrazitPrubezneVysledky || $jeUzavreno) {
                    if ($row[5]) echo number_format($row[5], 2);
                }
                echo "</td>";
            }

            if ( RonPortalSettings::getIntValue(RonPortalSettings::ZOBRAZIT_VYSLEDKY_HODNOCENI) & 2 ) // koeficient nebo oboji
            {
                echo "<td class='hodnocenipodrobnosti align-right'>";
                if ($this->zobrazitPrubezneVysledky || $jeUzavreno) {
                    if ($row[6]) echo number_format($row[6], 2);
                }
                echo "</td>";
            }

            echo "</tr>\n";
        }
    }


    /**
     * @param array $values
     * @param string $className
     * @param int $rowNumber
     * @param bool $edit
     * @throws Exception
     */
    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        $this->zobrazSlozky($values[0], $className, $values[9]); // $values[9] - priznak, jestli je uzavreno

        $this->renderSeparator();
    }

}
