<?php

namespace RonPortal\Mzdy;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\RonPortal\BrowserProhlaseniPoplatnikaDane;
use Ron\RonPortal\DokumentyProhlaseniBrowser;
use Ron\RonPortal\ProhlaseniPoplatnikaDane;
use Ron\RonPortal\ZadostOZuctovaniZaloh;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Dokumenty\DokumentyUtils;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalSettings;
use RonPortal\RonPortalUtils;
use RonPortal\System\Report;
use RonPortal\System\ReportOutputObject;
use RonPortal\User;
use function Ron\ronText;

require_once ('mzdy/danecontroller.php');
require_once ('mzdy/zadostozuctovanizaloh.php');
require_once ('mzdy/prohlasenipoplatnikadane.php');

class DaneController extends \Ron\RonPortal\DaneController
{


    /** @var Database */
    public $database;

    /** @var PracovniPomer $pracovniPomer */
    public $pracovniPomer;


    /** @var PravaNaOsoby $pravo_vyplnit */
    public $pravo_prohlaseni;

    /** @var PravaNaOsoby $pravo_vyuctovani */
    public $pravo_vyuctovani;

    /**
     * DaneController constructor.
     * @param Database $database
     */
    public function __construct($database)
    {
        parent::__construct($database);
//        $this->database = $database;
//
//        $this->pravo_prohlaseni = Prava::vratPrava('dane_prohlaseni');
//        $this->pravo_vyuctovani = Prava::vratPrava('dane_vyuctovani');
    }

    /**
     * @param int $rok Rok vyuctovani dane
     * @return bool
     * @throws Exception
     */
    public static function lzeEditovatVyuctovani($rok)
    {
        if (RonPortalSettings::getIntValue('zadostizuctovanidanepoterminu')) {
            return true;
        }

        //editace vyuctovani za zvoleny rok je mozna od 1.1. nasledujiciho roku
        $editovatOd = DateUtils::incMonth($rok, 12);
        //do zvoleneho terminu v danem (nasledujicim) roce (napr. 28.2.) - pokud neni zadano bere se 31.3.
        $editovatDo = DateUtils::dateStringToTimestamp(RonPortalSettings::getValue('daneterminvyplneni', '31.3.') . date('Y', $editovatOd));

        if ((DateUtils::today() >= $editovatOd) && (DateUtils::today() <= $editovatDo)) {
            return true;
        }

        return false;
    }

    /** Vrati typ dokumentu pro zvolenou sekci
     * @param $sekce
     * @return int|mixed
     */
    public static function vratTypDokumentuProSekci($sekce)
    {
        switch ($sekce) {
            //vyuctovani
            case ZadostOZuctovaniZaloh::DOKUMENT_ZAMESTNAVATEL :
                return RonPortalSettings::getIntValue('dane_dokumenty_predchozizam_typ', -5);
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_PARTNER :
                return RonPortalSettings::getIntValue('dane_dokumenty_slevapartner_typ', -6);
            case ZadostOZuctovaniZaloh::DOKUMENT_SKOLKOVNE :
                return RonPortalSettings::getIntValue('dane_dokumenty_skolkovne_typ', -7);
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET :
                return RonPortalSettings::getIntValue('dane_dokumenty_odecitatelne_typ', -8);
            //prohlaseni
            case ProhlaseniPoplatnikaDane::DOKUMENT_DETI :
                return RonPortalSettings::getIntValue('dane_dokumenty_deti_typ', -2);
            case ProhlaseniPoplatnikaDane::DOKUMENT_PARTNER_NEUPLATNUJE :
                return RonPortalSettings::getIntValue('dane_dokumenty_partner_typ', -4);
            case ProhlaseniPoplatnikaDane::DOKUMENT_OBECNY :
            default :
                return RonPortalSettings::getIntValue('dane_dokumenty_odecet_typ', -3);
        }
    }

    /** Vrati true pokud je prilozeni dokumentu pro danou sekci povinne
     * @param string $sekce - casti formulare: deti, partner, odecet (slevy na dani)
     * @return int|mixed
     */
    public static function povinnyDokumentProSekci($sekce)
    {
        switch ($sekce) {
            //vyuctovani
            case ZadostOZuctovaniZaloh::DOKUMENT_ZAMESTNAVATEL :
                return RonPortalSettings::getIntValue('dane_dokumenty_predchozizam_povinne');
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_PARTNER :
                return RonPortalSettings::getIntValue('dane_dokumenty_slevapartner_povinne');
            case ZadostOZuctovaniZaloh::DOKUMENT_SKOLKOVNE :
                return RonPortalSettings::getIntValue('dane_dokumenty_skolkovne_povinne');
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET :
                return RonPortalSettings::getIntValue('dane_dokumenty_odecitatelne_povinne');
            //prohlaseni
            case ProhlaseniPoplatnikaDane::DOKUMENT_DETI :
                return RonPortalSettings::getIntValue('dane_dokumenty_deti_povinne');
            case ProhlaseniPoplatnikaDane::DOKUMENT_PARTNER_NEUPLATNUJE :
                return RonPortalSettings::getIntValue('dane_dokumenty_partner_povinne');
            case ProhlaseniPoplatnikaDane::DOKUMENT_OBECNY :
            default :
                return RonPortalSettings::getIntValue('dane_dokumenty_odecet_povinne');
        }
    }

    /** Vrati typ formulare (akci pro url) dle zvolene sekce.
     * @param string $sekce - casti formulare: deti, partner, odecet (slevy na dani)
     * @return string
     */
    public static function vratTypFormulareDleSekce($sekce)
    {
        switch ($sekce) {
            case ZadostOZuctovaniZaloh::DOKUMENT_ZAMESTNAVATEL :
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_PARTNER :
            case ZadostOZuctovaniZaloh::DOKUMENT_SKOLKOVNE :
            case ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET :
                return 'formularzadosti';
            case ProhlaseniPoplatnikaDane::DOKUMENT_DETI :
            case ProhlaseniPoplatnikaDane::DOKUMENT_PARTNER_NEUPLATNUJE :
            case ProhlaseniPoplatnikaDane::DOKUMENT_OBECNY :
            default :
                return 'formularprohlaseni';
        }
    }

    /**
     * @param Database $database
     * @param PracovniPomer $pracovniPomer
     * @param int $rok
     * @param int $typDokumentu
     * @param string $popisDokumentu
     * @return int
     * @throws DBException
     */
    public static function vratNovePoradoveCisloDokumentu($database, $pracovniPomer, $rok, $typDokumentu, $popisDokumentu = null)
    {
        $params = $database->createParameters();
        if (!is_null($popisDokumentu)) {
            $sql =
                "SELECT Popis FROM Dokument JOIN DokumentyOsoby ON Dokument.id = DokumentyOsoby.id 
                WHERE DokumentyOsoby.VyuctovaniDane_RC = " . $params->addParameter($pracovniPomer->rc) .
                "  AND DokumentyOsoby.VyuctovaniDane_Rok = " . $params->addDateParameter($rok) .
                "  AND Dokument.typ = " . $params->addParameter($typDokumentu) .
                "  AND Dokument.Popis LIKE " . $params->addParameter("%{$popisDokumentu}%") .
                " ORDER BY Dokument.id DESC";
            $posledniPopis = DBUtils::getSqlValue($database, $sql, $params);

            $posledniCislo = substr($posledniPopis, -1);
        } else {
            $sql =
                "SELECT COUNT(Dokument.id) FROM Dokument JOIN DokumentyOsoby ON Dokument.id = DokumentyOsoby.id 
                WHERE DokumentyOsoby.VyuctovaniDane_RC = " . $params->addParameter($pracovniPomer->rc) .
                "  AND DokumentyOsoby.VyuctovaniDane_Rok = " . $params->addDateParameter($rok) .
                "  AND Dokument.typ = " . $params->addParameter($typDokumentu);
            $posledniCislo = DBUtils::getSqlValue($database, $sql, $params);
        }

        return (int)$posledniCislo + 1;
    }

    /** Zobrazi seznam pripojenych dokumentu k sekci s moznosti vlozeni noveho.
     * @param Database $database
     * @param $rok
     * @param $pracovniPomer
     * @param string $sekceFormulare ke ktere casti jsou dokumenty mozne hodnoty: deti, partner, odecet
     * @param $povolitEditaci
     * @param $kontrolovatPovinnost
     * @throws DBException
     */
    public static function zobrazDokumenty($database, $rok, $pracovniPomer, $sekceFormulare, $povolitEditaci, $kontrolovatPovinnost = true, $castiSekce = null)
    {
        echo "<A name='dokumenty'></A>\n";

        $typDokumentu = self::vratTypDokumentuProSekci($sekceFormulare);
        $povinny = false;
        if ($kontrolovatPovinnost) {
            $povinny = self::povinnyDokumentProSekci($sekceFormulare);
        }

        if ($typDokumentu) {
            // Seznam dokumentu
            $b = new DokumentyVyuctovaniBrowser($database, $rok, $pracovniPomer, $typDokumentu, $povolitEditaci, $povinny, self::vratTypFormulareDleSekce($sekceFormulare));
            $b->load();
            $b->render();

            if ($povolitEditaci) {
                echo "<br/>";

                if (is_array($castiSekce)) {
                    foreach ($castiSekce as $cast => $popis) {
                        echo "<label for='{$sekceFormulare}_{$cast}'>$popis</label>
                            <span id='{$sekceFormulare}_{$cast}'><input type='file' name='{$sekceFormulare}_{$cast}'></span><br/>";
                    }
                } else {
                    echo "<label for='{$sekceFormulare}'>" . ronText('Vlozit_novy_dokument') . "</label>
                            <input type='file'  name='{$sekceFormulare}'>";
                    echo "<br/>";
                }
            }
        }
    }

    /** Zobrazi odkaz na pripojeni dokumentu k radku nezdanitelnych polozek (slev na dani). Umoznuje cislovani popisu dokumentu.
     * @param Database $database
     * @param int $rok
     * @param \RonPortal\PracovniPomer $pracovniPomer
     * @param string $castProhlaseni
     * @param string $popisDokumentu
     * @throws DBException
     */
    public static function zobrazOdkazPripojeniDokumentu($database, $rok, $pracovniPomer, $castProhlaseni, $popisDokumentu)
    {
        echo
            "<a href='#' title='" . TextManager::_('Vlozit_novy_dokument') . "'>" .
            "<i class='inline-glyph fa glyph-upload show-dokument-input-dialog' data-input-name='{$castProhlaseni}_{$popisDokumentu}' ></i> " .
            "</a>";
    }

//    /**
//     * @param ProhlaseniPoplatnikaDane $hodnotyProhlaseni
//     * @param array $historieOdpoctuNaDeti
//     * @return bool
//     */
//    public function jePovinnyDokument($hodnotyProhlaseni, $historieOdpoctuNaDeti)
//    {
//        $povinnyDokumentDeti = false;
//        if (self::povinnyDokumentProSekci('deti')) {
//            $povinnyDokumentDeti = true;
//
//            $odpocetNaDetiZmeny = $historieOdpoctuNaDeti['zmeny'];
//
//            if (empty($odpocetNaDetiZmeny) || count($odpocetNaDetiZmeny) == 0)
//                $povinnyDokumentDeti = false;
//
//            $uplatnujeOdpocetNaDite = false;
//            foreach ($odpocetNaDetiZmeny as $dite) {
//                if (($dite['datumOdNavrh'] != '' && $dite['poradiDitete_navrh'] != '') || ($dite['datumOd'] != '' && $dite['poradiDitete'] != '')) {
//                    $uplatnujeOdpocetNaDite = true;
//                    break;
//                }
//            }
//            if (!$uplatnujeOdpocetNaDite)
//                $povinnyDokumentDeti = false;
//        }
//
//        if ($povinnyDokumentDeti
//            || self::povinnyDokumentProSekci('partner')
//            || (self::povinnyDokumentProSekci('odecet') && (($hodnotyProhlaseni->naZdravotniStav != $hodnotyProhlaseni->naZdravotniStavNavrh)
//                    || ($hodnotyProhlaseni->odpocetNaStudenta != $hodnotyProhlaseni->naZdravotniStavNavrh))))
//            return true;
//
//        return false;
//    }
//
//    public function zkontrolujPovinneDokumentyProhlaseni($rok, $hodnoty)
//    {
//        $typ = RonPortalSettings::getIntValue('dane_dokumenty_deti_typ');
//        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_deti_povinne') && ($hodnoty['pocetdetipoplatnika'] > 0)) {
//            $diteStr = isset($hodnoty['pozaduji_upravu_poradi_ditete']) ? 'poradi_ditete_navrh_' : 'poradi_ditete_old_';
//            $uplatnujeOdecet = false;
//            for ($i = 0; $i < $hodnoty['pocetdetipoplatnika']; $i++) {
//                if ($hodnoty["$diteStr{$i}"] > 0)
//                    $uplatnujeOdecet = true;
//            }
//            //kontrola pripojeneho dokumentu, jen pokud u nektereho z deti uplatnuje odecet
//            if ($uplatnujeOdecet) {
//                $this->jePripojenyDokument($typ, $rok);
//            }
//        }
//
//        //TODO: kontrolovat povinnost jen pokud je zadana zmena na invaliditu nebo studenta
//        $typ = RonPortalSettings::getIntValue('dane_dokumenty_odecet_typ');
//        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_odecet_povinne') && $this->jeZmenaSlev($hodnoty))
//            $this->jePripojenyDokument($typ, $rok);
//
//        $typ = RonPortalSettings::getIntValue('dane_dokumenty_partner_typ');
//        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_partner_povinne'))
//            $this->jePripojenyDokument($typ, $rok);
//    }
//
    public function zkontrolujPovinneDokumentyVyuctovani($rok, $hodnoty)
    {
        $typ = RonPortalSettings::getIntValue('dane_dokumenty_skolkovne_typ', -7);
        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_skolkovne_povinne') && ($hodnoty['pocetdetipoplatnika'] > 0)) {
            $uplatnujeSkolkovne = false;
            for ($i = 0; $i < $hodnoty['pocetdetipoplatnika']; $i++) {
                $rcDitete = $hodnoty['ditepoplatnika_' . $i];
                $skolkovneNaDite = $hodnoty['skolkovnenadite_' . $rcDitete];
                if ($skolkovneNaDite > 0)
                    $uplatnujeSkolkovne = true;
            }
            //kontrola pripojeneho dokumentu, jen pokud u nektereho z deti uplatnuje odecet
            if ($uplatnujeSkolkovne) {
                $this->jePripojenyDokument($typ, $rok);
            }
        }

        $typ = RonPortalSettings::getIntValue('dane_dokumenty_odecitatelne_typ', -8);
        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_odecitatelne_povinne')) {
            if (($hodnoty['zadostdaryvyse'] != "" && $hodnoty['zadostdaryvyse'] > 0) ||
                ($hodnoty['zadosturokyvyse'] != "" && $hodnoty['zadosturokyvyse'] > 0) ||
                ($hodnoty['zadostpenzijnivyse'] != "" && $hodnoty['zadostpenzijnivyse'] > 0) ||
                ($hodnoty['zadostpojistnevyse'] != "" && $hodnoty['zadostpojistnevyse'] > 0) ||
                ($hodnoty['zadostclenskevyse'] != "" && $hodnoty['zadostclenskevyse'] > 0) ||
                ($hodnoty['zadostuhradazazkouskyvyse'] != "" && $hodnoty['zadostuhradazazkouskyvyse'] > 0) )
            $this->jePripojenyDokument($typ, $rok);
        }

        $typ = RonPortalSettings::getIntValue('dane_dokumenty_slevapartner_typ', -6);
        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_slevapartner_povinne')) {
            if (isset($hodnoty['slevanapartnera']) && ($hodnoty['slevanapartnera'] !== '')) {
                $this->jePripojenyDokument($typ, $rok);
            }
        }

        $typ = RonPortalSettings::getIntValue('dane_dokumenty_predchozizam_typ', -6);
        if ($typ && RonPortalSettings::getIntValue('dane_dokumenty_predchozizam_povinne')) {
            if (($hodnoty['predchoziplatcedaneadresa_0'] !== '') || ($hodnoty['predchoziplatcedaneadresa_1'] !== '') || ($hodnoty['predchoziplatcedaneadresa_2'] !== '')) {
                $this->jePripojenyDokument($typ, $rok);
            }
        }
    }

    /** Zkontroluje zda je k vyctovani zvoleneho roku pripojen dokument daneho typu.
     * @param $typDokumentu
     * @param $rok
     * @return void
     * @throws DBException
     */
    public function jePripojenyDokument($typDokumentu, $rok)
    {
        $params = $this->database->createParameters();
        $sql =
            'SELECT DokumentyOsoby.Id ' .
            '  FROM DokumentyOsoby JOIN Dokument ON (Dokument.Id = DokumentyOsoby.Id) ' .
            ' WHERE DokumentyOsoby.RC =  ' . $params->addParameter($this->pracovniPomer->rc) .
            '   AND DokumentyOsoby.VyuctovaniDane_Rok = ' . $params->addParameter($this->database->dateToParam($rok)) .
            '   AND DokumentyOsoby.VyuctovaniDane_RC = ' . $params->addParameter($this->pracovniPomer->rc) .
            '   AND Dokument.typ = ' . $params->addParameter($typDokumentu);

        if (!$cursor = $this->database->select($sql, $params)) {
            throw new DBException($this->database, $sql);
        }

        $row = $cursor ->fetch();
        if (!$row) {
            $params = $this->database->createParameters();
            $typDokumentuPopis = DBUtils::getSqlValue($this->database, "SELECT Popis FROM TypDokumentu WHERE kod = " . $params->addParameter($typDokumentu), $params);
            throw new Exception(sprintf(ronText('Prohlaseni_neexistuje_povinny_dokument'), $typDokumentuPopis));
        }
    }

//    public function jeZmenaSlev($hodnoty)
//    {
//        if (isset($hodnoty['pozaduji_upravu_slev']) && (($hodnoty['sleva_na_zdravotni_stav1'] != $hodnoty['sleva_na_zdravotni_stav1_old'])
//                || ($hodnoty['sleva_na_zdravotni_stav2'] != $hodnoty['sleva_na_zdravotni_stav2_old']) || ($hodnoty['sleva_na_studenta_nova'] != $hodnoty['odpocetNaStudenta_old'])))
//            return true;
//
//        return false;
//    }

    /**
     * @return Redirect|BrowserProhlaseniPoplatnikaDane
     * @throws DBException
     */
    public function browserProhlaseniPoplatnikaDane()
    {
        $osoba = isset($_GET['osoba']) ? $_GET['osoba'] : '';
        //Pokud se jedna o dny kdy jeste nebylo vytvoreno obdobi pak nemusi jeste existovat zaznam o rocnim vyuctovani dane, proto zkontrolovat
        $obdobi = DateUtils::firstDayOfYear(DateUtils::today());         //1.1.aktu.roku

        //14.2.2022 zrusena kontrola na PP se zdanenim po dohode s Radovanem Kulou, nove se nacitaji PP platne v minulem a aktualnim roce
        //Kontrola na PP se zdanenim, musí existovat alespon jeden
        /*$ppSeZdanenim = $this->kontrolaNaVicePracovnichPomeruSeZdanenim($this->database, $obdobi);
        if (empty($ppSeZdanenim)){
            //Pokud existuje pak neni jiste zda je tento PP prirazen k RVD, tedy pokusi se najit PP v RVD, pokud tam nebude pak se pravdepodobne jedna o 1. pristup
            //a nutno vyzvat uzivatele k vyberu PP, tedy v pripade ze se nejedná o zamestnance s prave jednim PP
            throw new Exception(StringUtils::fromUTF8("Neexistuje pracovní poměr pro zdanění! Informujte prosím mzdového pracovníka."));
        }*/

        //Pokud je v URL osoba pak jiz nekontrolovat
        if ($osoba != "") {
            //Kontroly zda je vytvoreno, zda ma nastaveno IDPP, zda existuje vice PP a zaroven neni nastaveno IDPP v RVD
            //Pred zobrazenim browseru overi zda existuje zaznam na aktualni rok, pokud neni pak ho doplni a pouzije hodnoty z lonska pokud jsou k dispozici
            $this->kontrolaZaznamuRocnihoVyuctovaniDane($osoba, $obdobi);
        } else {
            $osoba = $this->nactiPracovniPomerZRocnihoVyuctovaniDane($obdobi);
            if (!is_null($osoba)) {
                $pp = PracovniPomer::nactiPP($this->database, $osoba);
                $pp->vyberNactenyPP();
            } else {
                $seznamPPosoby = PracovniPomer::nactiPPOsoby($this->database, User::getRC());
                //pokud ma uzivatel jen jeden PP, pak vytvorit zaznam vyuctovani z kopie predchoziho
                if (count($seznamPPosoby) == 1) {
                    $osoba = $seznamPPosoby[0];
                    $this->kontrolaZaznamuRocnihoVyuctovaniDane($osoba->idPP, $obdobi);
                }
            }
        }

        //Pokud je vic PP a neni v RVD urcen konkretni pak se vypise hlaska a uzivatel se vyzve aby jeden zvolil.
        require_once ('mzdy/b_prohlasenipoplatnikadane.php');
        $b = new BrowserProhlaseniPoplatnikaDane($this->database, null, $obdobi);
        $b->load();

        return $b;
    }

    /**
     * @param $obdobi
     * @param $idPP
     * @return BaseViewObject
     * @throws DBException
     * @throws NeniPravoException
     */
    public function zobrazitFormularZadostiOZuctovaniDane($obdobi, $idPP)
    {
        //Načte PP
        $this->pracovniPomer = new PracovniPomer();
        $this->pracovniPomer->nactiPPPodleId($this->database, $idPP);

        //Kontrola práv - nejdříve se hledá pp pro zdanění, pokud je nalezen je dle jeho ID načten příslušný pp
        if (!($this->pravo_vyuctovani->lzeZobrazitRC($this->pracovniPomer->rc))) {
            throw new NeniPravoException();
        }

        require_once 'mzdy/zadostozuctovanizaloh.php';
        $hodnotyZadosti = ZadostOZuctovaniZaloh::nactiZadost($this->database, $this->pracovniPomer, $obdobi);

        $chybaPP = false;
        if ($hodnotyZadosti->zadostPortalStav == 3)
        {
            //Formulář nelze vyplnit, dokud nebude opraveno mzdovým pracovníkem
            $chybaPP = true;
        }

        Model::addData('database', $this->database);

        //TODO datumObdobiRok a datumObdobi_timestamp sjednotit !
        Model::addData('datumObdobiRok', $obdobi);
        Model::addData('datumObdobi_timestamp', $obdobi);
        Model::addData('chybaPP', $chybaPP);
        Model::addData('hodnotyZadosti', $hodnotyZadosti);
        Model::addData('volby_comboboxu', $this->volbyComboBoxuZadostiAProhlaseni());
        Model::addData('adresa', $this->aktualniAdresaPoplatnika($obdobi));
        Model::addData('pracovniPomer', $this->pracovniPomer);
        Model::addData('partnerPoplatnika', $this->nactiPartneraPoplatnika($this->database, $this->pracovniPomer, $obdobi));

        require_once 'mzdy/prohlasenipoplatnikadane.php';
        $hodnotyProhlaseni = ProhlaseniPoplatnikaDane::nactiProhlaseni($this->database, $this->pracovniPomer, $obdobi);
        Model::addData('detiPoplatnika', $this->nactiOdpocetNaDeti($hodnotyProhlaseni, $this->pracovniPomer));
        Model::addData('nastaveniOdpoctu', NastaveniOdpoctu::nactiNastaveni($this->database, $obdobi));

        Model::addData('reportlist', Report::loadFormReports($this->database, 'DaneVyuctovani'));

        return new BaseViewObject("mzdy/view_zadostozuctovanizaloh.php");
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return void
     */
    public function aktualizaceVypoctuVyuctovani($rec)
    {
        if ($rec->findFieldByName('OpravaHodnotDaru')->isChanged() ||
            $rec->findFieldByName('OpravaUrokuZeStavebSpor')->isChanged() ||
            $rec->findFieldByName('OpravaPenzijnihoPrip')->isChanged() ||
            $rec->findFieldByName('ZivotniPojisteni')->isChanged() ||
            $rec->findFieldByName('OpravaClenskychPrispevku')->isChanged() ||
            $rec->findFieldByName('OpravaUhradZaZkousky')->isChanged() ||
            $rec->findFieldByName('PocetMesicuOdpoctu')->isChanged() ||
            $rec->findFieldByName('Skolkovne')->isChanged()
        ) {
            $rec->addField('AktualizovatVypocet', 'int', false, 0, 1);
        }
    }

    /**
     * @return \Ron\MVC\BaseViewObject|Redirect
     * @throws DBException
     * @throws NeniPravoException
     */
    public function zapisZadosti()
    {
        $rok = $_POST['datumobdobi'];
        //Kontrola zda nedošlo k submitu po termínu
        if (!static::lzeEditovatVyuctovani($rok)) {
            throw new NeniPravoException();
        }

        //Kontrola zdali žádost nebyla schválena mzdovým pracovníkem v průběhu editace formuláře
        $this->kontrolaJizSchvaleneZadosti();

        $hodnoty = $this->nactiPOSTZadosti();

        $this->pracovniPomer = PracovniPomer::nactiPP($this->database, (int)$hodnoty["osoba"]);

        try {
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_ZAMESTNAVATEL, $rok, $this->pracovniPomer, $this->pravo_vyuctovani);
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_PARTNER, $rok, $this->pracovniPomer, $this->pravo_vyuctovani);
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SKOLKOVNE, $rok, $this->pracovniPomer, $this->pravo_vyuctovani);
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_dary');
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_uroky');
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_penzijni');
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_zivotni');
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_clenske_prispevky');
            $this->dokumentUpload(ZadostOZuctovaniZaloh::DOKUMENT_SLEVA_ODECET, $rok, $this->pracovniPomer, $this->pravo_vyuctovani, '_zkousky');

            $this->zkontrolujPovinneDokumentyVyuctovani($rok, $hodnoty);
        } catch (Exception $exception) {
            MessageManager::addErrorMessage($exception);
            return $this->zobrazitFormularZadostiOZuctovaniDane($rok, $this->pracovniPomer->idPP);
        }

        //Pokud ještě není žádost schválená pak spočítat školkovné - a zapsat sumu
        $sumaSkolkovnehoProVyuctovaniDane = 0;

        if ($hodnoty['pocetdetipoplatnika'] > 0) {
            for ($i = 0; $i < $hodnoty['pocetdetipoplatnika']; $i++) {

                $rcDitete = $hodnoty['ditepoplatnika_' . $i];
                //Pokud pres kontrolu klienta projde skolkovne vetsi nez max. pak nastavit na max
                $skolkovneNaDite = min($hodnoty['skolkovnenadite_' . $rcDitete], $hodnoty['skolkovne_max']);
                $skolkovneNaDitePuvodni = $hodnoty['skolkovnenaditeold_' . $rcDitete];

                if (is_numeric($skolkovneNaDite)) {
                    $sumaSkolkovnehoProVyuctovaniDane += $skolkovneNaDite;
                }

                if ($skolkovneNaDite !== $skolkovneNaDitePuvodni) {
                    $params = $this->database->createParameters();

                    $rec = new RonPortalDBRecord($this->database, 'SkolkovneNaDite');
                    $rec->logDescription = 'Skolkovne na dite poplatnika - portal';

                    $rec->addField('Rok', 'timestamp', true, 0, $rok);
                    $rec->addField('RC', '', true, 15, $this->pracovniPomer->rc);
                    $rec->addField('RC_RodinnehoPrislusnika', '', true, 15, $rcDitete);
                    $rec->addField('Skolkovne', 'float', false, 0, (int)$skolkovneNaDite);

                    $rec->setWhere(
                        'Rok = ' . $params->addParameter($this->database->timestampToParam($rok)) .
                        ' AND RC = ' . $params->addParameter($this->pracovniPomer->rc) .
                        ' AND RC_RodinnehoPrislusnika = ' . $params->addParameter($rcDitete), $params);

                    try {
                        $rec->updateOrInsert();
                    }
                    catch (Exception $exception) {
                        throw new Exception(StringUtils::fromUTF8('Chyba při zápisu/aktualizaci školkovného: ' . $exception->getMessage()));
                    }
                }
            }
        }


        $rec = new RonPortalDBRecord($this->database,'RocniVyuctovaniDane');
        $rec->logDescription = 'Rocni vyuctovani dane poplatnika - portal';


        $termin = mktime(0,0,0,2,15, (int)date("Y", time()));
        $aktualniDatum = time();
        $datumPortal = ($termin < $aktualniDatum) ? $termin : $aktualniDatum;
        $stav = isset($hodnoty['podepsatzadost']) ? 1 : 0;

        $rec->addField('ProvestRocniVyuctovani', 'int', false, 0, 1);
        $rec->addField('ZadostPortalStav', 'int', false, 0, $stav);
        $rec->addField('AdresaBytovePotrebyUveru', 'memo', false, 0, $hodnoty['zadostbytovepotrebyuveruadresa']);
        $rec->addField('OpravaHodnotDaru', 'float', false, 0, $hodnoty['zadostdaryvyse'] != "" && $hodnoty['zadostdaryvyse'] > 0 ? $hodnoty['zadostdaryvyse'] : 0);
        $rec->addField('OpravaUrokuZeStavebSpor', 'float', false, 0, $hodnoty['zadosturokyvyse'] != "" && $hodnoty['zadosturokyvyse'] > 0 ? $hodnoty['zadosturokyvyse'] : 0);
        $rec->addField('OpravaPenzijnihoPrip', 'float', false, 0, $hodnoty['zadostpenzijnivyse'] != "" && $hodnoty['zadostpenzijnivyse'] > 0 ? $hodnoty['zadostpenzijnivyse'] : 0);
        $rec->addField('ZivotniPojisteni', 'float', false, 0, $hodnoty['zadostpojistnevyse'] != "" && $hodnoty['zadostpojistnevyse'] > 0 ? $hodnoty['zadostpojistnevyse'] : 0);
        $rec->addField('OpravaClenskychPrispevku', 'float', false, 0, $hodnoty['zadostclenskevyse'] != "" && $hodnoty['zadostclenskevyse'] > 0 ? $hodnoty['zadostclenskevyse'] : 0);
        $rec->addField('OpravaUhradZaZkousky', 'float', false, 0, $hodnoty['zadostuhradazazkouskyvyse'] != "" && $hodnoty['zadostuhradazazkouskyvyse'] > 0 ? $hodnoty['zadostuhradazazkouskyvyse'] : 0);
        $rec->addField('OsobyUplatnujiciUver', 'memo', false, 0, $this->sestaveniOsobUplatnujicichUverZHodnot($hodnoty));
        $rec->addField('PredchoziPrijmyKdyOdKoho', 'memo', false, 0, $this->sestaveniPredchozichPrijmuKdyOdKohoZHodnot($hodnoty));
        $rec->addField('Skolkovne', 'float', false, 0, (float)$sumaSkolkovnehoProVyuctovaniDane);

        $rec->addField('DatumZadostiPortal', 'timestamp', false, 0, $datumPortal);

        //pri kliknuti na schvalit se zapise i elektronicky podpis
        if ($stav == 1) {
            $rec->addField('ElektronickyPodpisZadost', 'memo', false, 0, $this->signaturaUzivatele());
        }

        $partnerZtpMesicu = 0;
        $partnerMesicu = 0;
        $slevaNaPartneratext = '';

        //Zápis ve formě mm-mm;mm-mm
        if (isset($hodnoty['slevanapartnera']) && ($hodnoty['slevanapartnera'] !== "" )) {
            $slevaNaPartneratext = $this->kontrolaRozsahuMesicu($hodnoty['slevanapartnera']) . ";" . (isset($hodnoty['slevanapartneraproztp']) ? $this->kontrolaRozsahuMesicu($hodnoty['slevanapartneraproztp']) : '');

            $partnerMesiceOd = (int)(explode("-", $hodnoty['slevanapartnera'])[0]);
            $partnerMesiceDo = (int)(explode("-", $hodnoty['slevanapartnera'])[1]);

            $partnerMesicu = $partnerMesiceDo - $partnerMesiceOd;
            $partnerMesicu += 1;
        }

        //Zápis ve formě mm-mm;mm-mm
        if (isset($hodnoty['slevanapartneraproztp']) && ($hodnoty['slevanapartneraproztp'] !== "")) {
            $partnerZtpMesiceOd = (int)(explode("-", $hodnoty['slevanapartneraproztp'])[0]);
            $partnerZtpMesiceDo = (int)(explode("-", $hodnoty['slevanapartneraproztp'])[1]);

            $partnerZtpMesicu = $partnerZtpMesiceDo - $partnerZtpMesiceOd;
            $partnerZtpMesicu += 1;
        }

        if ($partnerZtpMesicu > $partnerMesicu) {
            throw new Exception(ronText('zadost_chyba_pocet_mesicu_ztp_partnera'));
        }

        $rec->addField('UplatnujeOdpocetPartnera', 'int', false, 0, isset($hodnoty['slevanapartnera']) && ($hodnoty['slevanapartnera'] !== ""));

        $rec->addField('SlevaPartnerObdobi', '', false, 15, $slevaNaPartneratext);
        $rec->addField('PocetMesicuOdpoctu', 'int', false, 0, $partnerMesicu);
        $rec->addField('PartnerZTPP', 'int', false, 0, $partnerZtpMesicu);

        $params = $this->database->createParameters();
        $sqlWhere =
            ' RC = ' . $params->addParameter($this->pracovniPomer->rc) .
            ' AND Rok = ' . $params->addParameter($this->database->timestampToParam($rok));

        $rec->setWhere($sqlWhere, $params);

        $rec->loadRecord();

        $this->aktualizaceVypoctuVyuctovani($rec);

        if (!$rec->updateRecord()) {
            throw new Exception(ronText("chyba_aktualizace_rocniho_vyuctovani"));
        }

        //jen uložení, znovu zobrazí formulář
        if ($stav == 0) {
            return new Redirect(null, "?menuid=dane&action=formularzadosti&obdobi=$rok&osoba={$this->pracovniPomer->idPP}");
        }

        return new Redirect(null, "?menuid=dane");
    }

    public function zapisProhlaseni()
    {
        $hodnoty = $this->nactiPOSTProhlaseni();

        $rok = (mktime(0,0,0,1,1,$hodnoty["datumobdobi"]));

        $pracovniPomer = PracovniPomer::nactiPP($this->database, $hodnoty["osoba"]);
        $this->pracovniPomer = $pracovniPomer;

        if (!($this->pravo_prohlaseni->lzeZobrazitRC($pracovniPomer->rc))){
            throw new NeniPravoException();
        }

        //Kontrola zdali prohlášení nebylo schváleno mzdovým pracovníkem v průběhu editace formuláře prohlášení
        $this->kontrolaJizSchvalenehoProhlaseni($rok);

        //kontrola "ProhlaseniElektronicky"
        $this->kontrolaZdaLzePodepsatElektronicky($rok);

        try {
            $this->dokumentUpload(ProhlaseniPoplatnikaDane::DOKUMENT_OBECNY, $rok, $this->pracovniPomer, $this->pravo_prohlaseni);
            $this->dokumentUpload(ProhlaseniPoplatnikaDane::DOKUMENT_DETI, $rok, $this->pracovniPomer, $this->pravo_prohlaseni);
            $this->dokumentUpload(ProhlaseniPoplatnikaDane::DOKUMENT_PARTNER_NEUPLATNUJE, $rok, $this->pracovniPomer, $this->pravo_prohlaseni);

            $this->zkontrolujPovinneDokumentyProhlaseni($rok, $hodnoty);
        } catch (Exception $exception) {
            MessageManager::addErrorMessage($exception);
            return $this->zobrazitFormularProhlaseni($this->pracovniPomer->idPP, $rok, isset($_GET['zmenovacast']));
        }

        //Pokud je ma RVD v polich ProhlaseniPortalRC, ProhlaseniPortalOsc, ProhlaseniPortalDatNastup jiny IDPP nez je vybran ve
        //..filtru Osoby, pak nastavit $zmenaPPIDRVD na true a odstranit pozadovane navolene zmeny slev na dani
        $zmenaPPIDRVD = ((int)$hodnoty["prohlaseniPPID"] != (int)$hodnoty["osoba"] ? true: false);


        $this->ukliditPoZmenePracovnihoPomeruVRocniVyuctovaniDane($pracovniPomer, $hodnoty, $zmenaPPIDRVD);

        $stav = isset($hodnoty['podepsatprohlaseni']) ? 1 : 0;

        //RocniVyuctovaniDane ---------------------------------------------------
        $rec = new RonPortalDBRecord($this->database,'RocniVyuctovaniDane');
        $rec->logDescription = 'Zapis prohlaseni poplatnika dane (podepsani) - portal';

        //zapise se jen pri podepsani, ne pri ulozeni
        if ($stav == 1) {
            $rec->addField('DatumProhlaseniPortal', 'timestamp', false, 0, time());
        }
        //Uzivatel muze prohlaseni "nepodepsat"
        $rec->addField('ProhlaseniPortalStav', 'int', false, 0, 0);
        $rec->addField('ProhlaseniPortal', 'int', false, 0, $hodnoty['prohlasenikdanicinim']);
        $rec->addField('ElektronickyPodpis', 'memo', false, 0, $this->signaturaUzivatele());

        $rec->addField('VyzivujeJinyPoplatnik', 'int', false, 0, (int)$hodnoty['vyzivujeJinyPoplatnik']);
        $rec->addField('JinyPoplatnikUplatnujeZv', 'int', false, 0, (int)$hodnoty['jinyPoplatnikUplatnujeZv']);
        $rec->addField('JinyPoplatnikZamestnani', 'int', false, 0, (int)$hodnoty['jinyPoplatnikZamestnani']);
        $rec->addField('JinyPoplatnikJmeno', '', false, 30, $hodnoty['jinyPoplatnikJmeno']);
        $rec->addField('JinyPoplatnikPrijmeni', '', false, 40, $hodnoty['jinyPoplatnikPrijmeni']);
        $rec->addField('JinyPoplatnikRC', '', false, 15, $hodnoty['jinyPoplatnikRC']);

        $rec->addField('JinyPoplatnikObec', '', false, 80, $hodnoty['jinyPoplatnikObec']);
        $rec->addField('JinyPoplatnikPSC', '', false, 10, $hodnoty['jinyPoplatnikPSC']);
        $rec->addField('JinyPoplatnikUlice', '', false, 80, $hodnoty['jinyPoplatnikUlice']);

        $rec->addField('JinyPoplatnikNazevPlatce', '', false, 120, $hodnoty['jinyPoplatnikNazevPlatce']);
        $rec->addField('JinyPoplatnikObecPlatce', '', false, 80, $hodnoty['jinyPoplatnikObecPlatce']);
        $rec->addField('JinyPoplatnikUlicePlatce', '', false, 80, $hodnoty['jinyPoplatnikUlicePlatce']);
        $rec->addField('JinyPoplatnikPSCPlatce', '', false, 10, $hodnoty['jinyPoplatnikPSCPlatce']);

        $params = $this->database->createParameters();
        $sqlWhere =
            ' RC = ' . $params->addParameter($pracovniPomer->rc) .
            " AND Rok = " . $params->addParameter($this->database->timestampToParam($rok));

        $rec->setWhere($sqlWhere, $params);
        $rec->loadRecord();


        //Nastavi se az pri podepsani a pouze tehdy kdyz NENI Prohlaseni schvaleno mzdovym pracovnikem
        //Pole muze menit dokud nebude schvaleno mzdovym pracovnikem
        if ($rec->findFieldByName('ProhlaseniPortalStav')->value != 1){
            $rec->addField('ProhlaseniPortalRC', '', false, 15, $pracovniPomer->rc);
            $rec->addField('ProhlaseniPortalOsc', '', false, 15, $pracovniPomer->osobniCislo);
            $rec->addField('ProhlaseniPortalDatNastup', 'timestamp', false, 0, $pracovniPomer->datumNastupu);
        }


        if (!$rec->updateRecord()) {
            throw new Exception(ronText("chyba_aktualizace_prohlaseni"));
        }
        //RocniVyuctovaniDane ---------------------------------------------------



        //OdpocetNavrh - pokud došlo ke změně požadovaných slev -----------------
        //datum od - bude datum hlášené změny a poté již bude použit tento datum (při opětovném otevření bude hledán datum v rámci 1.1. - 31.12.)

        if ($hodnoty['prohlasenikdanicinim'])
        {
            //Pokud ano, pak zapsat zmeny
            if ($hodnoty["pozaduji_upravu_slev"]) {
                $datumOdOdpocetNavrh = $hodnoty["datumOdOdpocetNavrh"] != "" ? $hodnoty["datumOdOdpocetNavrh"] : DateUtils::today();
                //Zde OdpocetNavrh a OdpocetPuvodni je stejny, rozdilne mohou byt pouze u zmen, kde lze zadat jiny mesic nez ktery je aktualni
                $datumOdOdpocetPuvodni = $datumOdOdpocetNavrh;
                $datumVlozeniNavrhu = $hodnoty["datumVlozeniNavrhu"] != "" ? $hodnoty["datumVlozeniNavrhu"] : time();
                $slevaNaZdravotniStav = ($hodnoty["sleva_na_zdravotni_stav2"] == 1 ? 2 : ($hodnoty["sleva_na_zdravotni_stav1"] == 1 ? 1 : 0));

                //OdpocetNavrh ------------------------------------------------------
                $this->zapisOdpocetNavrh($pracovniPomer,
                    $datumOdOdpocetPuvodni,
                    $datumOdOdpocetNavrh,
                    $datumVlozeniNavrhu,
                    $hodnoty["sleva_zakladni_nova"],
                    $hodnoty["sleva_na_studenta_nova"],
                    $slevaNaZdravotniStav,
                    $hodnoty['sleva_ztpp'],
                    'Prohlaseni poplatnika dane a navrh odpoctu - portal');
            }


            //OdpocetNaDiteNavrh - pokud došlo ke změně poradi slev u ditete --------
            if ($hodnoty["pocetdetipoplatnika"] > 0) {
                for ($i = 0; $i < $hodnoty["pocetdetipoplatnika"]; $i++) {
                    $rcDitete = $hodnoty["dite_" . $i];
                    $datumOd = $hodnoty["old_datumOdNavrh_na_dite_" . $i] != "" ? $hodnoty["old_datumOdNavrh_na_dite_" . $i] : DateUtils::today();
                    $puvodniPoradi = $hodnoty["poradi_ditete_old_" . $i];
                    $novePoradi = $hodnoty["poradi_ditete_navrh_" . $i];

                    $datumVlozeniNavrhu = (int)$hodnoty["old_datumVlozeniNavrhu_na_dite_$i"] != "" ? $hodnoty["old_datumVlozeniNavrhu_na_dite_$i"] : time();

                    if ($puvodniPoradi != $novePoradi && $novePoradi != "") {
                        $this->zapisOdpocetNaDiteNavrh($pracovniPomer, $rcDitete, $datumOd, $datumOd, $datumVlozeniNavrhu, $novePoradi, 'Prohlaseni poplatnika dane a zmena odpoctu na deti - portal');
                    }
                }
            }
        }

        //Pokud doslo ke zmene osoby v RVD pak tuto osobu nacist do url
        $osobaDoURL = $zmenaPPIDRVD ? $hodnoty["osoba"] : $hodnoty["prohlaseniPPID"];

        //jen uložení, znovu zobrazí formulář
        if ($stav == 0) {
            return new Redirect(null, "?menuid=dane&action=formularprohlaseni&osoba=$osobaDoURL&obdobi=$rok");
        }

        return new Redirect(null, "?menuid=dane&osoba=$osobaDoURL");
    }

    function dokumentUpload($castProhlaseni, $rok, $pracovniPomer, $prava, $suffix = '')
    {
        if ($_FILES[$castProhlaseni . $suffix]['error'] !== UPLOAD_ERR_OK) {
            return;
        }

        $datumOd = $rok;
        $datumDo = DateUtils::incDay(DateUtils::incMonth($datumOd, 12), -1);
        Prava::nastavObdobiProPrava($datumOd, $datumDo);

        if (!$this->pracovniPomer->lzeZobrazitPP($prava)) {
            throw new NeniPravoException();
        }

        $typDokumentu = static::vratTypDokumentuProSekci($castProhlaseni);
        $params = $this->database->createParameters();
        $popisTypu = DBUtils::getSqlValue($this->database, "SELECT Popis FROM TypDokumentu WHERE kod = " . $params->addParameter($typDokumentu), $params);
        $popisTypu = ronText($popisTypu);
        $popisDokumentu = null;

        $popis = RonPortalSettings::getValue('dane_dokumenty_maska', '%TYPDOKUMENTU% %PORADOVECISLO%');

        if ($suffix !== '') {
            $popisDokumentu = substr($suffix, 1);

            switch ($popisDokumentu) {
                case 'dary':
                    $popisDokumentu = ronText('zadost_dary_pripojeni_dokumentu');
                    break;
                case 'uroky':
                    $popisDokumentu = ronText('zadost_uroky_pripojeni_dokumentu');
                    break;
                case 'penzijni':
                    $popisDokumentu = ronText('zadost_penzijni_pripojeni_dokumentu');
                    break;
                case 'zivotni':
                    $popisDokumentu = ronText('zadost_zivotni_pripojeni_dokumentu');
                    break;
                case 'clenske_prispevky':
                    $popisDokumentu = ronText('zadost_clenske_pripojeni_dokumentu');
                    break;
                case 'zkousky':
                    $popisDokumentu = ronText('zadost_zkousky_pripojeni_dokumentu');
                    break;
            }

            $popisTypu = "{$popisTypu} - {$popisDokumentu}";
        }

        $noveCislo = static::vratNovePoradoveCisloDokumentu($this->database, $pracovniPomer, $rok, $typDokumentu, $popisDokumentu);

        $popis = str_replace(
            ['%JMENO%', '%PRIJMENI%', '%OSOBNICISLO%', '%IDOSOBY%', '%IDPP%', '%DATUM%', '%TYPDOKUMENTU%', '%PORADOVECISLO%'],
            [$pracovniPomer->jmeno, $pracovniPomer->prijmeni, $pracovniPomer->osobniCislo, $pracovniPomer->rc, $pracovniPomer->idPP, date('j.n.Y', time()), $popisTypu, $noveCislo],
            $popis);

        // vlozi do databaze obsah dokumentu
        $id = DokumentyUtils::vlozDokument($this ->database, $castProhlaseni . $suffix, $typDokumentu, $popis, $this);

        $rec = new RonPortalDBRecord($this ->database, 'DokumentyOsoby', $this);
        $rec->addField('Id', 'int', false, 0, $id);
        $rec->addField('RC', '', false, 15, $pracovniPomer->rc);
        $rec->addField('VyuctovaniDane_Rok', 'timestamp', false, 0, $datumOd);
        $rec->addField('VyuctovaniDane_RC', '', false, 15, $pracovniPomer->rc);

        $rec->insertRecord();
    }

    public function report()
    {
        if (!$_GET['idpp'] || !$_GET['rok']) {
            throw new Exception('Neni zadano rocni vyuctovani pro tisk!');
        }

        Prava::nastavObdobiProPrava(time(), time());

        $idPP = (int)$_GET['idpp'];
        $rok  = DateUtils::dateStringToTimestamp('1.1.' . $_GET['rok']);
        $konecRoku = DateUtils::incDay(DateUtils::incMonth($rok, 12), -1);

        if (($_GET['typ'] == 'prohlaseni')) {
            $reportName = 'DaneProhlaseni';
            if (!$this->pravo_prohlaseni->lzeZobrazitPP($idPP)) {
                throw new NeniPravoException();
            }
        }
        if ($_GET['typ'] == 'vyuctovani') {
            $reportName = 'DaneVyuctovani';
            if (!$this->pravo_vyuctovani->lzeZobrazitPP($idPP)) {
                throw new NeniPravoException();
            }
        }

        $result = new ReportOutputObject();
        $result->loadReportFromGet($this->database, $reportName, false);
        $result->nastavPP(PracovniPomer::nactiPP($this->database, $_GET['idpp']));
        $result->nastavObdobi(3, $rok, $konecRoku);

        $result->dateParams['rok'] = date('j.n.Y', $rok);

        return $result;
    }

    public function handleAction($action)
    {
        if (!($this->pravo_prohlaseni->jsouNejakePrava() || $this->pravo_vyuctovani->jsouNejakePrava())){
            throw new NeniPravoException();
        }

        TextManager::getInstance()->loadStrings('mzdy.ini');
        TextManager::getInstance()->loadStrings('person.ini');
        HtmlHeaders::getInstance()->addCss('css/mzdy.css');
        HtmlHeaders::getInstance()->addScript('script/mzdy.js');
        HtmlHeaders::getInstance()->addScript('', '?menuid=dane&action=translations&ver=' . HtmlHeaders::getInstance() ->versionId);


        $daneaction = isset($_GET['action']) ? $_GET['action'] : '';
        switch ($daneaction) {
            case 'formularzadosti':
                return $this->zobrazitFormularZadostiOZuctovaniDane($_GET['obdobi'], $_GET['osoba']);
            case 'ulozitprohlaseni':
                return $this->zapisProhlaseni();
            case 'ulozitzadost':
                return $this->zapisZadosti();
            case 'report':
                return $this->report();
            default:
                return parent::handleAction($action);
        }
    }

}
