<?php
/**
 * stanislav.elbl, 01.08.2021 12:04
 */

namespace RonPortal\Skoleni;

use Ron\Controls\ComboBox;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSession;

/**
 * Class PlanovaneSkoleniFilterForm
 * @package Ron\RonPortal
 */
class PlanovaneSkoleniFilterForm extends RonPortalFilterForm
{

    /** @var PravaNaOsoby $prava*/
    var $pravoNaPlan;

    /**
     * PlanovaneSkoleniFilterForm constructor.
     * @param Database $database
     * @param $pravo
     * @param string $action
     * @param bool $useGet
     */
    public function __construct(Database $database, $pravo, $action, $useGet = false)
    {
        parent::__construct($database, $action, $useGet);

        $this->nastavDatumOdDo(true,false);
        Prava::nastavObdobiProPrava(time(),time());

        $this->pravoNaPlan = $pravo;
        $this->f_classname = 'filtercontainer leftcaptions';
        $this->f_formaction = '?menuid=skoleni&action=planovaneskolenikurzy';

    }


    /**
     * @throws DBException
     */
    function renderTypSkoleni()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenDruhSkoleniAKurzu', TextManager::_('planovany_kurz'),
            isset($_SESSION['jenDruhSkoleniAKurzu'])  &&  $_SESSION['jenDruhSkoleniAKurzu'],
            ['id' => 'jenKurz'], 'clickAutoSubmit');
        echo '</span>';

        $params = $this->database->createParameters();
        $sql =
            'SELECT Kod, Popis FROM DruhSkoleni';

//        if (!($this->pravoNaPlan->prava == 3)){
//            $sql .= "WHERE PlanovaneSkoleniOsob.RC = " . $params->addParameter(User::getRC());
//        }

        $sql .= ' ORDER BY Popis';

        $combo = new ComboBox('druhSkoleniAKurzu');
        $combo->className = 'form-input adsfilterforminput_full';
        $combo->htmlParams = [
            'id' => 'typKurzu',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenKurz'
        ];
          //  'onChange="if (jenDruhSkoleniAKurzu.checked) submit();"';
        $combo->showCode = 1;
        $combo->loadData($this->database, $sql, isset($_SESSION['druhSkoleniAKurzu']) ? $_SESSION['druhSkoleniAKurzu'] : null, $params);
        $combo->render();
        echo '</div>';

    }

    function loadTypSkoleni()
    {
        if (isset($_POST['adsfilterform'])) {
            $_SESSION['jenDruhSkoleniAKurzu'] = isset($_POST['jenDruhSkoleniAKurzu']);
            $_SESSION['druhSkoleniAKurzu'] = $_POST['druhSkoleniAKurzu'];
        }
    }


    function loadData()
    {
        $this->loadTypSkoleni();
        parent::loadData();
    }


    /**
     * @throws DBException
     */
    function renderFilters()
    {
        parent::renderFilters();
        $this->renderTypSkoleni();
    }
}

///**
// * Class DetailPlanovanehoSkolenikurzu
// * @package Ron\RonPortal
// */
//class DetailPlanovanehoSkolenikurzu extends BrowserField
//{
//
//    /**
//     * DetailPlanovanehoSkolenikurzu constructor.
//     * @param Database $database
//     */
//    function __construct($database)
//    {
//        parent::__construct($database);
//        $this->header = TextManager::_('detail_planovaneho_skoleni');
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//        $result .= '<a href="?menuid=skoleni&action=detailplanovanehoskolenikurzu&record=' . HttpUtils::urlEncode($rowData[0]) . '">';
//        $result .= StringUtils::htmlTextConvert($rowData[1]);
//        $result .= '</a>';
//        return $result;
//    }
//}

///**
// * Class DatumPosledniAktualizacePlanovanehoField
// * @package Ron\RonPortal
// */
//class DatumPosledniAktualizacePlanovanehoField extends BrowserField
//{
//
//    /**
//     * DatumPosledniAktualizacePlanovanehoField constructor.
//     * @param Database $database
//     */
//    function __construct($database)
//    {
//        parent::__construct($database);
//        $this->header = TextManager::_('posledni_aktualizace');
//        $this->align = 'center';
//        $this->sqlFieldName = "PS.Update_Timestamp";
//        $this->ordering = 1;
//        $this->sortSQL = "PS.Update_Timestamp";
//        $this->sortSQLDesc = "PS.Update_Timestamp DESC";
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//        if ($rowData[29]) {
//            $result .= "<div >" . StringUtils::format('date', $this->database->stringToTimestamp($rowData[29])) . ' (' . StringUtils::htmlTextConvert( $rowData[28]) . ') ' . "</div>" ;
//        }
//        return $result;
//    }
//}

///**
// * Class DatumVlozeniPlanovanehoField
// * @package Ron\RonPortal
// */
//class DatumVlozeniPlanovanehoField extends BrowserField
//{
//
//    /**
//     * DatumVlozeniPlanovanehoField constructor.
//     * @param Database $database
//     */
//    function __construct($database)
//    {
//        parent::__construct($database);
//        $this->header = TextManager::_('datum_vlozeni');
//        $this->align = 'center';
//        $this->sqlFieldName = "PS.Update_Timestamp";
//        $this->ordering = 1;
//        $this->sortSQL = "PS.Insert_Timestamp";
//        $this->sortSQLDesc = "PS.Insert_Timestamp DESC";
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//        if ($rowData[27]) {
//            $result .= "<div >" . StringUtils::format('date', $this->database->stringToTimestamp($rowData[27])) . ' (' . StringUtils::htmlTextConvert( $rowData[26]) . ') ' . "</div>" ;
//        }
//        return $result;
//    }
//}


/**
 * Class PlanovaneSkoleniBrowser
 */
class PlanovaneSkoleniBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby $pravo*/
    public $pravo;


    /**
     * PlanovaneSkoleniBrowser constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct(Database $database)
    {
        parent::__construct($database, 'skoleni');


        Prava::nastavObdobiProPrava(time(), time());
        $this->pravo = Prava::vratPrava('skoleni_plan');

        $this->code = 'browserplanovaneskoleni';
        $this->tableId = 'browserplanovaneskoleni';
        $this->browserUrl = "?menuid=skoleni&action=planovaneskolenikurzy";

        $this->sqlSelectPart =
            "PS.CisloSkoleni, PS.Popis, PS.DruhSkoleni, " .                   //0..2
            "PS.DatumPocatkuSkoleni, PS.CasPocatkuSkoleni, PS.DatumUkonceniSkoleni, " .       //3..5
            "PS.CasUkonceniSkoleni, PS.MistoSkoleni, PS.PocetOsob, " .        //6..8
            "PS.KonkretniUcastnici, PS.SkoliciFirma, PS.Skolitel, " .         //9..11
            "PS.CenaZaSkoleni, PS.DPH1, PS.DPH2, PS.DPH3, " .       //12..15
            "PS.Dan1, PS.Dan2, PS.Dan3, PS.Stav, " .                //16..19
            $this->database->castWideMemo("PS.Poznamka") . ", S_StavPlanovanehoSkoleni.Kod, S_StavPlanovanehoSkoleni.Popis, " . //20..22
            "PS.DelkaSkoleniDnu, PS.DelkaSkoleniHodin, Firma.Nazev1, PS.Insert_UserName, PS.Insert_Timestamp, PS.Update_UserName, PS.Update_Timestamp, " .               //23..29
            "(Select RC From PlanovaneSkoleniOsob Where DatumVlozeni = (Select MIN(DatumVlozeni) From PlanovaneSkoleniOsob Where (PS.CisloSkoleni = PlanovaneSkoleniOsob.CisloSkoleni))) ";  //30

        $this->sqlFromPart =
            "PlanovaneSkoleni PS
              LEFT JOIN S_StavPlanovanehoSkoleni ON (PS.Stav = S_StavPlanovanehoSkoleni.Kod)
               LEFT JOIN Firma ON (PS.SkoliciFirma = Firma.kodFirmy)";

        $this ->primaryField = 0;

        $this->addField()
            ->setSqlFieldName('PS.CisloSkoleni', 0) ->setHeaderText('ID') ->setOrdering(1)
            ->setCode('col-cisloskoleni');

        //$this->addField(new DetailPlanovanehoSkolenikurzu($this->database));
        $this->addField()
            ->setSqlFieldName('PS.Popis', 1) ->setHeaderText('detail_planovaneho_skoleni') ->setOrdering(1)
            ->setLink('?menuid=skoleni&action=detailplanovanehoskolenikurzu&record=')
            ->setCode('col-popis');

        $this->addField()
            ->setSqlFieldName('PS.DruhSkoleni', 2) ->setHeaderText('druh_skoleni') ->setOrdering(1)
            ->setCode('col-druhskoleni');


        $this->addField()
            ->setSqlFieldName('S_StavPlanovanehoSkoleni.Popis', 22) ->setHeaderText('stav') ->setOrdering(1)
            ->setCode('col-stav');

        $this->addField()
            ->setSqlFieldName('PS.DatumPocatkuSkoleni', 3) ->setFormat('date') ->setHeaderText('datum_pocatku_skoleni') ->setOrdering(1)
            ->setCode('col-datumpocatkuskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.CasPocatkuSkoleni', 4) ->setFormat('time') ->setHeaderText('cas_pocatku_skoleni') ->setOrdering(1)
            ->setCode('col-caspocatkuskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.CasUkonceniSkoleni', 6) ->setFormat('time') ->setHeaderText('cas_ukonceni_skoleni') ->setOrdering(1)
            ->setCode('col-casukonceniskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.DatumUkonceniSkoleni', 5) ->setFormat('date') ->setHeaderText('datum_ukonceni_skoleni') ->setOrdering(1)
            ->setCode('col-datumukonceniskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('Firma.Nazev1', 25) ->setHeaderText('skolici_firma') ->setOrdering(1)
            ->setCode('col-firma');

        $this->addField()
            ->setSqlFieldName('PS.Skolitel', 11) ->setHeaderText('skolitel') ->setOrdering(1)
            ->setCode('col-skolitel');

        //$this->addField(new DatumVlozeniPlanovanehoField($this->database));
        $this ->addField()
            ->setSqlFieldName('PS.Insert_Timestamp', 27) ->setSqlFieldIndex2(26) ->setFormat('date')
            ->setHeaderText('datum_vlozeni') ->setAlign('center') ->setOrdering(1)
            ->setCode('col-datumvlozeni');

        //$this->addField(new DatumPosledniAktualizacePlanovanehoField($this->database));
        $this ->addField()
            ->setSqlFieldName('PS.Update_Timestamp', 29) ->setSqlFieldIndex2(28) ->setFormat('date')
            ->setHeaderText('posledni_aktualizace') ->setAlign('center') ->setOrdering(1)
            ->setCode('col-datumaktualizace');
    }


    function setFilterForm()
    {
        $this->filterForm = new PlanovaneSkoleniFilterForm($this ->database, $this->pravo, null);
        $this->filterForm->loadData();
    }


    /**
     * @param array $values
     * @return bool
     * @throws \Exception
     */
    function enableLine($values)
    {
        if ($this->pravo->prava == 3){
            return true;
        }

        if ($values[30] && $this->pravo->lzeZobrazitRC($values[30])) {
            return true;
        }

        return false;
    }


    /**
     * @return string
     */
    function getSQLFilter()
    {
        $result = '';
        $params = $this->database->createParameters();


//        $result .= "PS.Stav < 2 ";    - Nebylo mozno zobrazit omylem zamitnute kurzy

        if (isset($_SESSION['jenDruhSkoleniAKurzu'])  &&  $_SESSION['jenDruhSkoleniAKurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                'PS.DruhSkoleni = ' . $params->addParameter($_SESSION['druhSkoleniAKurzu']);
        }

        if (RonPortalSession::getFiltrovatDatum()) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumOd())) .
                ' AND PS.DatumPocatkuSkoleni <= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumDo()));
        }

        return new SqlStatement($result, $params);
    }
}
