<?php
/**
 * Roman.Szablatura RON Software 19.07.2019
 */

namespace RonPortal\Skoleni;

use Ron\Controls\BrowserField;
use Ron\Controls\ComboBox;
use Ron\Controls\LinksList;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSession;
use RonPortal\User;


/**
 * Class SchvalovaniOsobNaPlanuKurzuFilter
 * @package Ron\RonPortal
 */
class SchvalovaniOsobNaPlanuKurzuFilter extends RonPortalFilterForm
{
    /** @var PravaNaOsoby $prava */
    public $pravoPrihlasit;

    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /**
     * SchvalovaniOsobNaPlanuKurzuFilter constructor.
     * @param $database
     * @param PravaNaOsoby $pravoPrihlasit
     * @param PravaNaOsoby $pravoSchvalit
     */
    public function __construct($database, $pravoPrihlasit, $pravoSchvalit)
    {
        parent::__construct($database, 'skoleni', true);

        $this->pravoPrihlasit = $pravoPrihlasit;
        $this->pravoSchvalit = $pravoSchvalit;
        Prava::nastavObdobiProPrava(time(),time());

        $this->nastavDatumOdDo(true,false);

        $this->f_classname = 'filtercontainer leftcaptions';
        $this->f_formaction = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=planypodlekurzu";
    }


    /**
     * @throws DBException
     */
    public function renderPouzeTypKurzu()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenTypKurzu', \Ron\ronText('typ_skoleni'), isset($_SESSION['jenTypKurzu']) ? $_SESSION['jenTypKurzu'] : 0,
            ['id' => 'jenTypKurzu'], 'clickAutoSubmit');
        echo '</span>';

        $params = $this->database->createParameters();

        $sql =
            'SELECT Distinct DruhSkoleni.Kod, DruhSkoleni.Popis' .
            ' FROM DruhSkoleni' .
            ' WHERE DruhSkoleni.Aktivni = 1';

        $combo = new ComboBox('typKurzu');
        $combo->className = 'adsfilterforminput_popis';
        $combo->showCode = 1;
        $combo->htmlParams = [
            'id' => 'typKurzu',
            'data-ron-select2' => '#typKurzu_kod',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenTypKurzu'
        ];
        $combo->loadData($this->database,
            $sql . ' ORDER BY DruhSkoleni.Popis',
            isset($_SESSION['typKurzu']) ? $_SESSION['typKurzu'] : null,
            $params);
        $combo->dataTypeComparison = false;
        $combo->render();

        $combo = new ComboBox('');
        $combo->className = 'adsfilterforminput_kod';
        $combo->htmlParams = [
            'id' => 'typKurzu_kod',
            'data-ron-select2' => '#typKurzu',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenTypKurzu'
        ];
        $combo->captionIndex = 0;
        $combo->showCode = 1;
        $combo->keyIndex = 0;
        $combo->dataTypeComparison = false;
        $combo->loadData($this->database,
            $sql . ' ORDER BY DruhSkoleni.Kod',
            isset($_SESSION['typKurzu']) ? $_SESSION['typKurzu'] : null,
            $params);
        $combo->render();

        echo '</div>';
    }


    /**
     * @throws DBException
     */
    public function renderPouzeKodKurzu()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenKodKurzu', \Ron\ronText('pouze_kod_kurzu'),
            isset($_SESSION['jenKodKurzu'])  &&  $_SESSION['jenKodKurzu'],
            ['id' => 'jenKodKurzu'], 'clickAutoSubmit');
        echo '</span>';

        $params = $this->database->createParameters();
        $sql =
            'SELECT Distinct PS.CisloSkoleni, PS.Popis' .
            ' FROM PlanovaneSkoleni PS' .
            ' WHERE PS.Stav <> 2 ';

        $combo = new ComboBox('kodKurzu');
        $combo->className = 'adsfilterforminput_popis';
        $combo->showCode = 1;
        $combo->htmlParams = [
            'id' => 'kodKurzu',
            'data-ron-select2' => '#kodKurzu_kod',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenKodKurzu'
        ];
        $combo->loadData($this->database,
            $sql . ' ORDER BY PS.Popis',
            isset($_SESSION['kodKurzu']) ? $_SESSION['kodKurzu'] : null,
            $params);
        $combo->render();

        $combo = new ComboBox('');
        $combo->className = 'adsfilterforminput_kod';
        $combo->htmlParams = [
            'id' => 'kodKurzu_kod',
            'data-ron-select2' => '#kodKurzu',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenKodKurzu'
        ];
        $combo->showCode = 1;
        $combo->keyIndex = 0;
        $combo->captionIndex = 0;
        $combo->loadData($this->database,
            $sql . 'ORDER BY PS.CisloSkoleni',
            isset($_SESSION['kodKurzu']) ? $_SESSION['kodKurzu'] : null,
            $params);
        $combo->render();

        echo '</div>';
    }

    public function renderPodMenuPrihlaseniNaPlanovaneSkoleni()
    {
        if ($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava()) {
            LinksList::renderLinks(
                [
                    'planypodleosoby' => \Ron\ronText('plany_podle_osoby'),
                    'planypodlekurzu' => \Ron\ronText('plany_podle_kurzu')
                ],
                'planypodlekurzu',
                '?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=');
        }
    }


     private function loadPodMenuPrihlaseniNaPlanovaneSkoleni()
    {
        //Moje kurzy odstraneno (na zadost Martina) jelikoz funkcnost nahrazuje "pro osobu"
        if ($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava()) {
            if (isset($_GET['filtrprihlaseninaplanovaneskoleni'])) {
                $_SESSION['filtrprihlaseninaplanovaneskoleni'] = $_GET['filtrprihlaseninaplanovaneskoleni'];
            }
            //Pri prvnim zobrazeni stranky se implicitne nastavi Pro osobu
            if (!isset($_SESSION['filtrprihlaseninaplanovaneskoleni'])) {
                $_SESSION['filtrprihlaseninaplanovaneskoleni'] = 'planypodleosoby';
            }
        }
    }


    public function renderPouzeNeschvalenePlanyKurzu()
    {
        echo "<div class='filterrow'>";
        echo '<span class="filtercaption">';
            GuiUtils::renderCheckbox('aktualniplanykurzu', \Ron\ronText('filtr_pouze_aktualni_plany'),
                isset($_SESSION['aktualniplanykurzu']) && $_SESSION['aktualniplanykurzu'],
                '', 'clickAutoSubmit');
        echo "</span>";
        echo "</div>";
    }


    function loadData()
    {
        parent::loadData();
        $this->loadPodMenuPrihlaseniNaPlanovaneSkoleni();

        if (isset($_GET['adsfilterform'])) {
            // typ kurzu
            $_SESSION['jenTypKurzu'] = isset($_GET['jenTypKurzu']);
            $_SESSION['typKurzu'] = $_GET['typKurzu'];
            // kod kurzu
            $_SESSION['jenKodKurzu'] = isset($_GET['jenKodKurzu']);
            $_SESSION['kodKurzu'] = $_GET['kodKurzu'];

            $_SESSION['aktualniplanykurzu'] = isset($_GET['aktualniplanykurzu']);
        }
    }


    /**
     * @throws DBException
     */
    public function renderFilters()
    {
        $this->renderPodMenuPrihlaseniNaPlanovaneSkoleni();
        parent::renderFilters();
        $this->renderPouzeTypKurzu();
        $this->renderPouzeKodKurzu();
        $this->renderPouzeNeschvalenePlanyKurzu();

        echo
            '<input type="hidden" name="action" value="prihlaseninaplanovaneskoleni"/>' .
            '<input type="hidden" name="adsfilterform" value="1"/>' .
            "<input type='hidden' name='filtrprihlaseninaplanovaneskoleni' value='planypodlekurzu'/>";
    }
}


/**
 * Class KurzyPodrizenehoField
 * @package Ron\RonPortal
 */
class KurzyPodrizenehoField extends BrowserField
{
    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $urlNaKurzy = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=planypodleosoby&osoba=$rowData[0]";

        $textOznameni = TextManager::_(User::hasRC($rowData[14]) ? 'prejit_na_moje_plany' : 'prejit_na_kurzy_osoby');

        return
            "<a href='$urlNaKurzy'>$textOznameni</a>";
    }
}


/**
 * Class ObsazenostNaKurzuField
 * @package Ron\RonPortal
 */
class ObsazenostNaKurzuField extends BrowserField
{

    /**
     * PocetOsobNaKurzuField constructor.
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);
        $this
            ->setSqlFieldName('PSO.RC')
            ->setHeaderText('kapacita_obsazenost_volne')
            ->setAlign('center')
            ->setOrdering(1);
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = '';
        $vycerpano = ((int)$rowData[12]-(int)$rowData[13]) <= 0
            ? 'minus'
            : '';

        $kapacita = (int)$rowData[12];
        $volno = ((int)$rowData[12]-(int)$rowData[13]);

        $result .= "<div>";
        $result .= "<span title=''>" . $kapacita . "</span>/<span class=' $vycerpano' >" . $volno . "</span>";
        $result .= "</div>";

        return $result;
    }
}


/**
 * Class StavHromadneField
 * @package Ron\RonPortal
 */
class StavHromadneField extends BrowserField
{
    function __construct($database)
    {
        parent::__construct($database);
        $this
            ->setSqlFieldName('PSO.Potvrzeni')
            ->setHeaderText('stav')
            ->setOrdering(1);
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $stavCiselne = $rowData[9];
        switch ($stavCiselne){
            case 0:
                if ($rowData[9] === null) {
                    return \Ron\ronText('-');
                }

                return \Ron\ronText('osoba_plan_kurzu_prihlasen_neschvaleno');

            case 1:
                return \Ron\ronText('osoba_plan_kurzu_prihlasen_schvaleno');

            case 2:
                return \Ron\ronText('osoba_plan_kurzu_zamitnuto');
        }

        return '';
    }
}


/**
 * Class SchvaleniPrihlaseniOsobyNaKurzuField
 * @package Ron\RonPortal
 */
class SchvaleniPrihlaseniOsobyNaKurzuField extends BrowserField
{
    /** @var PravaNaOsoby $pravoPrihlasit */
    public $pravoPrihlasit;
    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /**
     * SchvaleniPrihlaseniOsobyNaKurzuField constructor.
     * @param Database $database
     * @param PravaNaOsoby $pravoPrihlasit
     * @param PravaNaOsoby $pravoSchvalit
     */
    function __construct($database, $pravoPrihlasit, $pravoSchvalit)
    {
        parent::__construct($database);
        $this->header = \Ron\ronText('schvaleni');
        $this->pravoPrihlasit = $pravoPrihlasit;
        $this->pravoSchvalit = $pravoSchvalit;
    }


    /**
     * @param array $rowData
     * @param string $akce  schvalit nebo zamitnout
     * @param string $textOznameniPoznamky
     * @return string
     */
    private function schvalitPrihlaseniLink($rowData, $akce, $textOznameniPoznamky)
    {
        return
            "<span class='pripojit-poznamku-schvaleni js'" .
            " data-ron-akce='$akce'" .
            " data-ron-osoba='$rowData[0]'" .
            " data-ron-cislokurzu='" . StringUtils::htmlTextConvert($rowData[3]) . "'" .
            " data-ron-poznamkaschvaleni='" . StringUtils::htmlTextConvert($rowData[10]) . "'" .
            ">$textOznameniPoznamky</span>";
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws \Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = '';

        $volnaMista = (int)$rowData[12] - (int)$rowData[13];
        $datumPocatkuKurzu = $this->database->stringToTimestamp($rowData[5]);

        //Prava
        $muzePrihlasit = $this->pravoPrihlasit->lzeZobrazitRC($rowData[14]);
        $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC($rowData[14]);

        //Url
        $url = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&cisloskoleni=$rowData[3]&osoba=$rowData[0]&hromadne=1";
        $urlSchvaleni = $url . "&plankurzuzamestnance=schvalit";
        $urlOdhlaseni = $url . "&plankurzuzamestnance=zrusit";
        $urlZamitnuti = $url . "&plankurzuzamestnance=zamitnout";

        //Stav
        $jePrihlasen = isset($rowData[9]) && (int)$rowData[9] === 0;
        $jeSchvalen = (int)$rowData[9] === 1;
        $jeZamitnut = (int)$rowData[9] === 2;

        if ($datumPocatkuKurzu < DateUtils::today()) {
            // kurz uz probiha nebo probehl
            return \Ron\ronText('expirace_kurzu');
        }

        if (!$jeSchvalen  &&  !$jePrihlasen  &&  $volnaMista <= 0) {
            // neni prihlasen ani schvalen a kapacita kurzu je naplnena
            return \Ron\ronText('kapacita_planu_naplnena');
        }

        //Pokud ma pravo na schvaleni ale neni zapsan na planu pak nabidnout prihlaseni a schvaleni jinak pouze prihlaseni
        //Pokud je prihlasen a nema pravo schvalit pak zobrazit pouze text uzivatel je prihlasen
        if ($muzePrihlasit || $muzeSchvalit) {
            if ($jeSchvalen) {
                //Je schvalen -> je i prihlasen
                if ($muzeSchvalit) {
                    $textOznameni = \Ron\ronText('odhlasit_z_planu_skoleni');
                    return "<a href='$urlOdhlaseni'>$textOznameni</a>";
                }

                return '';
            } else  if ($jePrihlasen) {
                //Je prihlasen, ale neschvalen ->  moznost schvalit nebo ignorovat
                if ($muzeSchvalit) {
                    $result .= "<div>";
                        $textOznameniPoznamky = \Ron\ronText('schvalit_plan_kurzu_poznamka');
                        $textOznameni = \Ron\ronText('schvalit_plan_skoleni_uzivatel_ma_zajem');
                        $result .= "<a href='$urlSchvaleni'>$textOznameni</a>";
                        $result .=  "&nbsp;&nbsp;&nbsp;" . $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky);
                    $result .= "</div>";

                    if (!$jeZamitnut) {
                        $result .= "<div>";
                        $textOznameni = \Ron\ronText('zamitnout');
                        $textOznameniPoznamky = \Ron\ronText('zamitnout_plan_kurzu_poznamka');
                        $result .= "<a href='$urlZamitnuti'>$textOznameni</a>";
                        $result .=  "&nbsp;&nbsp;&nbsp;" . $this->schvalitPrihlaseniLink($rowData, 'zamitnout', $textOznameniPoznamky);
                        $result .= "</div>";
                    }
                } else {
                    if ($muzePrihlasit){
                        $textOznameni = \Ron\ronText('odhlasit_z_planu_skoleni');
                        return "<a href='$urlOdhlaseni'>$textOznameni</a>";
                    }

                    return '';
                }

            } else {
                //Neni prihlasen, kapacita je -> moznost prihlasit i schvalit
                $textOznameni = \Ron\ronText('prihlasit_plan_skoleni_uzivatel_neprojevil_zajem');
                $textOznameniPoznamky = \Ron\ronText('prihlasit_plan_kurzu_poznamka');
                if ($muzeSchvalit) {
                    $textOznameni = \Ron\ronText('prihlasit_schvalit_plan_skoleni_uzivatel_neprojevil_zajem');
                    $textOznameniPoznamky = \Ron\ronText('prihlasit_schvalit_plan_kurzu_poznamka');
                    $result .= "<div>";
                    $result .= "<a title=''  href='$urlSchvaleni'>$textOznameni</a>";
                    $result .= "&nbsp;&nbsp;&nbsp;";
                    $result .= $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky);
                    $result .= "</div>";
                } elseif ($muzePrihlasit) {
                    $result .= "<div>";
                    $result .= "<a title=''  href='$urlSchvaleni'>$textOznameni</a>";
                    $result .= "&nbsp;&nbsp;&nbsp;";
                    $result .= $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky);

                    $result .= "</div>";
                }
            }
        }

        return $result;
    }
}


/**
 * Class SchvalovaniPlanuKurzuBrowser
 */
class SchvalovaniPlanuKurzuBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby $pravoPrihlasit */
    public $pravoPrihlasit;
    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /**
     * SchvalovaniPodrizenychNaPlanuKurzuBrowser constructor.
     * @param Database $database
     * @param $filtrPrihlaseniNaPlanovaneSkoleni
     * @throws \Exception
     */
    public function __construct($database, $filtrPrihlaseniNaPlanovaneSkoleni)
    {
        parent::__construct($database, 'skoleni');

        $this->code = 'browserschvalovaniosobpodleplanukurzu';
        $this->tableId = 'schvalovaniosobpodleplanukurzu';
        $this->browserUrl = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$filtrPrihlaseniNaPlanovaneSkoleni";

        $this->pravoPrihlasit = Prava::vratPrava('skoleni_prihlasit');
        $this->pravoSchvalit = Prava::vratPrava('skoleni_schvaleni_planu');
        Prava::nastavObdobiProPrava(time(), time());

        $this->filterForm = new SchvalovaniOsobNaPlanuKurzuFilter($database, $this->pravoPrihlasit, $this->pravoSchvalit);
        $this->filterForm->loadData();

        $this->sqlSelectPart =
            "PP.ID, COALESCE(O.Prijmeni,'') {fn_concat()} ' ' {fn_concat()} COALESCE(O.Jmeno,'')," .    // 0,1
            ' PS.DruhSkoleni, PS.CisloSkoleni, PS.Popis,' .                                             // 2..4
            ' PS.DatumPocatkuSkoleni, PS.CasPocatkuSkoleni, PS.CasUkonceniSkoleni,PS.DatumUkonceniSkoleni, PSO.Potvrzeni,' .    // 5..9
            ' {fn_CASTWIDEMEMO(PSO.PoznamkaSchvalovani)},{fn_CASTWIDEMEMO(PS.Poznamka)}, PS.PocetOsob AS Kapacita,' .           // 10..12
            "(SELECT COUNT(RC) FROM PlanovaneSkoleniOsob WHERE PlanovaneSkoleniOsob.CisloSkoleni = PS.CisloSkoleni" .
            " AND PlanovaneSkoleniOsob.Potvrzeni < 2) AS CelkemPrihlasenych," . // 13
            " O.RC";   // 14

        $this->sqlFromPart =
            "PracovniPomer PP 
                INNER JOIN Osoba O ON (O.RC = PP.RC)
                CROSS JOIN PlanovaneSkoleni PS
                LEFT OUTER JOIN PlanovaneSkoleniOsob PSO ON ((PSO.RC = O.RC) AND (PSO.CisloSkoleni = PS.CisloSkoleni))";

        $this->sqlWherePart =
            "(PP.Zamestnanec = 1  OR  PP.Zamestnanec = 2) 
                 AND PP.DatumNastupu <= " . $this->database->timestampToString(time()) . " 
                 AND (PP.DatumUkonceni >= " . $this->database->timestampToString(time()) .
                    " OR PP.DatumUkonceni IS NULL) 
                 AND PP.ID = (SELECT Max(ID) FROM PracovniPomer WHERE PracovniPomer.RC = PP.RC)";

        $this->defaultSort = -6;

        $this->addField()
            ->setSqlFieldName('O.Prijmeni, O.Jmeno', 1) ->setHeaderText('Jmeno') ->setOrdering(true)
            ->setCode('col-prijmeni');

        $this->addField()
            ->setSqlFieldName('PS.DruhSkoleni', 2) ->setHeaderText('typ_skoleni') ->setOrdering(1)
            ->setCode('col-druhskoleni');

        $this->addField()
            ->setSqlFieldName('PS.CisloSkoleni', 3) ->setHeaderText('cislo_skoleni') ->setOrdering(1)
            ->setCode('col-cisloskoleni');

        $this->addField()
            ->setSqlFieldName('PS.Popis', 4) ->setHeaderText('popis_planu_kurzu') ->setOrdering(1) ->setClassName('font-weight-bold')
            ->setCode('col-popis');

        //Sloupec s proklikem na Schvalovani kurzu podrizeneho
        $this->addField(new KurzyPodrizenehoField($database));

        $this->addField()
            ->setSqlFieldName('PS.DatumPocatkuSkoleni', 5) ->setHeaderText('datum_pocatku_skoleni') ->setFormat('date')
            ->setOrdering(1) ->setAlign('center')
            ->setCode('col-datumpocatkuskoleni');

        $this->addField()
            ->setSqlFieldName('PS.DatumUkonceniSkoleni', 8) ->setHeaderText('datum_ukonceni_skoleni') ->setFormat('date')
            ->setOrdering(1) ->setAlign('center')
            ->setCode('col-datumukonceniskoleni');

        $this->addField(new ObsazenostNaKurzuField($database));

        $this->addField(new StavHromadneField($database));

        $this->addField(new SchvaleniPrihlaseniOsobyNaKurzuField($database, $this->pravoPrihlasit, $this->pravoSchvalit));
    }


    function setFilterForm()
    {
        // nedela nic - filtr uz je nastaven v konstruktoru
    }


    /**
     * @param array $values
     * @param string $className
     * @param int $rowNumber
     * @param bool $edit
     */
    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        //PSO.PoznamkaSchvalovani: PSO.PoznamkaSchvalovani
        if ($values[10]) {
            echo
                "<tr class='$className'>" .
                '<td></td>' .
                '<td class="poznamka" colspan="' . ($this->columnCount - 3) . '">' .
                \Ron\ronText('poznamka_schvaleni') . ': ' .
                StringUtils::htmlTextConvert($values[10]) .
                '<td colspan="2"></td>' .
                '</tr>';
        }
    }

    /**
     * @return SqlStatement|string
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();

        //Overeni prav
        $result =
            '(' .
            $this->pravoPrihlasit->sqlFiltr('PP',time(),time()) .
            ' OR ' .
            $this->pravoSchvalit->sqlFiltr('PP',time(),time()) .
            ')';

        $result .=
            ' AND PS.Stav < 2 ';

        if(isset($_SESSION['jenTypKurzu'])  &&  $_SESSION['jenTypKurzu']) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DruhSkoleni = ' . $params->addParameter($_SESSION['typKurzu']);
        }

        if (RonPortalSession::getFiltrovatDatum()) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumOd())) .
                ' AND PS.DatumPocatkuSkoleni <= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumDo()));
        }


        if (isset($_SESSION['aktualniplanykurzu'])  &&  $_SESSION['aktualniplanykurzu']) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addParameter( $this->database->timestampToParam(DateUtils::today()));
        }

        if (isset($_SESSION['jenKodKurzu'])  &&  $_SESSION['jenKodKurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.CisloSkoleni = ' . $params->addParameter($_SESSION['kodKurzu']);
        }

        return new SqlStatement($result, $params);
    }


    public function render()
    {
        parent::render();
        // dialog pro zapsani poznamky pri prihlasovani
        require 'ronportal/skoleni/view_poznamka_schvaleni_planu.php';
    }

}
