<?php
/**
 * Roman.Szablatura RON Software 17.07.2019
 */

namespace RonPortal\Skoleni;


use Exception;
use Ron\Controls\BrowserField;
use Ron\Controls\ComboBox;
use Ron\Controls\LinksList;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\StringUtils;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSession;


/**
 * Class SchvalovaniPlanuKurzuOsobyFilter
 * @package Ron\RonPortal
 */
class SchvalovaniPlanuKurzuOsobyFilter extends RonPortalFilterForm
{
/** @var PravaNaOsoby $pravaPrihlasit */
    public $pravoPrihlasit;

    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;


    /**
     * SchvalovaniPlanuKurzuOsobyFilter constructor.
     * @param $database
     */
    public function __construct($database)
    {
        parent::__construct($database, 'skoleni', true);

        $this->f_classname = 'filtercontainer leftcaptions';

        $this->pravoPrihlasit = Prava::vratPrava('skoleni_prihlasit');
        $this->pravoSchvalit = Prava::vratPrava('skoleni_schvaleni_planu');

        $this ->nastavOsoby(true,
            [$this->pravoPrihlasit, $this->pravoSchvalit],
            time(), time()); // prava podle aktualniho casu

        Prava::nastavObdobiProPrava(time(),time());

        $this->nastavDatumOdDo(true, false);
    }


    public function renderPodMenuPrihlaseniNaPlanovaneSkoleni()
    {
        if ($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava()) {
            LinksList::renderLinks(
                [
                    'planypodleosoby' => \Ron\ronText('plany_podle_osoby'),
                    'planypodlekurzu' => \Ron\ronText('plany_podle_kurzu')
                ],
                'planypodleosoby',
                '?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=');
        }
    }


    /**
     * @throws DBException
     */
    public function renderPouzeTypKurzu()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
        GuiUtils::renderCheckbox('jenTypKurzu', \Ron\ronText('typ_skoleni'), isset($_SESSION['jenTypKurzu']) ? $_SESSION['jenTypKurzu'] : 0,
            ['id' => 'jenTypKurzu'], 'clickAutoSubmit');
        echo '</span>';

        $params = $this->database->createParameters();

        $sql =
            'SELECT Distinct DruhSkoleni.Kod, DruhSkoleni.Popis' .
            ' FROM DruhSkoleni' .
            ' WHERE DruhSkoleni.Aktivni = 1';

        $combo = new ComboBox('typKurzu');
        $combo->className = 'adsfilterforminput_popis';
        $combo->showCode = 1;
        $combo->htmlParams = [
            'id' => 'typKurzu',
            'data-ron-select2' => '#typKurzu_kod',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenTypKurzu'
        ];
        $combo->loadData($this->database,
            $sql . ' ORDER BY DruhSkoleni.Popis',
            isset($_SESSION['typKurzu']) ? $_SESSION['typKurzu'] : null,
            $params);
        $combo->dataTypeComparison = false;
        $combo->render();

        $combo = new ComboBox('');
        $combo->className = 'adsfilterforminput_kod';
        $combo->htmlParams = [
            'id' => 'typKurzu_kod',
            'data-ron-select2' => '#typKurzu',
            'data-ron-autosubmit' => '1',
            'data-ron-autosubmit-check' => '#jenTypKurzu'
        ];
        $combo->captionIndex = 0;
        $combo->showCode = 1;
        $combo->keyIndex = 0;
        $combo->dataTypeComparison = false;
        $combo->loadData($this->database,
            $sql . ' ORDER BY DruhSkoleni.Kod',
            isset($_SESSION['typKurzu']) ? $_SESSION['typKurzu'] : null,
            $params);
        $combo->render();

        echo '</div>';
    }


    public function renderPouzeNeschvalenePlanyKurzu()
    {
        echo "<div class='filterrow'>";
        echo '<span class="filtercaption">';
            GuiUtils::renderCheckbox('aktualniplanykurzu', \Ron\ronText('filtr_pouze_aktualni_plany'),
                isset($_SESSION['aktualniplanykurzu']) ? $_SESSION['aktualniplanykurzu'] : 0,
                '', 'clickAutoSubmit');
        echo "</span>";

        echo '<span class="">';
            GuiUtils::renderCheckbox('neschvaleneplanykurzu', \Ron\ronText('filtr_pouze_neschvalene'),
                isset($_SESSION['neschvaleneplanykurzu']) ? $_SESSION['neschvaleneplanykurzu'] : 0,
                '', 'clickAutoSubmit');
        echo "</span>";

        echo '<span class="">';
            GuiUtils::renderCheckbox('pouzenaplanukurzu', \Ron\ronText('filtr_pouze_na_planu_kurzu'),
                isset($_SESSION['pouzenaplanukurzu']) ? $_SESSION['pouzenaplanukurzu'] : 0,
                '', 'clickAutoSubmit');
        echo "</span>";
        echo "</div>";
    }


    private function loadPodMenuPrihlaseniNaPlanovaneSkoleni()
    {
        //Moje kurzy odstraneno (na zadost Martina) jelikoz funkcnost nahrazuje "pro osobu"
        if ($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava()) {
            if (isset($_GET['filtrprihlaseninaplanovaneskoleni'])) {
                $_SESSION['filtrprihlaseninaplanovaneskoleni'] = $_GET['filtrprihlaseninaplanovaneskoleni'];
            }
            //Pri prvnim zobrazeni stranky se implicitne nastavi Pro osobu
            if (!isset($_SESSION['filtrprihlaseninaplanovaneskoleni'])) {
                $_SESSION['filtrprihlaseninaplanovaneskoleni'] = 'planypodleosoby';
            }
        }
    }


    /**
     * @throws Exception
     */
    function loadData()
    {
        parent::loadData();

        $this->loadPodMenuPrihlaseniNaPlanovaneSkoleni();

        if (isset($_GET['adsfilterform'])) {
            $_SESSION['neschvaleneplanykurzu'] = isset($_GET['neschvaleneplanykurzu']);
            $_SESSION['aktualniplanykurzu'] = isset($_GET['aktualniplanykurzu']);
            $_SESSION['pouzenaplanukurzu'] = isset($_GET['pouzenaplanukurzu']);
        }

        if (isset($_GET['typKurzu'])) {
            $_SESSION['jenTypKurzu'] = isset($_GET['jenTypKurzu']);
            $_SESSION['typKurzu'] = $_GET['typKurzu'];
        }
    }


    /**
     * @throws DBException
     */
    function renderFilters()
    {
        $this->renderPodMenuPrihlaseniNaPlanovaneSkoleni();
        parent::renderFilters();
        $this->renderPouzeTypKurzu();
        $this->renderPouzeNeschvalenePlanyKurzu();

        echo
            '<input type="hidden" name="action" value="prihlaseninaplanovaneskoleni"/>' .
            '<input type="hidden" name="adsfilterform" value="1"/>' .
            "<input type='hidden' name='filtrprihlaseninaplanovaneskoleni' value='planypodleosoby'/>";
    }
}


/**
 * Class PopisSkoleniField
 * @package Ron\RonPortal
 */
class PopisSkoleniField extends BrowserField
{

    /** @var PravaNaOsoby $pravoNaPlan */
    public $pravoNaPlan;

    /**
     * PopisSkoleniField constructor.
     * @param Database $database
     * @param PravaNaOsoby $pravoNaPlan
     */
    function __construct($database, $pravoNaPlan)
    {
        parent::__construct($database);
        $this->pravoNaPlan = $pravoNaPlan;

        $this
            ->setType(BrowserField::FIELD_TYPE_TEXT)
            ->setText('<i class="inline-glyph fa glyph-edit" title="' . \Ron\ronText('editace_planu_kurzu') . '"></i>')
            ->setLink('?menuid=skoleni&action=detailplanovanehoskolenikurzu&filtrprihlaseninaplanovaneskoleni=planypodleosoby&record=')
            ->setLinkAttributes(['target' => '_blank']);
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if ($rowData[14]  &&  ($this->pravoNaPlan->lzeZobrazitRC($rowData[14])) || $this->pravoNaPlan->prava == 3) {
            return parent::getViewText($value, $rowNumber, $recordId, $rowData);
        }

        return '';
    }
}


/**
 * Class CasKurzuField
 * @package Ron\RonPortal
 */
class CasKurzuField extends BrowserField
{

    /**
     * CasKurzuField constructor.
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);
        $this->header = \Ron\ronText('cas_planovaneho_kurzu');
        $this->align = 'center';
        $this->ordering = 1;
        $this->sortSQL = "PS.CasPocatkuSkoleni";
        $this->sortSQLDesc = "PS.CasPocatkuSkoleni DESC";
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = '';
        $result .= "<div>";
        $result .= StringUtils::format('time', $this->database->stringToTimestamp($rowData[4])) .
            " - " . StringUtils::format('time', $this->database->stringToTimestamp($rowData[5]));
        $result .= "</div>";
        return $result;
    }
}


/**
 * Class StavNaKurzuField
 * @package Ron\RonPortal
 */
class StavNaKurzuField extends BrowserField
{

    /**
     * PocetOsobNaKurzuField constructor.
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);
        $this->header = \Ron\ronText('stav');
        $this->align = 'center';
        $this->ordering = 1;
        $this->sortSQL = "Schvaleni";
        $this->sortSQLDesc = "Schvaleni DESC";
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = '';
        $stav = "";

        $stavCiselne = $rowData[10];
        switch ($stavCiselne){
            case 0:
                if ($rowData[9] == 1) {
                    $stav = \Ron\ronText('osoba_plan_kurzu_prihlasen_neschvaleno');
                } else {
                    $stav = \Ron\ronText('-');
                }
                break;

            case 1:
                $stav = \Ron\ronText('osoba_plan_kurzu_prihlasen_schvaleno');
                break;

            case 2:
                $stav = \Ron\ronText('osoba_plan_kurzu_zamitnuto');
                break;

        }


        $result .= "<div>";
        $result .= $stav;
        $result .= "</div>";
        return $result;
    }
}


/**
 * Class PocetOsobNaKurzuField
 * @package Ron\RonPortal
 */
class PocetOsobNaKurzuField extends BrowserField
{

    /**
     * PocetOsobNaKurzuField constructor.
     * @param Database $database
     */
    function __construct($database)
    {
        parent::__construct($database);

        $this
            ->setHeaderText('kapacita_obsazenost_volne')
            //->setSqlFieldName('Kapacita')
            ->setAlign('center')
            ->setOrdering(1);
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $vycerpano = ((int)$rowData[7]-(int)$rowData[8]) <= 0
            ? 'minus'
            : '';

        $kapacita = (int)$rowData[7];
        $volno = ((int)$rowData[7]-(int)$rowData[8]);

        return
            "<span>" . $kapacita . "</span>/<span class='$vycerpano'>" . $volno . "</span>";
    }
}


/**
 * Class SchvaleniPrihlaseniNaKurzuField
 * @package Ron\RonPortal
 */
class SchvaleniPrihlaseniNaKurzuField extends BrowserField
{
    /** @var PravaNaOsoby $pravaPrihlasit */
    public $jePravoPrihlasit;

    /** @var PravaNaOsoby $pravoSchvalit */
    public $jePravoSchvalit;

    /**
     * SchvaleniPrihlaseniNaKurzuField constructor.
     * @param Database $database
     * @param bool $jePravoPrihlasit
     * @param bool $jePravoSchvalit
     */
    function __construct($database, $jePravoPrihlasit, $jePravoSchvalit)
    {
        parent::__construct($database);

//        $this
//            ->setSqlFieldName('PS.Potvrzeni')
//            ->setOrdering(1);

        $this->jePravoPrihlasit = $jePravoPrihlasit;
        $this->jePravoSchvalit = $jePravoSchvalit;
    }


    /**
     * @param array $rowData
     * @param string $akce  schvalit nebo zamitnout
     * @param string $textOznameniPoznamky
     * @return string
     */
    private function schvalitPrihlaseniLink($rowData, $akce, $textOznameniPoznamky)
    {
        return
            "<span class='pripojit-poznamku-schvaleni js'" .
                " data-ron-akce='$akce'" .
                " data-ron-osoba='$rowData[13]'" .
                " data-ron-cislokurzu='" . StringUtils::htmlTextConvert($rowData[0]) . "'" .
                " data-ron-poznamkaschvaleni='" . StringUtils::htmlTextConvert($rowData[11]) . "'" .
                ">$textOznameniPoznamky</span>";
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $datumPocatkuKurzu = $this->database->stringToTimestamp($rowData[3]);

        $url = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&cisloskoleni=$rowData[0]&osoba=$rowData[13]&hromadne=0";

        //Pokud ma pravo schvalit osobu
        $urlSchvaleni = $url . "&plankurzuzamestnance=schvalit";
        //Odhlasit - zrusit (odstrani se zaznam)
        $urlOdhlaseni = $url . "&plankurzuzamestnance=zrusit";
        $urlZamitnuti = $url . "&plankurzuzamestnance=zamitnout";

        $jePrihlasen = $rowData[10] == 0 && $rowData[9] == 1;
        $jeSchvalen = $rowData[10] == 1;
        $jeZamitnut = $rowData[10] == 2;

        if ($datumPocatkuKurzu < DateUtils::today()) {
            // kurz uz probiha nebo probehl
            return \Ron\ronText('expirace_kurzu');
        }

        if (!$jeSchvalen  &&  !$jePrihlasen  &&  (int)$rowData[7] <= (int)$rowData[8]) {
            // neni prihlasen ani schvalen a kapacita kurzu je naplnena
            return \Ron\ronText('kapacita_planu_naplnena');
        }

//        if (!$muzeSchvalit  &&  (!$muzePrihlasit || $jeSchvalen)) {
//            // bud nemam zadne pravo, nebo je plan schvalen a nemam pravo (od)schvalovat => jen zobrazit
//            if ($jeSchvalen) {
//                return \Ron\ronText('osoba_je_na_planu');
//            }
//
//            return '';
//        }


        //Pokud ma pravo na schvaleni ale neni zapsan na planu pak nabidnout prihlaseni a schvaleni jinak pouze prihlaseni
        //Pokud je prihlasen a nema pravo schvalit pak zobrazit pouze text uzivatel je prihlasen
        if ($this ->jePravoPrihlasit || !$this ->jePravoSchvalit) {
            if ($jeSchvalen) {
                //Je schvalen -> je i prihlasen
                if ($this ->jePravoSchvalit) {
                    $textOznameni = \Ron\ronText('odhlasit_z_planu_skoleni');
                    return "<a href='$urlOdhlaseni'>$textOznameni</a>";
                }

                return \Ron\ronText('osoba_je_na_planu');
            }

            //Neni schvalen
            if ($jePrihlasen) {
                //Je prihlasen, ale neschvalen ->  moznost chvalit nebo ignorovat
                if ($this ->jePravoSchvalit) {
                    $textOznameni = \Ron\ronText('schvalit_plan_skoleni_uzivatel_ma_zajem');
                    $textOznameniPoznamky = \Ron\ronText('schvalit_plan_kurzu_poznamka');

                    $result =
                        "<div>" .
                        "<span class='padding-right-2'><a href='$urlSchvaleni'>$textOznameni</a></span>" .
                        $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky) .
                        "</div>";

                    if (!$jeZamitnut) {
                        $textOznameni = \Ron\ronText('zamitnout');
                        $textOznameniPoznamky = \Ron\ronText('zamitnout_plan_kurzu_poznamka');

                        $result .=
                            "<div>" .
                            "<span class='margin-right-2'><a href='$urlZamitnuti'>$textOznameni</a></span>" .
                            $this->schvalitPrihlaseniLink($rowData, 'zamitnout', $textOznameniPoznamky) .
                            "</div>";
                    }

                    return $result;
                }

                if ($this ->jePravoPrihlasit) {
                    $textOznameni = \Ron\ronText('odhlasit_z_planu_skoleni');
                    return "<a href='$urlOdhlaseni'>$textOznameni</a>";
                }

                return \Ron\ronText('osoba_je_prihlasena_na_planu');

            }

            //Neni prihlasen
            if ($this ->jePravoSchvalit) {
                $textOznameni = \Ron\ronText('prihlasit_schvalit_plan_skoleni_uzivatel_neprojevil_zajem');
                $textOznameniPoznamky = \Ron\ronText('prihlasit_schvalit_plan_kurzu_poznamka');
                return
                    "<span class='margin-right-2'><a href='$urlSchvaleni'>$textOznameni</a></span>" .
                    $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky);
            }

            if ($this ->jePravoPrihlasit && !$this ->jePravoSchvalit) {
                $textOznameni = \Ron\ronText('prihlasit_plan_skoleni_uzivatel_neprojevil_zajem');
                $textOznameniPoznamky = \Ron\ronText('prihlasit_plan_kurzu_poznamka');

                return
                    "<span class='margin-right-2'><a title=''  href='$urlSchvaleni'>$textOznameni</a></span>" .
                    $this->schvalitPrihlaseniLink($rowData, 'schvalit', $textOznameniPoznamky);
            }
        }

        return '';
    }
}


/**
 * Class SchvalovaniPlanuOsobyBrowser
 */
class SchvalovaniPlanuOsobyBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby $pravoPrihlasit */
    public $pravoPrihlasit;
    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /** @var PravaNaOsoby $pravoPlan */
    public $pravoPlan;

    /**
     * SchvalovaniPlanuKurzuPodrizenehoBrowser constructor.
     * @param Database $database
     * @throws Exception
     */
    public function __construct($database)
    {
        parent::__construct($database, 'skoleni');

        $this->code = 'browserschvalovaniplanukurzuosoby';
        $this->tableId = 'schvalovaniplanukurzuosoby';
        $this->browserUrl = "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=planypodleosoby";
        $this->pravoPrihlasit = Prava::vratPrava('skoleni_prihlasit');
        $this->pravoSchvalit = Prava::vratPrava('skoleni_schvaleni_planu');
        $this->pravoPlan = Prava::vratPrava('skoleni_plan');

        Prava::nastavObdobiProPrava(time(), time());

        $this->filterForm = new SchvalovaniPlanuKurzuOsobyFilter($database);
        $this->filterForm->loadData();

        $this->sqlSelectPart =
            "PS.CisloSkoleni, PS.Popis, PS.DruhSkoleni, PS.DatumPocatkuSkoleni, PS.CasPocatkuSkoleni, " .       // 0..4
            "PS.CasUkonceniSkoleni, PS.DatumUkonceniSkoleni, PS.PocetOsob AS Kapacita, " .                      // 5..7
            "(SELECT COUNT(RC) FROM PlanovaneSkoleniOsob PSO 
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.Potvrzeni < 2 ) AS CelkemPrihlasenych, " .     // 8

            "(SELECT COUNT(RC) FROM PlanovaneSkoleniOsob PSO 
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.RC = '" . $this ->filterForm ->vybranaOsobaRC . "') AS JePrihlasen," . // 9

            "(SELECT PSO.Potvrzeni FROM PlanovaneSkoleniOsob PSO 
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.RC = '" . $this ->filterForm ->vybranaOsobaRC . "') AS Schvaleni," .   // 10

            "(SELECT {fn_CASTWIDEMEMO(PSO.PoznamkaSchvalovani)} FROM PlanovaneSkoleniOsob PSO 
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.RC = '" . $this ->filterForm ->vybranaOsobaRC . "')," .    // 11

            "{fn_CASTWIDEMEMO(PS.Poznamka)}, " .        // 12

            "(SELECT MAX(ID) FROM PracovniPomer Where PracovniPomer.RC = '" . $this ->filterForm ->vybranaOsobaRC . "')," . // 13
            "(SELECT RC FROM PlanovaneSkoleniOsob 
                            Where DatumVlozeni = (Select MIN(DatumVlozeni) From PlanovaneSkoleniOsob Where PlanovaneSkoleniOsob.CisloSkoleni = PS.CisloSkoleni))"; // 14

        $this->sqlFromPart = "PlanovaneSkoleni PS";

        $this ->primaryField = 0;


        $this->addField(new PopisSkoleniField($database, $this->pravoPlan))
            ->setCode('col-detail')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.DruhSkoleni', 2) ->setHeaderText('druh_skoleni') ->setOrdering(1)
            ->setCode('col-druhskoleni');

        $this->addField()
            ->setSqlFieldName('PS.Popis', 1) ->setHeaderText('popis_planu_kurzu') ->setClassName('font-weight-bold') ->setOrdering(1)
            ->setCode('col-popis');

        $this->addField()
            ->setSqlFieldName('DatumPocatkuSkoleni', 3) ->setHeaderText('datum_pocatku_skoleni')
            ->setFormat('date') ->setOrdering(1) ->setAlign('center')
            ->setCode('col-datumpocatku');

        $this->addField()
            ->setSqlFieldName('DatumUkonceniSkoleni', 6) ->setHeaderText('datum_ukonceni_skoleni')
            ->setFormat('date') ->setOrdering(1) ->setAlign(1)
            ->setCode('col-datumukonceni');

        $this->addField(new PocetOsobNaKurzuField($database));

        $this->addField(new StavNaKurzuField($database));

        $muzePrihlasit = $this->pravoPrihlasit->lzeZobrazitRC($this ->filterForm ->vybranaOsobaRC);
        $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC($this ->filterForm ->vybranaOsobaRC);

        $this->addField(new SchvaleniPrihlaseniNaKurzuField($database, $muzePrihlasit, $muzeSchvalit));

        $this->defaultSort = -4;
    }

    function setFilterForm()
    {
        // uz bylo nastaveno v konstruktoru
    }


    /**
     * @param array $values
     * @param string $className
     * @param int $rowNumber
     * @param bool $edit
     */
    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        //PS.Poznamka : PS.Poznamka
        //PSO.PoznamkaSchvalovani: PSO.PoznamkaSchvalovani
        if ($values[11]) {
            echo
                "<tr class='$className'>" .
                '<td></td>' .
                '<td colspan="' . ($this->columnCount - 3) . '" class="poznamka">' .
                '<strong>' . \Ron\ronText('poznamka_schvaleni') . ': ' . '</strong>' .
                StringUtils::htmlTextConvert($values[11]) .
                '</td>' .
                '<td colspan="2"></td>' .
                '</tr>';
        }

        if ($values[12]) {
            echo
                "<tr class='$className'>" .
                '<td></td><td colspan="' . ($this->columnCount - 3) . '" class="poznamka">' .
                '<strong>' . \Ron\ronText('poznamka_kurzu') . '</strong>: ' .
                StringUtils::htmlTextConvert($values[12]) .
                '<td colspan="2"></td>' .
                '</tr>';
        }
    }


    /**
     * @return SqlStatement
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $result = "PS.Stav < 2";

        if (RonPortalSession::getFiltrovatDatum()) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumOd())) .
                ' AND PS.DatumPocatkuSkoleni <= ' . $params->addParameter( $this->database->timestampToParam(RonPortalSession::getDatumDo()));
        }

        if(isset($_SESSION['jenTypKurzu'])  &&  $_SESSION['jenTypKurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                " PS.DruhSkoleni = " . $params->addParameter($_SESSION['typKurzu']);
        }

        if(isset($_SESSION['neschvaleneplanykurzu'])  &&  $_SESSION['neschvaleneplanykurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                "(SELECT PSO.Potvrzeni FROM PlanovaneSkoleniOsob PSO
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.RC = " . $params->addParameter(RonPortalSession::osobaRC()) . ") = 0 ";
        }

        if(isset($_SESSION['aktualniplanykurzu'])  &&  $_SESSION['aktualniplanykurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addParameter( $this->database->timestampToParam(DateUtils::today()));
        }

        if(isset($_SESSION['pouzenaplanukurzu'])  &&  $_SESSION['pouzenaplanukurzu']){
            $result .=
                ($result ? ' AND ' : '') .
                "(SELECT COUNT(RC) FROM PlanovaneSkoleniOsob PSO
                Where PSO.CisloSkoleni = PS.CisloSkoleni AND PSO.RC = " . $params->addParameter(RonPortalSession::osobaRC()) . ") = 1 ";
        }


        return new SqlStatement($result, $params);
    }


    public function render()
    {
        parent::render();
        // dialog pro zadani poznamky
        require 'ronportal/skoleni/view_poznamka_schvaleni_planu.php';
    }


}
