<?php

/**
 * Pavel Rudol, RON Software
 *  10.2.2015
 */

namespace RonPortal\Terminaly;

use Exception;
use Ron\Controls\ComboBox;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;

/*
 * Zobrazi filtr rozdeleni, umisteni, urceni
 */
class TerminalyFilterForm extends RonPortalFilterForm
{
    /** @var string|null    Aktualni hodnota filtru umisteni */
    public $umisteniTerminalu;

    /** @var int|null       Aktualni hodnota filtru urceni */
    public $urceniTerminalu;

    /** @var bool           Aktualni hodnota filtru "jen neuspesne nactene" */
    public $jenNeuspesne = false;

    /**
     * TerminalyFilterForm constructor.
     * @param Database $database
     * @param string $action
     * @param PravaNaOsoby $prava
     */
    function __construct($database, $action, $prava)
    {
        parent::__construct($database, $action);

        //$this->f_classname = 'filtercontainer leftcaptions';
        //$this->f_formaction = '?menuid=terminaly';

        $this ->setUseGet(true, 'terminaly');

        $this->nastavRozdeleni(true, $prava->typRozdeleni, 2);
        $this->showVcetnePodrizenychRozdeleni = false;
        $this->f_pravarozdeleni = $prava;
    }

    /**
     * Renderuje radek s filtrem pro umisteni terminalu
     * @throws Exception
     */
    function renderUmisteniTerminalu()
    {
        echo '<div class="filterrow" id="filterrow_umisteniterminalu">';

        echo
            '<span class="filtercaption">' .
            //GuiUtils::renderCheckbox('jenUmisteniTerminalu', TextManager::_('terminal_jen_umisteni') . '&nbsp;&nbsp;', isset($_SESSION['jenUmisteniTerminalu']), 'onClick="submit()"');
            TextManager::_('terminal_jen_umisteni') .
            '</span>';

        // combobox pro vyber
        $sql =
            'SELECT Kod, Popis FROM Umisteni ';        

        $sql .=
            ' ORDER BY Popis';

        // vyber umisteni podle popisu
        $combo = new ComboBox('umisteni');
        $combo
            ->setClassName('form-input adsfilterforminput_full')
            ->addHtmlParam('data-ron-autosubmit', '1')
            ->setEmptyRow(TextManager::_('_vse_'))
            ->loadData($this ->database, $sql, $this ->umisteniTerminalu);
        $combo->render();
        
        echo "</div>\n";
    }
    

    /**
     * Renderuje radek s filtrem pro urceni terminalu
     * @throws Exception
     */
    function renderUrceniTerminalu()
    {
        echo '<div class="filterrow" id="filterrow_urceniterminalu">';

        echo
            '<span class="filtercaption">' .
            TextManager::_('terminal_jen_urceni') .
            '</span>';

        // combobox pro vyber
        $sql =
            'SELECT Kod, Popis FROM S_UrceniTerminalu ';        

        $sql .=
            ' ORDER BY Popis';

        // vyber urceni podle popisu
        $combo = new ComboBox('urceni');
        $combo
            ->setClassName('form-input adsfilterforminput_full')
            ->addHtmlParam('data-ron-autosubmit', '1')
            ->setEmptyRow(TextManager::_('_vse_'))
            ->setDataTypeComparison(false)
            ->loadData($this ->database, $sql, $this ->urceniTerminalu);

        $combo->render();
        
        echo "</div>\n";
    }

    

    function renderFiltrStav()
    {        
        echo
            '<div class="filterrow" id="filterrow_stavterminalu">' .
            '<span class="filtercaption"></span>' .
            // checkbox "Jen neuspesne nactene"
            '<label>' .
            '<input type="hidden" name="jenneuspesne" id="jen_neuspesne_terminaly" value="' . ($this ->jenNeuspesne ? '1' : '0') . '"/>' .
            '<input type="checkbox" class="setValue clickAutoSubmit" ' . ($this ->jenNeuspesne ? ' checked="checked"' : '') .
            ' data-selector="#jen_neuspesne_terminaly" data-value-checked="1" data-value-unchecked="0"/>' .
            TextManager::_('terminal_jen_neuspesne_nastavene') .
            '</label>' .

            "</div>\n";
    }
    
    private function loadUmisteniTerminalu()
    {
        if (isset($_GET['umisteni'])) {
            $this ->umisteniTerminalu = (trim($_GET['umisteni']) == '')
                ? null
                : trim($_GET['umisteni']);

            $_SESSION['umisteniTerminalu'] = $this ->umisteniTerminalu;
        } else {
            $this ->umisteniTerminalu = isset($_SESSION['umisteniTerminalu'])
                ? $_SESSION['umisteniTerminalu']
                : null;
        }
    }
    
    private function loadUrceniTerminalu()
    {
        if (isset($_GET['urceni'])) {
            $this ->urceniTerminalu = (trim($_GET['urceni']) == '')
                ? null
                : (int)$_GET['urceni'];

            $_SESSION['urceniTerminalu'] = $this ->urceniTerminalu;
        } else {
            $this ->urceniTerminalu = isset($_SESSION['urceniTerminalu'])
                ? (int)$_SESSION['urceniTerminalu']
                : null;
        }
    }
    
    private function loadFiltrStav()
    {
        if (isset($_GET['jenneuspesne'])) {
            $this ->jenNeuspesne = (int)$_GET['jenneuspesne'];
            $_SESSION['jenNeuspesneNastaveneTerminaly'] = $this ->jenNeuspesne;
        } else {
            $this ->jenNeuspesne = $_SESSION['jenNeuspesneNastaveneTerminaly'] ?? 0;
        }
    }
    
    function loadData()
    {
        parent::loadData();
        
        $this->loadUmisteniTerminalu();
        $this->loadUrceniTerminalu();
        $this->loadFiltrStav();
    }

    /**
     * @throws Exception
     */
    function renderFilters()
    {
        parent::renderFilters(); // rozdeleni
       
        $this->renderUrceniTerminalu();
        
        $this->renderUmisteniTerminalu();
       
        $this->renderFiltrStav();
    }
}


/**
 * Seznam terminalu, na ktere ma prihlaseny uzivatel pravo podle rozdeleni. 
 * Pokud nelze pro filtrovani pouzit rozdeleni, budou se zobrazovat vsechny terminaly.
 *
 * @author pavel.rudol
 */
class TerminalyBrowser extends RonPortalBrowser
{
    
    /** @var PravaNaOsoby */
    private $pravaZobrazit;

    /**
     * TerminalyBrowser constructor.
     * @param Database $database
     * @param $action
     */
    public function __construct($database, $action) {
        parent::__construct($database, $action);        
        
        Prava::nastavObdobiProPrava(time(), time());
        $this->pravaZobrazit = Prava::vratPrava('prohl_terminaly');
        
        $this->title = TextManager::_('terminaly');

        $this->code = 'browserterminaly';
        $this->tableId = 'browserterminaly';
        
        $this->sqlSelectPart = 
            'Terminal.Kod, StavTerminalu.NeuspesnychNastaveni, ' . $database ->castWideMemo('Terminal.Poznamka'); // 0-2

        $this->sqlFromPart = 
                'Terminal JOIN S_UrceniTerminalu ON (S_UrceniTerminalu.Kod = Terminal.KodUrceni) '.
                'LEFT JOIN Umisteni ON (Umisteni.Kod = Terminal.KodUmisteni) '.
                'LEFT JOIN Rozdeleni ON (Rozdeleni.KodTypuRozdeleni = Terminal.KodTypuRozdeleni AND Rozdeleni.Kod = Terminal.KodRozdeleni)'.
                'LEFT JOIN StavTerminalu ON (StavTerminalu.KodTerminalu = Terminal.Kod)';
        
        
        $this->defaultSort = 1;
        $this->primaryField = 0;
        
        $this->browserUrl = '?menuid=terminaly&';
        
        $this ->filterFormAppCode = 'ADS';
        $this ->filterFormRights = 'prohl_terminaly';
        
        $this->addField()
            ->setSqlFieldName('Terminal.Kod', 0) ->setHeaderText('Kod') ->setOrdering(true)
            ->setCode('col-kod');

        $this->addField()
            ->setSqlFieldName('Terminal.Popis') ->setHeaderText('Popis') ->setOrdering(true)
            ->setCode('col-popis')
            ->setLink('?menuid=terminaly');

        $this->addField()
            ->setSqlFieldName('S_UrceniTerminalu.Popis') ->setHeaderText('terminal_urceni') ->setOrdering(true)
            ->setCode('col-urceni');

        $this->addField()
            ->setSqlFieldName('Umisteni.Popis') ->setHeaderText('umisteni') ->setOrdering(true)
            ->setCode('col-umisteni');

        $this->addField()
            ->setSqlFieldName('Rozdeleni.Popis') ->setHeaderText('rozdeleni') ->setOrdering(true)
            ->setCode('col-rozdeleni');

        $this->addField()
            ->setSqlFieldName('StavTerminalu.NeuspesnychNastaveni', 1) ->setHeaderText('terminal_pocet_nastaveni_browser')
            ->setAlign('center') ->setOrdering(true)
            ->setCode('col-neuspesnychnastaveni');

    }
    

    function setFilterForm() {
        $this->filterForm = new TerminalyFilterForm($this->database, $this->action, $this->pravaZobrazit);        
    }
    
    
    /**
     * Vraci cast retezce, ktera se vlozi do WHERE casti dotazu
     * muze vracet napriklad filtr podle zvolenych filtru (viz renderFilter)
     * 
     * @return string
     */
    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        if ($this->pravaZobrazit->jsouNejakePrava())
        {
            //$result = '((Rozdeleni.KodTypuRozdeleni = 8) OR (' . $this->f_pravaZobrazit->SQLfiltrRozdeleni(time(), time(), 1) . '))'; //rozdeleni na ktere je pravo vcetne vsech jidelen
            $result = '(' . $this->pravaZobrazit->sqlfiltrRozdeleni(time(), time(), 1) . ')'; //rozdeleni na ktere je pravo
        }
        else 
        {   
            $result = '1 = 0';   
        } 
                
        if ($this ->filterForm instanceof TerminalyFilterForm  &&  isset($this ->filterForm ->umisteniTerminalu)) {
            $result .=
                ($result ? ' AND ' : '') .
                ' Terminal.KodUmisteni = ' . $params ->addParameter($this ->filterForm ->umisteniTerminalu);
        }

        if ($this ->filterForm instanceof TerminalyFilterForm  &&  isset($this ->filterForm ->urceniTerminalu)) {
            $result .=
                ($result ? ' AND ' : '') .
                'Terminal.KodUrceni = ' . $params ->addParameter($this ->filterForm ->urceniTerminalu);
        }

        if (isset($this->filterForm->kodRozdeleni)) {
            $result .=
                ($result ? ' AND ' : '') .
                'Terminal.KodTypuRozdeleni = ' . $params ->addParameter((int)$this->pravaZobrazit->typRozdeleni) .
                ' AND Terminal.KodRozdeleni = ' . $params ->addParameter($this->filterForm->kodRozdeleni);
        }
        
        //if (isset($_SESSION['jenNeuspesneNastavene'])) {
        if ($this ->filterForm instanceof TerminalyFilterForm  &&  $this ->filterForm ->jenNeuspesne) {
            $result .=
                ($result ? ' AND ' : '') .
                ' StavTerminalu.NeuspesnychNastaveni > 0';
        }
        
        return new SqlStatement($result, $params);
    }



    function renderLine($values, $classname, $rownumber, $edit = false)
    {      
        
        if ($values[1] > 0) {
            $classname = $rownumber % 2 ? 'terminal_neuspesnenastaveni1' : 'terminal_neuspesnenastaveni2';
        }
        
        parent::renderLine($values, $classname, $rownumber, $edit);

        // Poznamka
        if ($values[2]) {
            echo
                "<tr class='$classname'>" .
                '<td></td>' .
                '<td colspan="' . ($this->visibleFieldsCount() - 1) . '"><span class="browserpoznamka terminalpoznamka">' . StringUtils::htmlTextConvert($values[2]) . '</span></td>' .
                '</tr>';
        }
    }
}
